(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    212087,       4580]
NotebookOptionsPosition[    207448,       4422]
NotebookOutlinePosition[    208054,       4446]
CellTagsIndexPosition[    208011,       4443]
WindowFrame->Normal
ContainsDynamic->True *)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Sample ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code for the paper \"Modeling a Diving Board\""
}], "Subtitle"],

Cell["\<\
Michael A. Karls and Brenda M. Skoczelas, Department of Mathematical \
Sciences, Ball State University, Muncie, IN  47306\
\>", "Subsubtitle",
 CellChangeTimes->{{3.456060025890625*^9, 3.45606008934375*^9}}],

Cell[CellGroupData[{

Cell["Beam Data", "Subsection"],

Cell[CellGroupData[{

Cell["Original Data", "Subsubsection"],

Cell["\<\
Remove headings from original data collected with World in Motion software.  

NOTE:  At t = 1 second, World in Motion recorded values of (-2000, -2000) for \
the (x, y) data point at the 13th tape mark, at approximately x = 1.46 m.  \
Looking at the nearby data, these clearly cannot be correct, so we \
interpolated the values from the corresponding points for x = 1.46 m at t = \
0.967 sec, which was recorded as (1.472478, 0), and at t = 1.033 sec, which \
was recorded as (1.481429, 0.0582).  These corrections are noted below in \
red.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Beam", "=", 
   RowBox[{"Drop", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<t(s)\>\"", ",", "\"\<x1(m)\>\"", ",", "\"\<y1(m)\>\"", ",", 
         "\"\<x2(m)\>\"", ",", "\"\<y2(m)\>\"", ",", "\"\<x3(m)\>\"", ",", 
         "\"\<y3(m)\>\"", ",", "\"\<x4(m)\>\"", ",", "\"\<y4(m)\>\"", ",", 
         "\"\<x5(m)\>\"", ",", "\"\<y5(m)\>\"", ",", "\"\<x6(m)\>\"", ",", 
         "\"\<y6(m)\>\"", ",", "\"\<x7(m)\>\"", ",", "\"\<y7(m)\>\"", ",", 
         "\"\<x8(m)\>\"", ",", "\"\<y8(m)\>\"", ",", "\"\<x9(m)\>\"", ",", 
         "\"\<y9(m)\>\"", ",", "\"\<x10(m)\>\"", ",", "\"\<y10(m)\>\"", ",", 
         "\"\<x11(m)\>\"", ",", "\"\<y11(m)\>\"", ",", "\"\<x12(m)\>\"", ",", 
         "\"\<y12(m)\>\"", ",", "\"\<x13(m)\>\"", ",", "\"\<y13(m)\>\"", ",", 
         "\"\<x14(m)\>\"", ",", "\"\<y14(m)\>\"", ",", "\"\<x15(m)\>\"", ",", 
         "\"\<y15(m)\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2193052`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.3401469`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.4475617`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.5549766`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.6713426`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "0.783233`", ",", 
         RowBox[{"-", "0.0805611`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.0985`"}], ",", "1.015965`", ",", 
         RowBox[{"-", "0.1208416`"}], ",", "1.12338`", ",", 
         RowBox[{"-", "0.1432197`"}], ",", "1.230795`", ",", 
         RowBox[{"-", "0.174549`"}], ",", "1.347161`", ",", 
         RowBox[{"-", "0.1924515`"}], ",", "1.459051`", ",", 
         RowBox[{"-", "0.2193052`"}], ",", "1.570942`", ",", 
         RowBox[{"-", "0.246159`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.033`", ",", "0.00448`", ",", "0", ",", "0.1074148`", ",", "0", ",",
          "0.2148296`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.3401469`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.4475617`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.5549766`", ",", 
         RowBox[{"-", "0.0448`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "0.783233`", ",", 
         RowBox[{"-", "0.0805611`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.0985`"}], ",", "1.015965`", ",", 
         RowBox[{"-", "0.1208416`"}], ",", "1.12338`", ",", 
         RowBox[{"-", "0.1432197`"}], ",", "1.23527`", ",", 
         RowBox[{"-", "0.174549`"}], ",", "1.347161`", ",", 
         RowBox[{"-", "0.1924515`"}], ",", "1.459051`", ",", 
         RowBox[{"-", "0.2193052`"}], ",", "1.566466`", ",", 
         RowBox[{"-", "0.246159`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.067`", ",", "0.00448`", ",", "0", ",", "0.1074148`", ",", "0", ",",
          "0.2193052`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.3446226`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.4520373`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.5549766`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "0.783233`", ",", 
         RowBox[{"-", "0.0805611`"}], ",", "0.8951235`", ",", 
         RowBox[{"-", "0.0985`"}], ",", "1.015965`", ",", 
         RowBox[{"-", "0.1208416`"}], ",", "1.12338`", ",", 
         RowBox[{"-", "0.1432197`"}], ",", "1.23527`", ",", 
         RowBox[{"-", "0.174549`"}], ",", "1.347161`", ",", 
         RowBox[{"-", "0.1924515`"}], ",", "1.459051`", ",", 
         RowBox[{"-", "0.2193052`"}], ",", "1.566466`", ",", 
         RowBox[{"-", "0.246159`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.1`", ",", "0.00448`", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2193052`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.3446226`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.4430861`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.5549766`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0805611`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.1029392`"}], ",", "1.015965`", ",", 
         RowBox[{"-", "0.1208416`"}], ",", "1.12338`", ",", 
         RowBox[{"-", "0.1432197`"}], ",", "1.23527`", ",", 
         RowBox[{"-", "0.1700734`"}], ",", "1.347161`", ",", 
         RowBox[{"-", "0.1924515`"}], ",", "1.459051`", ",", 
         RowBox[{"-", "0.2193052`"}], ",", "1.570942`", ",", 
         RowBox[{"-", "0.246159`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.133`", ",", "0.00448`", ",", "0", ",", "0.1074148`", ",", "0", ",",
          "0.2193052`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.3446226`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.4430861`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.5549766`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.6713426`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0805611`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.094`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.1208416`"}], ",", "1.12338`", ",", 
         RowBox[{"-", "0.1432197`"}], ",", "1.23527`", ",", 
         RowBox[{"-", "0.1700734`"}], ",", "1.347161`", ",", 
         RowBox[{"-", "0.1924515`"}], ",", "1.459051`", ",", 
         RowBox[{"-", "0.2148296`"}], ",", "1.570942`", ",", 
         RowBox[{"-", "0.2372077`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.167`", ",", "0.00448`", ",", "0", ",", "0.1074148`", ",", "0", ",",
          "0.2193052`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.3446226`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.4430861`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "0.6713426`", ",", 
         RowBox[{"-", "0.0492`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0761`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.0895`"}], ",", "1.015965`", ",", 
         RowBox[{"-", "0.0985`"}], ",", "1.127856`", ",", 
         RowBox[{"-", "0.1253173`"}], ",", "1.239746`", ",", 
         RowBox[{"-", "0.1476954`"}], ",", "1.351636`", ",", 
         RowBox[{"-", "0.1655978`"}], ",", "1.463527`", ",", 
         RowBox[{"-", "0.1879759`"}], ",", "1.579893`", ",", 
         RowBox[{"-", "0.1969271`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.2`", ",", "0.00448`", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2193052`", ",", "0", ",", "0.3446226`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.4475617`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0313`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0448`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.0492`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0627`"}], ",", "1.136807`", ",", 
         RowBox[{"-", "0.0716`"}], ",", "1.248697`", ",", 
         RowBox[{"-", "0.0895`"}], ",", "1.360588`", ",", 
         RowBox[{"-", "0.0985`"}], ",", "1.459051`", ",", 
         RowBox[{"-", "0.116366`"}], ",", "1.584369`", ",", 
         RowBox[{"-", "0.1253173`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.233`", ",", "0.00448`", ",", "0", ",", "0.1074148`", ",", "0", ",",
          "0.2193052`", ",", "0", ",", "0.3401469`", ",", "0", ",", 
         "0.4475617`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.9040747`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "1.024916`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "1.136807`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "1.253173`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "1.369539`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "1.463527`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "1.597795`", ",", 
         RowBox[{"-", "0.0313`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.267`", ",", "0.00448`", ",", "0", ",", "0.1074148`", ",", "0", ",",
          "0.2237809`", ",", "0.00448`", ",", "0.3446226`", ",", "0.00448`", 
         ",", "0.4430861`", ",", "0.00448`", ",", "0.5594522`", ",", 
         "0.00895`", ",", "0.6713426`", ",", "0.00895`", ",", "0.7921843`", 
         ",", "0.0179`", ",", "0.9040747`", ",", "0.0224`", ",", "1.024916`", 
         ",", "0.0269`", ",", "1.136807`", ",", "0.0313`", ",", "1.253173`", 
         ",", "0.0403`", ",", "1.369539`", ",", "0.0448`", ",", "1.463527`", 
         ",", "0.0492`", ",", "1.597795`", ",", "0.0627`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.3`", ",", "0.00448`", ",", "0", ",", "0.1074148`", ",", "0.00448`",
          ",", "0.2282565`", ",", "0.00895`", ",", "0.3446226`", ",", 
         "0.00895`", ",", "0.4475617`", ",", "0.0179`", ",", "0.5594522`", 
         ",", "0.0224`", ",", "0.6758182`", ",", "0.0313`", ",", "0.7877086`",
          ",", "0.0358`", ",", "0.9040747`", ",", "0.0403`", ",", "1.020441`",
          ",", "0.0537`", ",", "1.141282`", ",", "0.0627`", ",", "1.248697`", 
         ",", "0.0716`", ",", "1.369539`", ",", "0.0806`", ",", "1.468003`", 
         ",", "0.085`", ",", "1.59332`", ",", "0.0985`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.333`", ",", "0.00448`", ",", "0", ",", "0.1074148`", ",", "0", ",",
          "0.2282565`", ",", "0.00448`", ",", "0.3490981`", ",", "0.00448`", 
         ",", "0.4520373`", ",", "0.00895`", ",", "0.5594522`", ",", 
         "0.0134269`", ",", "0.6758182`", ",", "0.0134269`", ",", 
         "0.7921843`", ",", "0.0269`", ",", "0.9040747`", ",", "0.0313`", ",",
          "1.020441`", ",", "0.0448`", ",", "1.136807`", ",", "0.0492`", ",", 
         "1.253173`", ",", "0.0537`", ",", "1.369539`", ",", "0.0627`", ",", 
         "1.472478`", ",", "0.0761`", ",", "1.59332`", ",", "0.0806`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.367`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2282565`", ",", "0", ",", "0.3490981`", ",", "0.00448`", ",", 
         "0.4520373`", ",", "0", ",", "0.5639278`", ",", "0.00448`", ",", 
         "0.6758182`", ",", "0.00895`", ",", "0.7921843`", ",", "0.00895`", 
         ",", "0.9040747`", ",", "0.00895`", ",", "1.020441`", ",", 
         "0.0134269`", ",", "1.136807`", ",", "0.00895`", ",", "1.253173`", 
         ",", "0.00895`", ",", "1.369539`", ",", "0.0179`", ",", "1.476954`", 
         ",", "0.0134269`", ",", "1.59332`", ",", "0.0179`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.4`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2327321`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.3490981`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.4520373`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.6713426`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.7921843`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.9040747`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "1.024916`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "1.132331`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "1.248697`", ",", 
         RowBox[{"-", "0.0492`"}], ",", "1.369539`", ",", 
         RowBox[{"-", "0.0537`"}], ",", "1.472478`", ",", 
         RowBox[{"-", "0.0627`"}], ",", "1.588844`", ",", 
         RowBox[{"-", "0.0671`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.433`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2327321`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.3490981`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.4520373`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0537`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.0716`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0761`"}], ",", "1.132331`", ",", 
         RowBox[{"-", "0.094`"}], ",", "1.248697`", ",", 
         RowBox[{"-", "0.1029392`"}], ",", "1.360588`", ",", 
         RowBox[{"-", "0.1253173`"}], ",", "1.468003`", ",", 
         RowBox[{"-", "0.1297929`"}], ",", "1.584369`", ",", 
         RowBox[{"-", "0.1476954`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.467`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2282565`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.3490981`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.4520373`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.6713426`", ",", 
         RowBox[{"-", "0.0492`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0716`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.094`"}], ",", "1.015965`", ",", 
         RowBox[{"-", "0.1029392`"}], ",", "1.118904`", ",", 
         RowBox[{"-", "0.1253173`"}], ",", "1.244222`", ",", 
         RowBox[{"-", "0.1432197`"}], ",", "1.356112`", ",", 
         RowBox[{"-", "0.1700734`"}], ",", "1.463527`", ",", 
         RowBox[{"-", "0.1879759`"}], ",", "1.575417`", ",", 
         RowBox[{"-", "0.2058784`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.5`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2327321`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.3490981`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "0.4520373`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.6713426`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0761`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.094`"}], ",", "1.015965`", ",", 
         RowBox[{"-", "0.1118904`"}], ",", "1.127856`", ",", 
         RowBox[{"-", "0.1387441`"}], ",", "1.244222`", ",", 
         RowBox[{"-", "0.1566466`"}], ",", "1.356112`", ",", 
         RowBox[{"-", "0.174549`"}], ",", "1.463527`", ",", 
         RowBox[{"-", "0.1969271`"}], ",", "1.570942`", ",", 
         RowBox[{"-", "0.2058784`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.533`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2327321`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.3490981`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.4520373`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.6713426`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "0.9040747`", ",", 
         RowBox[{"-", "0.0716`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0895`"}], ",", "1.127856`", ",", 
         RowBox[{"-", "0.1029392`"}], ",", "1.248697`", ",", 
         RowBox[{"-", "0.1253173`"}], ",", "1.360588`", ",", 
         RowBox[{"-", "0.1387441`"}], ",", "1.463527`", ",", 
         RowBox[{"-", "0.1611222`"}], ",", "1.570942`", ",", 
         RowBox[{"-", "0.1700734`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.567`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2372077`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.3490981`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.4520373`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0448`"}], ",", "1.132331`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "1.248697`", ",", 
         RowBox[{"-", "0.0671`"}], ",", "1.369539`", ",", 
         RowBox[{"-", "0.0761`"}], ",", "1.472478`", ",", 
         RowBox[{"-", "0.0895`"}], ",", "1.575417`", ",", 
         RowBox[{"-", "0.0985`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.6`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0.00448`", ",", 
         "0.2372077`", ",", "0", ",", "0.3490981`", ",", "0", ",", 
         "0.4520373`", ",", "0", ",", "0.5549766`", ",", "0", ",", 
         "0.6758182`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "1.136807`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "1.248697`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "1.369539`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "1.472478`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "1.584369`", ",", 
         RowBox[{"-", "0.0134`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.633`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0.00448`", ",",
          "0.2372077`", ",", "0.00895`", ",", "0.3490981`", ",", "0.00448`", 
         ",", "0.456513`", ",", "0.00895`", ",", "0.5594522`", ",", 
         "0.00895`", ",", "0.6758182`", ",", "0.0134269`", ",", "0.7921843`", 
         ",", "0.0179`", ",", "0.8995991`", ",", "0.0269`", ",", "1.024916`", 
         ",", "0.0313`", ",", "1.136807`", ",", "0.0313`", ",", "1.248697`", 
         ",", "0.0403`", ",", "1.374014`", ",", "0.0403`", ",", "1.472478`", 
         ",", "0.0448`", ",", "1.588844`", ",", "0.0582`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.667`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2372077`", ",", "0.00895`", ",", "0.3490981`", ",", "0.00895`", 
         ",", "0.456513`", ",", "0.00895`", ",", "0.5594522`", ",", "0.0179`",
          ",", "0.6758182`", ",", "0.0224`", ",", "0.7877086`", ",", 
         "0.0269`", ",", "0.9040747`", ",", "0.0313`", ",", "1.024916`", ",", 
         "0.0448`", ",", "1.136807`", ",", "0.0492`", ",", "1.248697`", ",", 
         "0.0582`", ",", "1.374014`", ",", "0.0671`", ",", "1.481429`", ",", 
         "0.0716`", ",", "1.588844`", ",", "0.0806`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.7`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2416833`", ",", "0", ",", "0.3535738`", ",", "0.00448`", ",", 
         "0.456513`", ",", "0.00895`", ",", "0.5594522`", ",", "0.0134269`", 
         ",", "0.6758182`", ",", "0.0179`", ",", "0.7877086`", ",", "0.0179`",
          ",", "0.8995991`", ",", "0.0224`", ",", "1.020441`", ",", "0.0269`",
          ",", "1.136807`", ",", "0.0358`", ",", "1.253173`", ",", "0.0403`", 
         ",", "1.365063`", ",", "0.0448`", ",", "1.485905`", ",", "0.0492`", 
         ",", "1.59332`", ",", "0.0582`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.733`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2416833`", ",", "0", ",", "0.3535738`", ",", "0", ",", 
         "0.456513`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.5594522`", ",", "0", ",", 
         "0.6758182`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "1.020441`", ",", "0", ",", 
         "1.132331`", ",", "0", ",", "1.248697`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "1.360588`", ",", "0", ",", 
         "1.481429`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "1.588844`", ",", 
         RowBox[{"-", "0.00895`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.767`", ",", "0", ",", "0", ",", "0.1029392`", ",", "0", ",", 
         "0.2416833`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.3535738`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.456513`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0313`"}], ",", "0.8951235`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "1.132331`", ",", 
         RowBox[{"-", "0.0537`"}], ",", "1.244222`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "1.369539`", ",", 
         RowBox[{"-", "0.0627`"}], ",", "1.476954`", ",", 
         RowBox[{"-", "0.0716`"}], ",", "1.584369`", ",", 
         RowBox[{"-", "0.0761`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.8`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2416833`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.3535738`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.456513`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.7921843`", ",", 
         RowBox[{"-", "0.0537`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.0671`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0761`"}], ",", "1.132331`", ",", 
         RowBox[{"-", "0.0985`"}], ",", "1.248697`", ",", 
         RowBox[{"-", "0.1118904`"}], ",", "1.360588`", ",", 
         RowBox[{"-", "0.1253173`"}], ",", "1.472478`", ",", 
         RowBox[{"-", "0.1387441`"}], ",", "1.579893`", ",", 
         RowBox[{"-", "0.152171`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.833`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.246159`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.3535738`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.4609886`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0537`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0671`"}], ",", "0.8951235`", ",", 
         RowBox[{"-", "0.0850367`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.1029392`"}], ",", "1.136807`", ",", 
         RowBox[{"-", "0.1253173`"}], ",", "1.244222`", ",", 
         RowBox[{"-", "0.1387441`"}], ",", "1.360588`", ",", 
         RowBox[{"-", "0.1566466`"}], ",", "1.468003`", ",", 
         RowBox[{"-", "0.1835003`"}], ",", "1.579893`", ",", 
         RowBox[{"-", "0.1969271`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.867`", ",", "0", ",", "0", ",", "0.1074148`", ",", "0", ",", 
         "0.2416833`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.3535738`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.4609886`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "0.6802939`", ",", 
         RowBox[{"-", "0.0492`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0627`"}], ",", "0.8951235`", ",", 
         RowBox[{"-", "0.0761`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0985`"}], ",", "1.132331`", ",", 
         RowBox[{"-", "0.1208416`"}], ",", "1.244222`", ",", 
         RowBox[{"-", "0.1342685`"}], ",", "1.356112`", ",", 
         RowBox[{"-", "0.1566466`"}], ",", "1.468003`", ",", 
         RowBox[{"-", "0.174549`"}], ",", "1.579893`", ",", 
         RowBox[{"-", "0.1879759`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.9`", ",", "0", ",", "0", ",", "0.0985`", ",", "0", ",", 
         "0.246159`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.3580494`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.456513`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.783233`", ",", 
         RowBox[{"-", "0.0492`"}], ",", "0.8951235`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0761`"}], ",", "1.136807`", ",", 
         RowBox[{"-", "0.094`"}], ",", "1.244222`", ",", 
         RowBox[{"-", "0.1074148`"}], ",", "1.360588`", ",", 
         RowBox[{"-", "0.116366`"}], ",", "1.472478`", ",", 
         RowBox[{"-", "0.1342685`"}], ",", "1.579893`", ",", 
         RowBox[{"-", "0.1432197`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.933`", ",", "0", ",", "0", ",", "0.0985`", ",", "0", ",", 
         "0.246159`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.3535738`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.4654642`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.5639278`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.8951235`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0448`"}], ",", "1.136807`", ",", 
         RowBox[{"-", "0.0492`"}], ",", "1.248697`", ",", 
         RowBox[{"-", "0.0537`"}], ",", "1.365063`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "1.472478`", ",", 
         RowBox[{"-", "0.0761`"}], ",", "1.584369`", ",", 
         RowBox[{"-", "0.0761`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.967`", ",", "0", ",", "0", ",", "0.1029392`", ",", "0", ",", 
         "0.2506346`", ",", "0", ",", "0.3580494`", ",", "0", ",", 
         "0.4609886`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.5639278`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.6758182`", ",", "0", ",", 
         "0.7877086`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.8951235`", ",", "0", ",", 
         "1.020441`", ",", "0", ",", "1.136807`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "1.248697`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "1.365063`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "1.472478`", ",", "0", ",", 
         "1.584369`", ",", 
         RowBox[{"-", "0.00448`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0", ",", "0", ",", "0.1029392`", ",", "0", ",", 
         "0.2506346`", ",", "0.00448`", ",", "0.3580494`", ",", "0.00895`", 
         ",", "0.4609886`", ",", "0.00895`", ",", "0.5594522`", ",", 
         "0.00895`", ",", "0.6758182`", ",", "0.0134269`", ",", "0.7877086`", 
         ",", "0.0134269`", ",", "0.8951235`", ",", "0.0224`", ",", 
         "1.024916`", ",", "0.0269`", ",", "1.141282`", ",", "0.0269`", ",", 
         "1.244222`", ",", "0.0358`", ",", "1.365063`", ",", "0.0403`", ",", 
         StyleBox[
          FractionBox[
           StyleBox[
            RowBox[{"1.472478", "+", "1.481429"}],
            FontColor->RGBColor[1, 0, 0]], "2"],
          FontColor->RGBColor[1, 0, 0]], 
         StyleBox[",",
          FontColor->RGBColor[1, 0, 0]], 
         StyleBox[
          FractionBox[
           StyleBox[
            RowBox[{"0", "+", "0.0582"}],
            FontColor->RGBColor[1, 0, 0]], "2"],
          FontColor->RGBColor[1, 0, 0]], ",", "1.588844`", ",", "0.0537`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.033`", ",", "0", ",", "0", ",", "0.1029392`", ",", "0", ",", 
         "0.246159`", ",", "0.00895`", ",", "0.3580494`", ",", "0.00895`", 
         ",", "0.4609886`", ",", "0.0134269`", ",", "0.5594522`", ",", 
         "0.0134269`", ",", "0.6758182`", ",", "0.0179`", ",", "0.7921843`", 
         ",", "0.0224`", ",", "0.8995991`", ",", "0.0313`", ",", "1.024916`", 
         ",", "0.0313`", ",", "1.145758`", ",", "0.0403`", ",", "1.244222`", 
         ",", "0.0492`", ",", "1.369539`", ",", "0.0537`", ",", "1.481429`", 
         ",", "0.0582`", ",", "1.584369`", ",", "0.0671`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.067`", ",", "0", ",", "0", ",", "0.1029392`", ",", "0", ",", 
         "0.246159`", ",", "0", ",", "0.3580494`", ",", "0.00448`", ",", 
         "0.4609886`", ",", "0", ",", "0.5594522`", ",", "0.00448`", ",", 
         "0.6802939`", ",", "0.0134269`", ",", "0.7921843`", ",", "0.00448`", 
         ",", "0.8995991`", ",", "0.0134269`", ",", "1.024916`", ",", 
         "0.0134269`", ",", "1.145758`", ",", "0.0224`", ",", "1.248697`", 
         ",", "0.0179`", ",", "1.369539`", ",", "0.0269`", ",", "1.481429`", 
         ",", "0.0313`", ",", "1.59332`", ",", "0.0358`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.1`", ",", "0", ",", "0", ",", "0.1029392`", ",", "0", ",", 
         "0.2506346`", ",", "0", ",", "0.362525`", ",", "0", ",", 
         "0.4609886`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.7921843`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "1.145758`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "1.248697`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "1.365063`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "1.476954`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "1.59332`", ",", 
         RowBox[{"-", "0.0269`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.133`", ",", "0", ",", "0", ",", "0.1029392`", ",", "0", ",", 
         "0.2416833`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.362525`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.456513`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "0.6802939`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.7921843`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0448`"}], ",", "1.141282`", ",", 
         RowBox[{"-", "0.0671`"}], ",", "1.244222`", ",", 
         RowBox[{"-", "0.0716`"}], ",", "1.360588`", ",", 
         RowBox[{"-", "0.0761`"}], ",", "1.476954`", ",", 
         RowBox[{"-", "0.0895`"}], ",", "1.588844`", ",", 
         RowBox[{"-", "0.1074148`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.167`", ",", "0", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.1029392`", ",", "0", ",", 
         "0.2416833`", ",", 
         RowBox[{"-", "0.00895`"}], ",", "0.3670006`", ",", 
         RowBox[{"-", "0.0134`"}], ",", "0.4609886`", ",", 
         RowBox[{"-", "0.0224`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0313`"}], ",", "0.6758182`", ",", 
         RowBox[{"-", "0.0403`"}], ",", "0.7921843`", ",", 
         RowBox[{"-", "0.0582`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.0671`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.0850367`"}], ",", "1.141282`", ",", 
         RowBox[{"-", "0.0985`"}], ",", "1.253173`", ",", 
         RowBox[{"-", "0.1118904`"}], ",", "1.360588`", ",", 
         RowBox[{"-", "0.1253173`"}], ",", "1.476954`", ",", 
         RowBox[{"-", "0.1476954`"}], ",", "1.584369`", ",", 
         RowBox[{"-", "0.1566466`"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2`", ",", "0", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.0985`", ",", "0", ",", 
         "0.2416833`", ",", 
         RowBox[{"-", "0.00448`"}], ",", "0.362525`", ",", 
         RowBox[{"-", "0.0179`"}], ",", "0.4520373`", ",", 
         RowBox[{"-", "0.0269`"}], ",", "0.5594522`", ",", 
         RowBox[{"-", "0.0358`"}], ",", "0.6802939`", ",", 
         RowBox[{"-", "0.0492`"}], ",", "0.7877086`", ",", 
         RowBox[{"-", "0.0671`"}], ",", "0.8995991`", ",", 
         RowBox[{"-", "0.0761`"}], ",", "1.020441`", ",", 
         RowBox[{"-", "0.094`"}], ",", "1.136807`", ",", 
         RowBox[{"-", "0.116366`"}], ",", "1.244222`", ",", 
         RowBox[{"-", "0.1297929`"}], ",", "1.356112`", ",", 
         RowBox[{"-", "0.152171`"}], ",", "1.476954`", ",", 
         RowBox[{"-", "0.174549`"}], ",", "1.579893`", ",", 
         RowBox[{"-", "0.1879759`"}]}], "}"}]}], "}"}], ",", "1"}], "]"}]}], 
  ";"}]], "Input"],

Cell["\<\
Remove the first entry of each row, which corresponds to the time t at which \
the data was collected, for t \[GreaterEqual] 0 seconds.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Beam", "=", 
   RowBox[{"Drop", "[", 
    RowBox[{"Beam", ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "1", "}"}]}], "]"}]}], ";"}]], "Input"],

Cell["\<\
Define the positions for the tape pieces along the beam.  Check the length of \
this list - there should be fifteen points.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xtape", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Beam", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "i", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"Beam", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "2"}], "}"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0.1074148`", ",", "0.2193052`", ",", "0.3401469`", ",", 
   "0.4475617`", ",", "0.5549766`", ",", "0.6713426`", ",", "0.783233`", ",", 
   "0.8995991`", ",", "1.015965`", ",", "1.12338`", ",", "1.230795`", ",", 
   "1.347161`", ",", "1.459051`", ",", "1.570942`"}], "}"}]], "Output",
 CellChangeTimes->{3.456061439734375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "xtape", "]"}]], "Input"],

Cell[BoxData["15"], "Output",
 CellChangeTimes->{3.456061439796875*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Steady-State Solution", "Subsection"],

Cell["Solve the steady-state problem.", "Text"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"L", ",", "v", ",", "c", ",", "g"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["c", "2"]}], 
       RowBox[{
        RowBox[{"V", "''''"}], "[", "x", "]"}]}], "\[Equal]", "g"}], ",", 
     RowBox[{
      RowBox[{"V", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"V", "'"}], "[", "0", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"V", "''"}], "[", "L", "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"V", "'''"}], "[", "L", "]"}], "\[Equal]", "0"}]}], "}"}], ",",
    
   RowBox[{"V", "[", "x", "]"}], ",", "x"}], "]"}]], "Input",
 CellChangeTimes->{{3.4354830778616147`*^9, 3.435483097174238*^9}, 
   3.4354861195913906`*^9, 3.4354861645913906`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"V", "[", "x", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", "g", " ", 
       SuperscriptBox["L", "2"], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"4", " ", "g", " ", "L", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"g", " ", 
       SuperscriptBox["x", "4"]}]}], 
     RowBox[{"24", " ", 
      SuperscriptBox["c", "2"]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.456061439984375*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", "[", "x_", "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "g", " ", 
     SuperscriptBox["L", "2"], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"4", " ", "g", " ", "L", " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"g", " ", 
     SuperscriptBox["x", "4"]}]}], 
   RowBox[{"24", " ", 
    SuperscriptBox["c", "2"]}]]}]], "Input",
 CellChangeTimes->{{3.435483107768056*^9, 3.435483116549362*^9}, 
   3.4354861324663906`*^9, 3.4354861708101406`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v", "[", "x", "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", "g", " ", 
    SuperscriptBox["L", "2"], " ", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{"4", " ", "g", " ", "L", " ", 
    SuperscriptBox["x", "3"]}], "-", 
   RowBox[{"g", " ", 
    SuperscriptBox["x", "4"]}]}], 
  RowBox[{"24", " ", 
   SuperscriptBox["c", "2"]}]]], "Output",
 CellChangeTimes->{3.456061440078125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initial Conditions", "Subsection"],

Cell[TextData[{
 "Define initial conditions and model parameters.  Length of beam is L \
meters.  Parameters c, k, and g will be chosen dynamically below.  The \
function f(x) is initial displacement of beam.  Initial velocity g(x) is \
assumed to be zero.   Define ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"h", "(", "x", ")"}], "=", 
    RowBox[{
     RowBox[{"f", "(", "x", ")"}], "-", 
     RowBox[{"v", "(", "x", ")"}]}]}], TraditionalForm]]],
 " to be the extra amount by which the beam is bent initially.  "
}], "Text",
 CellChangeTimes->{{3.4370619522145*^9, 3.4370620035895*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"L", "=", "1.6"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Fit", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Beam", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", "2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["x", "2"]}], "}"}], ",", "x"}], "]"}]], "Input",
 CellChangeTimes->{
  3.43706202268325*^9, {3.437062061480125*^9, 3.437062068011375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "0.03410838629169443`"}], " ", "x"}], "-", 
  RowBox[{"0.08082295676851754`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.456061440171875*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"a", " ", "x"}], "-", 
   RowBox[{"b", " ", 
    SuperscriptBox["x", "2"]}]}]}]], "Input",
 CellChangeTimes->{{3.43706209024575*^9, 3.437062103167625*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"-", "0.0341084"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "=", "0.0808230"}], ";"}]}], "Input",
 CellChangeTimes->{{3.43706210949575*^9, 3.437062172542625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.437062179792625*^9, 3.437062180511375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "0.0341084`"}], " ", "x"}], "-", 
  RowBox[{"0.080823`", " ", 
   SuperscriptBox["x", "2"]}]}]], "Output",
 CellChangeTimes->{3.45606144025*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"h", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], "-", 
   RowBox[{"v", "[", "x", "]"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.43706220218325*^9, 3.43706220312075*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "0.0341084`"}], " ", "x"}], "-", 
  RowBox[{"0.080823`", " ", 
   SuperscriptBox["x", "2"]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "15.360000000000003`"}], " ", "g", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"6.4`", " ", "g", " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"g", " ", 
     SuperscriptBox["x", "4"]}]}], 
   RowBox[{"24", " ", 
    SuperscriptBox["c", "2"]}]]}]], "Output",
 CellChangeTimes->{3.4560614403125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Construct Model", "Subsection"],

Cell[CellGroupData[{

Cell["Solve for the alpha values", "Subsubsection"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"alpha", ",", "\[Alpha]"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"alpha", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"\[Alpha]", "/.", 
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"\[Alpha]", "*", "L"}], "]"}], " ", "+", 
         FractionBox["1", 
          RowBox[{" ", 
           RowBox[{"Cosh", "[", 
            RowBox[{"\[Alpha]", "*", "L"}], "]"}], " "}]]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Alpha]", ",", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "n"}], "+", "1"}], ")"}], "\[Pi]"}], 
           RowBox[{"2", "L"}]]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "7"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Alpha]", "=", "alpha"}], ";"}]}], "Input",
 CellChangeTimes->{{3.437063949605125*^9, 3.437063954073875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Define position functions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["X", "n"], "(", 
    RowBox[{"x", ",", "t"}], ")"}], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"X", "[", 
   RowBox[{"x_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", 
      RowBox[{"[", "n", "]"}], "]"}], "*", "x"}], "]"}], "-", 
   RowBox[{"Cosh", "[", 
    RowBox[{
     RowBox[{"\[Alpha]", "[", 
      RowBox[{"[", "n", "]"}], "]"}], "*", "x"}], "]"}], "-", 
   RowBox[{
    FractionBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cosh", "[", 
        RowBox[{
         RowBox[{"\[Alpha]", "[", 
          RowBox[{"[", "n", "]"}], "]"}], "*", "L"}], "]"}], "+", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"\[Alpha]", "[", 
          RowBox[{"[", "n", "]"}], "]"}], "*", "L"}], "]"}]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sinh", "[", 
        RowBox[{
         RowBox[{"\[Alpha]", "[", 
          RowBox[{"[", "n", "]"}], "]"}], "*", "L"}], "]"}], "+", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"\[Alpha]", "[", 
          RowBox[{"[", "n", "]"}], "]"}], "*", "L"}], "]"}]}], ")"}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", "[", 
         RowBox[{"[", "n", "]"}], "]"}], "*", "x"}], "]"}], "-", 
      RowBox[{"Sinh", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", "[", 
         RowBox[{"[", "n", "]"}], "]"}], "*", "x"}], "]"}]}], 
     ")"}]}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Define the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "n"], TraditionalForm]]],
 " Coefficients - for the Manipulate command to work, the coefficients ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "n"], TraditionalForm]]],
 " have been found explicitly, which can be done with our choice of f(x)!"
}], "Subsubsection",
 CellChangeTimes->{{3.43706223149575*^9, 3.437062294698875*^9}, {
  3.437062701323875*^9, 3.4370627050895*^9}, {3.437063803698875*^9, 
  3.437063822948875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"A", ",", "AN"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"A", "[", "n_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{"L", " ", 
         RowBox[{
         "\[Alpha]", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}],
         "]"}], "+", 
       RowBox[{"Sinh", "[", 
        RowBox[{"L", " ", 
         RowBox[{
         "\[Alpha]", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}],
         "]"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], " ", "g", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"L", " ", 
          RowBox[{
          "\[Alpha]", "\[LeftDoubleBracket]", "n", 
           "\[RightDoubleBracket]"}]}], "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["c", "2"], " ", "L", " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", 
          RowBox[{"b", " ", "L"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
         "\[Alpha]", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
         "4"]}], "+", 
       RowBox[{"g", " ", 
        RowBox[{"(", 
         RowBox[{"8", "+", 
          RowBox[{
           SuperscriptBox["L", "4"], " ", 
           SuperscriptBox[
            RowBox[{
            "\[Alpha]", "\[LeftDoubleBracket]", "n", 
             "\[RightDoubleBracket]"}], "4"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Cosh", "[", 
         RowBox[{"L", " ", 
          RowBox[{
          "\[Alpha]", "\[LeftDoubleBracket]", "n", 
           "\[RightDoubleBracket]"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "8"}], " ", "g"}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"L", " ", 
             RowBox[{
             "\[Alpha]", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", 
              SuperscriptBox["c", "2"], " ", "L", " ", 
              RowBox[{"(", 
               RowBox[{"a", "-", 
                RowBox[{"b", " ", "L"}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{
               "\[Alpha]", "\[LeftDoubleBracket]", "n", 
                "\[RightDoubleBracket]"}], "4"]}], "+", 
             RowBox[{"g", " ", 
              RowBox[{"(", 
               RowBox[{"8", "+", 
                RowBox[{
                 SuperscriptBox["L", "4"], " ", 
                 SuperscriptBox[
                  RowBox[{
                  "\[Alpha]", "\[LeftDoubleBracket]", "n", 
                   "\[RightDoubleBracket]"}], "4"]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["c", "2"], " ", 
        SuperscriptBox[
         RowBox[{
         "\[Alpha]", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
         "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", 
           RowBox[{
           "\[Alpha]", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
            " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"L", " ", 
             RowBox[{
             "\[Alpha]", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", " ", 
              RowBox[{
              "\[Alpha]", "\[LeftDoubleBracket]", "n", 
               "\[RightDoubleBracket]"}]}], "-", 
             RowBox[{"2", " ", "b", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"L", " ", 
                RowBox[{
                "\[Alpha]", "\[LeftDoubleBracket]", "n", 
                 "\[RightDoubleBracket]"}]}], "]"}]}]}], ")"}], " ", 
           RowBox[{"Sinh", "[", 
            RowBox[{"L", " ", 
             RowBox[{
             "\[Alpha]", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], "]"}]}]}], ")"}]}]}], ")"}]}], 
    ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox[
      RowBox[{
      "\[Alpha]", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}], 
      "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "L"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "L", " ", 
          RowBox[{
          "\[Alpha]", "\[LeftDoubleBracket]", "n", 
           "\[RightDoubleBracket]"}]}], "]"}], " ", 
        RowBox[{
        "\[Alpha]", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
       "+", 
       RowBox[{"L", " ", 
        RowBox[{"Cosh", "[", 
         RowBox[{"2", " ", "L", " ", 
          RowBox[{
          "\[Alpha]", "\[LeftDoubleBracket]", "n", 
           "\[RightDoubleBracket]"}]}], "]"}], " ", 
        RowBox[{
        "\[Alpha]", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}]}], 
       "-", 
       RowBox[{"6", " ", 
        RowBox[{"Cosh", "[", 
         RowBox[{"L", " ", 
          RowBox[{
          "\[Alpha]", "\[LeftDoubleBracket]", "n", 
           "\[RightDoubleBracket]"}]}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"L", " ", 
          RowBox[{
          "\[Alpha]", "\[LeftDoubleBracket]", "n", 
           "\[RightDoubleBracket]"}]}], "]"}]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"Cosh", "[", 
          RowBox[{"L", " ", 
           RowBox[{
           "\[Alpha]", "\[LeftDoubleBracket]", "n", 
            "\[RightDoubleBracket]"}]}], "]"}], "2"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "L", " ", 
          RowBox[{
          "\[Alpha]", "\[LeftDoubleBracket]", "n", 
           "\[RightDoubleBracket]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"L", " ", 
             RowBox[{
             "\[Alpha]", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], "]"}]}], "+", 
          RowBox[{"4", " ", "L", " ", 
           RowBox[{
           "\[Alpha]", "\[LeftDoubleBracket]", "n", "\[RightDoubleBracket]"}],
            " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"L", " ", 
             RowBox[{
             "\[Alpha]", "\[LeftDoubleBracket]", "n", 
              "\[RightDoubleBracket]"}]}], "]"}]}]}], ")"}], " ", 
        RowBox[{"Sinh", "[", 
         RowBox[{"L", " ", 
          RowBox[{
          "\[Alpha]", "\[LeftDoubleBracket]", "n", 
           "\[RightDoubleBracket]"}]}], "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"L", " ", 
           RowBox[{
           "\[Alpha]", "\[LeftDoubleBracket]", "n", 
            "\[RightDoubleBracket]"}]}], "]"}], "2"], " ", 
        RowBox[{"Sinh", "[", 
         RowBox[{"2", " ", "L", " ", 
          RowBox[{
          "\[Alpha]", "\[LeftDoubleBracket]", "n", 
           "\[RightDoubleBracket]"}]}], "]"}]}]}], ")"}]}], ")"}]}]}], "\n", 
 RowBox[{
  RowBox[{"AN", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"A", "[", "n", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "7"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.437062492042625*^9, 3.43706249580825*^9}, {
  3.437063340823875*^9, 3.43706334687075*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Define the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["B", "n"], TraditionalForm]]],
 " Coefficients"
}], "Subsubsection",
 CellChangeTimes->{{3.4370623235895*^9, 3.437062324011375*^9}, {
  3.437062710417625*^9, 3.4370627133395*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"\[Mu]", ",", "B", ",", "BN"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]", "[", "n_", "]"}], ":=", 
   RowBox[{
    FractionBox["1", "2"], 
    SqrtBox[
     RowBox[{
      RowBox[{"4", 
       SuperscriptBox["c", "2"], 
       SuperscriptBox[
        RowBox[{"\[Alpha]", "[", 
         RowBox[{"[", "n", "]"}], "]"}], "4"]}], "-", 
      SuperscriptBox["k", "2"]}]]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"B", "[", "n_", "]"}], ":=", 
   FractionBox[
    RowBox[{"k", " ", 
     RowBox[{"AN", "[", 
      RowBox[{"[", "n", "]"}], "]"}]}], 
    RowBox[{"2", 
     RowBox[{"\[Mu]", "[", "n", "]"}]}]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"BN", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"B", "[", "n", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "7"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4370625678395*^9, 3.4370626065895*^9}, {
  3.437062722417625*^9, 3.437062728605125*^9}, {3.43706388380825*^9, 
  3.43706388449575*^9}, {3.437064003730125*^9, 3.43706400424575*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Define time functions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["T", "n"], "(", 
    RowBox[{"x", ",", "t"}], ")"}], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"t_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"AN", "[", 
        RowBox[{"[", "n", "]"}], "]"}], 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"\[Mu]", "[", "n", "]"}], " ", "t"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"BN", "[", 
        RowBox[{"[", "n", "]"}], "]"}], 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"\[Mu]", "[", "n", "]"}], " ", "t"}], "]"}]}]}], ")"}], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "k", " ", "t"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4370626585895*^9, 3.437062669448875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Define model ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", 
     RowBox[{"x", ",", "t"}], ")"}], "=", 
    RowBox[{
     RowBox[{"v", "(", "x", ")"}], "+", 
     RowBox[{"\[Sum]", 
      RowBox[{
       RowBox[{
        SubscriptBox["X", "n"], "(", 
        RowBox[{"x", ",", "t"}], ")"}], 
       RowBox[{
        SubscriptBox["T", "n"], "(", 
        RowBox[{"x", ",", "t"}], ")"}]}]}]}]}], TraditionalForm]]]
}], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"y", "[", 
   RowBox[{"x_", ",", "t_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"v", "[", "x", "]"}], "+", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"X", "[", 
       RowBox[{"x", ",", "n"}], "]"}], 
      RowBox[{"T", "[", 
       RowBox[{"t", ",", "n"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "1", ",", "7"}], "}"}]}], "]"}]}]}]], "Input"],

Cell["Check to make sure our model is a function of c, k, and g:", "Text",
 CellChangeTimes->{{3.437063686448875*^9, 3.437063702511375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"y", "[", 
  RowBox[{"x", ",", "t"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "15.360000000000003`"}], " ", "g", " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{"6.4`", " ", "g", " ", 
     SuperscriptBox["x", "3"]}], "-", 
    RowBox[{"g", " ", 
     SuperscriptBox["x", "4"]}]}], 
   RowBox[{"24", " ", 
    SuperscriptBox["c", "2"]}]], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"k", " ", "t"}], "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"0.01708002532301344`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3.2669394535721263`", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"22.759425728692335`", " ", "g"}], "+", 
         RowBox[{"3.3374183885553954`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"0.29963279504576884`", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3.945940831916758`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"20.362363368326186`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"7.5453877980506485`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      SuperscriptBox["c", "2"]], "+", 
     FractionBox[
      RowBox[{"0.01708002532301344`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3.2669394535721263`", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"22.759425728692335`", " ", "g"}], "+", 
         RowBox[{"3.3374183885553954`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"0.29963279504576884`", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3.945940831916758`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"20.362363368326186`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", "k", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"7.5453877980506485`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"7.5453877980506485`", " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SuperscriptBox["k", "2"]}]]}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"1.1719400429449756`", " ", "x"}], "]"}], "-", 
     RowBox[{"Cosh", "[", 
      RowBox[{"1.1719400429449756`", " ", "x"}], "]"}], "-", 
     RowBox[{"0.7340955137589129`", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"1.1719400429449756`", " ", "x"}], "]"}], "-", 
        RowBox[{"Sinh", "[", 
         RowBox[{"1.1719400429449756`", " ", "x"}], "]"}]}], ")"}]}]}], 
    ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"k", " ", "t"}], "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"0.000013400797174164186`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "393.4643563613987`"}], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"493.66519312435884`", " ", "g"}], "+", 
         RowBox[{"54.654287010560694`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"0.01829682637350656`", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "154.9726758189674`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"493.5188185133708`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"296.3371695027897`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      SuperscriptBox["c", "2"]], "+", 
     FractionBox[
      RowBox[{"0.000013400797174164186`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "393.4643563613987`"}], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"493.66519312435884`", " ", "g"}], "+", 
         RowBox[{"54.654287010560694`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"0.01829682637350656`", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "154.9726758189674`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"493.5188185133708`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", "k", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"296.3371695027897`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"296.3371695027897`", " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SuperscriptBox["k", "2"]}]]}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"2.9338069581088586`", " ", "x"}], "]"}], "-", 
     RowBox[{"Cosh", "[", 
      RowBox[{"2.9338069581088586`", " ", "x"}], "]"}], "-", 
     RowBox[{"1.0184673187592193`", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"2.9338069581088586`", " ", "x"}], "]"}], "-", 
        RowBox[{"Sinh", "[", 
         RowBox[{"2.9338069581088586`", " ", "x"}], "]"}]}], ")"}]}]}], 
    ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"k", " ", "t"}], "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"4.247872768789749`*^-8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"80603.51788464916`", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"3814.5524728249343`", " ", "g"}], "+", 
         RowBox[{"1288.9850543978853`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"0.0007758041853070283`", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1215.010907996633`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"3814.546266391452`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"2323.3314614205633`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      SuperscriptBox["c", "2"]], "+", 
     FractionBox[
      RowBox[{"4.247872768789749`*^-8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"80603.51788464916`", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"3814.5524728249343`", " ", "g"}], "+", 
         RowBox[{"1288.9850543978853`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"0.0007758041853070283`", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "1215.010907996633`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"3814.546266391452`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", "k", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"2323.3314614205633`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"2323.3314614205633`", " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SuperscriptBox["k", "2"]}]]}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"4.909223398898508`", " ", "x"}], "]"}], "-", 
     RowBox[{"Cosh", "[", 
      RowBox[{"4.909223398898508`", " ", "x"}], "]"}], "-", 
     RowBox[{"0.9992244965174283`", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"4.909223398898508`", " ", "x"}], "]"}], "-", 
        RowBox[{"Sinh", "[", 
         RowBox[{"4.909223398898508`", " ", "x"}], "]"}]}], ")"}]}]}], 
    ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"k", " ", "t"}], "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"3.420415622308074`*^-10", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"814490.9016531678`", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"14625.27357354029`", " ", "g"}], "+", 
         RowBox[{"29803.87073804782`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"0.00003355268880280212`", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4665.685182311908`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"14625.273305118779`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"8921.675601268784`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      SuperscriptBox["c", "2"]], "+", 
     FractionBox[
      RowBox[{"3.420415622308074`*^-10", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"814490.9016531678`", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"14625.27357354029`", " ", "g"}], "+", 
         RowBox[{"29803.87073804782`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"0.00003355268880280212`", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "4665.685182311908`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"14625.273305118779`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", "k", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"8921.675601268784`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"8921.675601268784`", " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SuperscriptBox["k", "2"]}]]}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"6.872212959297166`", " ", "x"}], "]"}], "-", 
     RowBox[{"Cosh", "[", 
      RowBox[{"6.872212959297166`", " ", "x"}], "]"}], "-", 
     RowBox[{"1.0000335532517133`", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"6.872212959297166`", " ", "x"}], "]"}], "-", 
        RowBox[{"Sinh", "[", 
         RowBox[{"6.872212959297166`", " ", "x"}], "]"}]}], ")"}]}]}], 
    ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"k", " ", "t"}], "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"4.2067134326351754`*^-12", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1.9943905833542854`*^8", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"39951.831790108605`", " ", "g"}], "+", 
         RowBox[{"689706.3529026293`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"1.4498924011432159`*^-6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "12749.665424158717`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"39951.83177850946`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"24379.7801382504`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      SuperscriptBox["c", "2"]], "+", 
     FractionBox[
      RowBox[{"4.2067134326351754`*^-12", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1.9943905833542854`*^8", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"39951.831790108605`", " ", "g"}], "+", 
         RowBox[{"689706.3529026293`", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"1.4498924011432159`*^-6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "12749.665424158717`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"39951.83177850946`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", "k", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"24379.7801382504`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"24379.7801382504`", " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SuperscriptBox["k", "2"]}]]}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"8.835730244404044`", " ", "x"}], "]"}], "-", 
     RowBox[{"Cosh", "[", 
      RowBox[{"8.835730244404044`", " ", "x"}], "]"}], "-", 
     RowBox[{"0.9999985501086501`", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"8.835730244404044`", " ", "x"}], "]"}], "-", 
        RowBox[{"Sinh", "[", 
         RowBox[{"8.835730244404044`", " ", "x"}], "]"}]}], ")"}]}]}], 
    ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"k", " ", "t"}], "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"6.66526222604041`*^-14", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3.0778528843483596`*^9", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"89143.40507192448`", " ", "g"}], "+", 
         RowBox[{"1.5960258578710688`*^7", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"6.265562536207914`*^-8", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "28451.116017340537`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"89143.40507142324`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"54403.933759413594`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      SuperscriptBox["c", "2"]], "+", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"54403.933759413594`", " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["k", "2"]}]]}]], 
      RowBox[{"6.66526222604041`*^-14", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3.0778528843483596`*^9", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"89143.40507192448`", " ", "g"}], "+", 
         RowBox[{"1.5960258578710688`*^7", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"6.265562536207914`*^-8", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "28451.116017340537`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"89143.40507142324`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", "k", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"54403.933759413594`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"10.799224707555148`", " ", "x"}], "]"}], "-", 
     RowBox[{"Cosh", "[", 
      RowBox[{"10.799224707555148`", " ", "x"}], "]"}], "-", 
     RowBox[{"1.0000000626556285`", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"10.799224707555148`", " ", "x"}], "]"}], "-", 
        RowBox[{"Sinh", "[", 
         RowBox[{"10.799224707555148`", " ", "x"}], "]"}]}], ")"}]}]}], 
    ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"k", " ", "t"}], "2"]}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"1.2493596788763664`*^-15", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2.873024725494401`*^11", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"173889.31565612732`", " ", "g"}], "+", 
         RowBox[{"3.693314622503152`*^8", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"2.707595129250147`*^-9", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "55501.14997531679`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"173889.31565610567`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"106128.73270025979`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}], 
      SuperscriptBox["c", "2"]], "+", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["c", "2"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"106128.73270025979`", " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["k", "2"]}]]}]], 
      RowBox[{"1.2493596788763664`*^-15", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2.873024725494401`*^11", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"173889.31565612732`", " ", "g"}], "+", 
         RowBox[{"3.693314622503152`*^8", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "8"}], " ", "g"}], "-", 
            RowBox[{"2.707595129250147`*^-9", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "55501.14997531679`"}], " ", 
                SuperscriptBox["c", "2"]}], "+", 
               RowBox[{"173889.31565610567`", " ", "g"}]}], ")"}]}]}], 
           ")"}]}]}], ")"}], " ", "k", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"106128.73270025979`", " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["k", "2"]}]], " ", "t"}], "]"}]}]}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"12.76272015690078`", " ", "x"}], "]"}], "-", 
     RowBox[{"Cosh", "[", 
      RowBox[{"12.76272015690078`", " ", "x"}], "]"}], "-", 
     RowBox[{"0.9999999972924051`", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"12.76272015690078`", " ", "x"}], "]"}], "-", 
        RowBox[{"Sinh", "[", 
         RowBox[{"12.76272015690078`", " ", "x"}], "]"}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.4560614404375*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Finding c, k, and g via the Manipulate command - Figures 3, 4, 5, and 6 in \
the paper are found this way!\
\>", "Subsection",
 CellChangeTimes->{{3.43706292224575*^9, 3.437062935917625*^9}, {
  3.43706354518325*^9, 3.437063569277*^9}, {3.437063669323875*^9, 
  3.437063671167625*^9}}],

Cell["\<\
Since beam isn't moving until the fourth set of data points, drop the first \
four sets of data points.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Beam", "=", 
   RowBox[{"Drop", "[", 
    RowBox[{"Beam", ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"Beam", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "Beam", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.43540529842275*^9, 3.435405305250875*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"c", ",", "k", ",", "g"}], "]"}]], "Input",
 CellChangeTimes->{{3.4354859578101406`*^9, 3.435485962044515*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           FractionBox[
            RowBox[{"j", "-", "1"}], "30"], ",", 
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "15", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "1", ",", 
           RowBox[{"Length", "[", "Beam", "]"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
          RowBox[{"RGBColor", "[", 
           RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "0.3"}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<t\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], ",", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox[
             RowBox[{"j", "-", "1"}], "30"], ",", 
            RowBox[{"Evaluate", "[", 
             RowBox[{"y", "[", 
              RowBox[{
               RowBox[{"data", "[", 
                RowBox[{"[", 
                 RowBox[{"j", ",", "15", ",", "1"}], "]"}], "]"}], ",", 
               FractionBox[
                RowBox[{"j", "-", "1"}], "30"]}], "]"}], "]"}]}], "}"}], ",", 
          
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", 
            RowBox[{"Length", "[", "Beam", "]"}]}], "}"}]}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"c", "\[Rule]", "\[Chi]1"}], ",", 
          RowBox[{"k", "\[Rule]", "\[Chi]2"}], ",", 
          RowBox[{"g", "\[Rule]", "\[Chi]3"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3`"}], ",", "0.3`"}], "}"}]}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Chi]1", ",", "1", ",", "\"\<c\>\""}], "}"}], ",", "1", ",", 
     "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Chi]2", ",", "0", ",", "\"\<k\>\""}], "}"}], ",", "0", ",", 
     "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Chi]3", ",", "0", ",", "\"\<g\>\""}], "}"}], ",", "0", ",", 
     "10"}], "}"}], ",", 
   RowBox[{"TrackedSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\[Chi]1", ",", "\[Chi]2", ",", "\[Chi]3"}], "}"}]}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4354864044351406`*^9, 3.4354864282788906`*^9}, {
  3.4354864850913906`*^9, 3.435486515794515*^9}, {3.435490096607015*^9, 
  3.4354901177788906`*^9}, {3.435490271357015*^9, 3.435490285450765*^9}, {
  3.4559613393918753`*^9, 3.4559613513293753`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`\[Chi]1$$ = 12.87, $CellContext`\[Chi]2$$ = 
    0.94, $CellContext`\[Chi]3$$ = 9.8, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`\[Chi]1$$], 1, "c"}, 1, 15}, {{
       Hold[$CellContext`\[Chi]2$$], 0, "k"}, 0, 4}, {{
       Hold[$CellContext`\[Chi]3$$], 0, "g"}, 0, 10}}, Typeset`size$$ = {
    360., {113., 117.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`\[Chi]1$166$$ = 
    0, $CellContext`\[Chi]2$171$$ = 0, $CellContext`\[Chi]3$172$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`\[Chi]1$$ = 1, $CellContext`\[Chi]2$$ = 
        0, $CellContext`\[Chi]3$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`\[Chi]1$$, $CellContext`\[Chi]1$166$$, 0], 
        Hold[$CellContext`\[Chi]2$$, $CellContext`\[Chi]2$171$$, 0], 
        Hold[$CellContext`\[Chi]3$$, $CellContext`\[Chi]3$172$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        ListPlot[
         Table[{($CellContext`j - 1)/30, 
           Part[$CellContext`data, $CellContext`j, 15, 2]}, {$CellContext`j, 
           1, 
           Length[$CellContext`Beam]}], PlotStyle -> {
           PointSize[0.02], 
           RGBColor[0, 0, 1]}, PlotRange -> {-0.3, 0.3}, 
         AxesLabel -> {"t", "y"}], 
        ListPlot[
         ReplaceAll[
          Table[{($CellContext`j - 1)/30, 
            Evaluate[
             $CellContext`y[
              
              Part[$CellContext`data, $CellContext`j, 15, 1], ($CellContext`j - 
               1)/30]]}, {$CellContext`j, 1, 
            
            Length[$CellContext`Beam]}], {$CellContext`c -> $CellContext`\
\[Chi]1$$, $CellContext`k -> $CellContext`\[Chi]2$$, $CellContext`g -> \
$CellContext`\[Chi]3$$}], PlotStyle -> RGBColor[1, 0, 0], 
         PlotRange -> {-0.3, 0.3}, Joined -> True]], 
      "Specifications" :> {{{$CellContext`\[Chi]1$$, 1, "c"}, 1, 
         15}, {{$CellContext`\[Chi]2$$, 0, "k"}, 0, 
         4}, {{$CellContext`\[Chi]3$$, 0, "g"}, 0, 10}}, 
      "Options" :> {
       TrackedSymbols -> {$CellContext`\[Chi]1$$, $CellContext`\[Chi]2$$, \
$CellContext`\[Chi]3$$}}, "DefaultOptions" :> {}],
     ImageSizeCache->{406., {234., 239.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`data = {{{0.00448, 0}, {0.1074148, 0}, {
          0.2193052, -0.00895}, {0.3446226, -0.0179}, {0.4430861, -0.0269}, {
          0.5549766, -0.0403}, {0.6713426, -0.0582}, {
          0.7877086, -0.0805611}, {0.8995991, -0.094}, {
          1.020441, -0.1208416}, {1.12338, -0.1432197}, {
          1.23527, -0.1700734}, {1.347161, -0.1924515}, {
          1.459051, -0.2148296}, {1.570942, -0.2372077}}, {{0.00448, 0}, {
          0.1074148, 0}, {0.2193052, -0.00895}, {0.3446226, -0.0134}, {
          0.4430861, -0.0269}, {0.5594522, -0.0358}, {0.6713426, -0.0492}, {
          0.7877086, -0.0761}, {0.8995991, -0.0895}, {1.015965, -0.0985}, {
          1.127856, -0.1253173}, {1.239746, -0.1476954}, {
          1.351636, -0.1655978}, {1.463527, -0.1879759}, {
          1.579893, -0.1969271}}, {{0.00448, 0}, {0.1074148, 0}, {
          0.2193052, 0}, {0.3446226, -0.00895}, {0.4475617, -0.0179}, {
          0.5594522, -0.0179}, {0.6758182, -0.0313}, {0.7877086, -0.0448}, {
          0.8995991, -0.0492}, {1.020441, -0.0627}, {1.136807, -0.0716}, {
          1.248697, -0.0895}, {1.360588, -0.0985}, {1.459051, -0.116366}, {
          1.584369, -0.1253173}}, {{0.00448, 0}, {0.1074148, 0}, {
          0.2193052, 0}, {0.3401469, 0}, {0.4475617, -0.00448}, {
          0.5594522, -0.00448}, {0.6758182, -0.00895}, {
          0.7877086, -0.00895}, {0.9040747, -0.0134}, {1.024916, -0.00895}, {
          1.136807, -0.0134}, {1.253173, -0.0224}, {1.369539, -0.0269}, {
          1.463527, -0.0224}, {1.597795, -0.0313}}, {{0.00448, 0}, {
          0.1074148, 0}, {0.2237809, 0.00448}, {0.3446226, 0.00448}, {
          0.4430861, 0.00448}, {0.5594522, 0.00895}, {0.6713426, 0.00895}, {
          0.7921843, 0.0179}, {0.9040747, 0.0224}, {1.024916, 0.0269}, {
          1.136807, 0.0313}, {1.253173, 0.0403}, {1.369539, 0.0448}, {
          1.463527, 0.0492}, {1.597795, 0.0627}}, {{0.00448, 0}, {0.1074148, 
          0.00448}, {0.2282565, 0.00895}, {0.3446226, 0.00895}, {0.4475617, 
          0.0179}, {0.5594522, 0.0224}, {0.6758182, 0.0313}, {0.7877086, 
          0.0358}, {0.9040747, 0.0403}, {1.020441, 0.0537}, {1.141282, 
          0.0627}, {1.248697, 0.0716}, {1.369539, 0.0806}, {1.468003, 
          0.085}, {1.59332, 0.0985}}, {{0.00448, 0}, {0.1074148, 0}, {
          0.2282565, 0.00448}, {0.3490981, 0.00448}, {0.4520373, 0.00895}, {
          0.5594522, 0.0134269}, {0.6758182, 0.0134269}, {0.7921843, 
          0.0269}, {0.9040747, 0.0313}, {1.020441, 0.0448}, {1.136807, 
          0.0492}, {1.253173, 0.0537}, {1.369539, 0.0627}, {1.472478, 
          0.0761}, {1.59332, 0.0806}}, {{0, 0}, {0.1074148, 0}, {
          0.2282565, 0}, {0.3490981, 0.00448}, {0.4520373, 0}, {0.5639278, 
          0.00448}, {0.6758182, 0.00895}, {0.7921843, 0.00895}, {0.9040747, 
          0.00895}, {1.020441, 0.0134269}, {1.136807, 0.00895}, {1.253173, 
          0.00895}, {1.369539, 0.0179}, {1.476954, 0.0134269}, {1.59332, 
          0.0179}}, {{0, 0}, {0.1074148, 0}, {0.2327321, -0.00448}, {
          0.3490981, -0.00448}, {0.4520373, -0.0134}, {0.5594522, -0.00895}, {
          0.6713426, -0.0134}, {0.7921843, -0.0269}, {0.9040747, -0.0358}, {
          1.024916, -0.0358}, {1.132331, -0.0403}, {1.248697, -0.0492}, {
          1.369539, -0.0537}, {1.472478, -0.0627}, {1.588844, -0.0671}}, {{0, 
          0}, {0.1074148, 0}, {0.2327321, -0.00895}, {0.3490981, -0.0134}, {
          0.4520373, -0.0224}, {0.5594522, -0.0269}, {0.6758182, -0.0403}, {
          0.7877086, -0.0537}, {0.8995991, -0.0716}, {1.020441, -0.0761}, {
          1.132331, -0.094}, {1.248697, -0.1029392}, {1.360588, -0.1253173}, {
          1.468003, -0.1297929}, {1.584369, -0.1476954}}, {{0, 0}, {
          0.1074148, 0}, {0.2282565, -0.0134}, {0.3490981, -0.0179}, {
          0.4520373, -0.0269}, {0.5594522, -0.0403}, {0.6713426, -0.0492}, {
          0.7877086, -0.0716}, {0.8995991, -0.094}, {1.015965, -0.1029392}, {
          1.118904, -0.1253173}, {1.244222, -0.1432197}, {
          1.356112, -0.1700734}, {1.463527, -0.1879759}, {
          1.575417, -0.2058784}}, {{0, 0}, {0.1074148, 0}, {
          0.2327321, -0.00895}, {0.3490981, -0.0224}, {0.4520373, -0.0358}, {
          0.5594522, -0.0403}, {0.6713426, -0.0582}, {0.7877086, -0.0761}, {
          0.8995991, -0.094}, {1.015965, -0.1118904}, {
          1.127856, -0.1387441}, {1.244222, -0.1566466}, {
          1.356112, -0.174549}, {1.463527, -0.1969271}, {
          1.570942, -0.2058784}}, {{0, 0}, {0.1074148, 0}, {
          0.2327321, -0.00895}, {0.3490981, -0.0134}, {0.4520373, -0.0224}, {
          0.5594522, -0.0269}, {0.6713426, -0.0403}, {0.7877086, -0.0582}, {
          0.9040747, -0.0716}, {1.020441, -0.0895}, {1.127856, -0.1029392}, {
          1.248697, -0.1253173}, {1.360588, -0.1387441}, {
          1.463527, -0.1611222}, {1.570942, -0.1700734}}, {{0, 0}, {
          0.1074148, 0}, {0.2372077, -0.00448}, {0.3490981, -0.00895}, {
          0.4520373, -0.0179}, {0.5594522, -0.0179}, {0.6758182, -0.0224}, {
          0.7877086, -0.0358}, {0.8995991, -0.0403}, {1.020441, -0.0448}, {
          1.132331, -0.0582}, {1.248697, -0.0671}, {1.369539, -0.0761}, {
          1.472478, -0.0895}, {1.575417, -0.0985}}, {{0, 0}, {0.1074148, 
          0.00448}, {0.2372077, 0}, {0.3490981, 0}, {0.4520373, 0}, {
          0.5549766, 0}, {0.6758182, -0.00448}, {0.7877086, -0.00895}, {
          0.8995991, -0.00448}, {1.020441, -0.00448}, {1.136807, -0.00895}, {
          1.248697, -0.0134}, {1.369539, -0.00448}, {1.472478, -0.0224}, {
          1.584369, -0.0134}}, {{0, 0}, {0.1074148, 0.00448}, {0.2372077, 
          0.00895}, {0.3490981, 0.00448}, {0.456513, 0.00895}, {0.5594522, 
          0.00895}, {0.6758182, 0.0134269}, {0.7921843, 0.0179}, {0.8995991, 
          0.0269}, {1.024916, 0.0313}, {1.136807, 0.0313}, {1.248697, 
          0.0403}, {1.374014, 0.0403}, {1.472478, 0.0448}, {1.588844, 
          0.0582}}, {{0, 0}, {0.1074148, 0}, {0.2372077, 0.00895}, {0.3490981,
           0.00895}, {0.456513, 0.00895}, {0.5594522, 0.0179}, {0.6758182, 
          0.0224}, {0.7877086, 0.0269}, {0.9040747, 0.0313}, {1.024916, 
          0.0448}, {1.136807, 0.0492}, {1.248697, 0.0582}, {1.374014, 
          0.0671}, {1.481429, 0.0716}, {1.588844, 0.0806}}, {{0, 0}, {
          0.1074148, 0}, {0.2416833, 0}, {0.3535738, 0.00448}, {0.456513, 
          0.00895}, {0.5594522, 0.0134269}, {0.6758182, 0.0179}, {0.7877086, 
          0.0179}, {0.8995991, 0.0224}, {1.020441, 0.0269}, {1.136807, 
          0.0358}, {1.253173, 0.0403}, {1.365063, 0.0448}, {1.485905, 
          0.0492}, {1.59332, 0.0582}}, {{0, 0}, {0.1074148, 0}, {
          0.2416833, 0}, {0.3535738, 0}, {0.456513, -0.00448}, {
          0.5594522, 0}, {0.6758182, -0.00895}, {0.7877086, -0.00448}, {
          0.8995991, -0.00448}, {1.020441, 0}, {1.132331, 0}, {
          1.248697, -0.00448}, {1.360588, 0}, {1.481429, -0.00448}, {
          1.588844, -0.00895}}, {{0, 0}, {0.1029392, 0}, {
          0.2416833, -0.00448}, {0.3535738, -0.00895}, {0.456513, -0.0179}, {
          0.5594522, -0.0134}, {0.6758182, -0.0224}, {0.7877086, -0.0313}, {
          0.8951235, -0.0358}, {1.020441, -0.0403}, {1.132331, -0.0537}, {
          1.244222, -0.0582}, {1.369539, -0.0627}, {1.476954, -0.0716}, {
          1.584369, -0.0761}}, {{0, 0}, {0.1074148, 0}, {
          0.2416833, -0.00895}, {0.3535738, -0.0134}, {0.456513, -0.0224}, {
          0.5594522, -0.0269}, {0.6758182, -0.0403}, {0.7921843, -0.0537}, {
          0.8995991, -0.0671}, {1.020441, -0.0761}, {1.132331, -0.0985}, {
          1.248697, -0.1118904}, {1.360588, -0.1253173}, {
          1.472478, -0.1387441}, {1.579893, -0.152171}}, {{0, 0}, {
          0.1074148, 0}, {0.246159, -0.0134}, {0.3535738, -0.0179}, {
          0.4609886, -0.0269}, {0.5594522, -0.0358}, {0.6758182, -0.0537}, {
          0.7877086, -0.0671}, {0.8951235, -0.0850367}, {
          1.020441, -0.1029392}, {1.136807, -0.1253173}, {
          1.244222, -0.1387441}, {1.360588, -0.1566466}, {
          1.468003, -0.1835003}, {1.579893, -0.1969271}}, {{0, 0}, {
          0.1074148, 0}, {0.2416833, -0.0134}, {0.3535738, -0.0179}, {
          0.4609886, -0.0224}, {0.5594522, -0.0358}, {0.6802939, -0.0492}, {
          0.7877086, -0.0627}, {0.8951235, -0.0761}, {1.020441, -0.0985}, {
          1.132331, -0.1208416}, {1.244222, -0.1342685}, {
          1.356112, -0.1566466}, {1.468003, -0.174549}, {
          1.579893, -0.1879759}}, {{0, 0}, {0.0985, 0}, {
          0.246159, -0.00448}, {0.3580494, -0.00895}, {0.456513, -0.0224}, {
          0.5594522, -0.0269}, {0.6758182, -0.0403}, {0.783233, -0.0492}, {
          0.8951235, -0.0582}, {1.020441, -0.0761}, {1.136807, -0.094}, {
          1.244222, -0.1074148}, {1.360588, -0.116366}, {
          1.472478, -0.1342685}, {1.579893, -0.1432197}}, {{0, 0}, {
          0.0985, 0}, {0.246159, -0.00448}, {0.3535738, -0.00895}, {
          0.4654642, -0.0134}, {0.5639278, -0.0134}, {0.6758182, -0.0179}, {
          0.7877086, -0.0269}, {0.8951235, -0.0358}, {1.020441, -0.0448}, {
          1.136807, -0.0492}, {1.248697, -0.0537}, {1.365063, -0.0582}, {
          1.472478, -0.0761}, {1.584369, -0.0761}}, {{0, 0}, {0.1029392, 0}, {
          0.2506346, 0}, {0.3580494, 0}, {0.4609886, -0.00448}, {
          0.5639278, -0.00448}, {0.6758182, 0}, {0.7877086, -0.00448}, {
          0.8951235, 0}, {1.020441, 0}, {1.136807, -0.00448}, {
          1.248697, -0.00448}, {1.365063, -0.00448}, {1.472478, 0}, {
          1.584369, -0.00448}}, {{0, 0}, {0.1029392, 0}, {0.2506346, 
          0.00448}, {0.3580494, 0.00895}, {0.4609886, 0.00895}, {0.5594522, 
          0.00895}, {0.6758182, 0.0134269}, {0.7877086, 0.0134269}, {
          0.8951235, 0.0224}, {1.024916, 0.0269}, {1.141282, 0.0269}, {
          1.244222, 0.0358}, {1.365063, 0.0403}, {1.4769535, 0.0291}, {
          1.588844, 0.0537}}, {{0, 0}, {0.1029392, 0}, {0.246159, 0.00895}, {
          0.3580494, 0.00895}, {0.4609886, 0.0134269}, {0.5594522, 
          0.0134269}, {0.6758182, 0.0179}, {0.7921843, 0.0224}, {0.8995991, 
          0.0313}, {1.024916, 0.0313}, {1.145758, 0.0403}, {1.244222, 
          0.0492}, {1.369539, 0.0537}, {1.481429, 0.0582}, {1.584369, 
          0.0671}}, {{0, 0}, {0.1029392, 0}, {0.246159, 0}, {0.3580494, 
          0.00448}, {0.4609886, 0}, {0.5594522, 0.00448}, {0.6802939, 
          0.0134269}, {0.7921843, 0.00448}, {0.8995991, 0.0134269}, {1.024916,
           0.0134269}, {1.145758, 0.0224}, {1.248697, 0.0179}, {1.369539, 
          0.0269}, {1.481429, 0.0313}, {1.59332, 0.0358}}, {{0, 0}, {
          0.1029392, 0}, {0.2506346, 0}, {0.362525, 0}, {
          0.4609886, -0.00448}, {0.5594522, -0.00448}, {
          0.6758182, -0.00895}, {0.7921843, -0.00895}, {
          0.8995991, -0.00895}, {1.020441, -0.00895}, {1.145758, -0.0134}, {
          1.248697, -0.0134}, {1.365063, -0.0224}, {1.476954, -0.0269}, {
          1.59332, -0.0269}}, {{0, 0}, {0.1029392, 0}, {
          0.2416833, -0.00448}, {0.362525, -0.00895}, {0.456513, -0.0179}, {
          0.5594522, -0.0224}, {0.6802939, -0.0269}, {0.7921843, -0.0403}, {
          0.8995991, -0.0358}, {1.020441, -0.0448}, {1.141282, -0.0671}, {
          1.244222, -0.0716}, {1.360588, -0.0761}, {1.476954, -0.0895}, {
          1.588844, -0.1074148}}, {{0, -0.00448}, {0.1029392, 0}, {
          0.2416833, -0.00895}, {0.3670006, -0.0134}, {0.4609886, -0.0224}, {
          0.5594522, -0.0313}, {0.6758182, -0.0403}, {0.7921843, -0.0582}, {
          0.8995991, -0.0671}, {1.020441, -0.0850367}, {1.141282, -0.0985}, {
          1.253173, -0.1118904}, {1.360588, -0.1253173}, {
          1.476954, -0.1476954}, {1.584369, -0.1566466}}, {{0, -0.00448}, {
          0.0985, 0}, {0.2416833, -0.00448}, {0.362525, -0.0179}, {
          0.4520373, -0.0269}, {0.5594522, -0.0358}, {0.6802939, -0.0492}, {
          0.7877086, -0.0671}, {0.8995991, -0.0761}, {1.020441, -0.094}, {
          1.136807, -0.116366}, {1.244222, -0.1297929}, {
          1.356112, -0.152171}, {1.476954, -0.174549}, {
          1.579893, -0.1879759}}}, $CellContext`Beam = {{
         0.00448, 0, 0.1074148, 0, 0.2193052, -0.00895, 0.3446226, -0.0179, 
          0.4430861, -0.0269, 0.5549766, -0.0403, 0.6713426, -0.0582, 
          0.7877086, -0.0805611, 0.8995991, -0.094, 1.020441, -0.1208416, 
          1.12338, -0.1432197, 1.23527, -0.1700734, 1.347161, -0.1924515, 
          1.459051, -0.2148296, 1.570942, -0.2372077}, {
         0.00448, 0, 0.1074148, 0, 0.2193052, -0.00895, 0.3446226, -0.0134, 
          0.4430861, -0.0269, 0.5594522, -0.0358, 0.6713426, -0.0492, 
          0.7877086, -0.0761, 0.8995991, -0.0895, 1.015965, -0.0985, 
          1.127856, -0.1253173, 1.239746, -0.1476954, 1.351636, -0.1655978, 
          1.463527, -0.1879759, 1.579893, -0.1969271}, {
         0.00448, 0, 0.1074148, 0, 0.2193052, 0, 0.3446226, -0.00895, 
          0.4475617, -0.0179, 0.5594522, -0.0179, 0.6758182, -0.0313, 
          0.7877086, -0.0448, 0.8995991, -0.0492, 1.020441, -0.0627, 
          1.136807, -0.0716, 1.248697, -0.0895, 1.360588, -0.0985, 
          1.459051, -0.116366, 1.584369, -0.1253173}, {
         0.00448, 0, 0.1074148, 0, 0.2193052, 0, 0.3401469, 0, 
          0.4475617, -0.00448, 0.5594522, -0.00448, 0.6758182, -0.00895, 
          0.7877086, -0.00895, 0.9040747, -0.0134, 1.024916, -0.00895, 
          1.136807, -0.0134, 1.253173, -0.0224, 1.369539, -0.0269, 
          1.463527, -0.0224, 1.597795, -0.0313}, {
         0.00448, 0, 0.1074148, 0, 0.2237809, 0.00448, 0.3446226, 0.00448, 
          0.4430861, 0.00448, 0.5594522, 0.00895, 0.6713426, 0.00895, 
          0.7921843, 0.0179, 0.9040747, 0.0224, 1.024916, 0.0269, 1.136807, 
          0.0313, 1.253173, 0.0403, 1.369539, 0.0448, 1.463527, 0.0492, 
          1.597795, 0.0627}, {
         0.00448, 0, 0.1074148, 0.00448, 0.2282565, 0.00895, 0.3446226, 
          0.00895, 0.4475617, 0.0179, 0.5594522, 0.0224, 0.6758182, 0.0313, 
          0.7877086, 0.0358, 0.9040747, 0.0403, 1.020441, 0.0537, 1.141282, 
          0.0627, 1.248697, 0.0716, 1.369539, 0.0806, 1.468003, 0.085, 
          1.59332, 0.0985}, {
         0.00448, 0, 0.1074148, 0, 0.2282565, 0.00448, 0.3490981, 0.00448, 
          0.4520373, 0.00895, 0.5594522, 0.0134269, 0.6758182, 0.0134269, 
          0.7921843, 0.0269, 0.9040747, 0.0313, 1.020441, 0.0448, 1.136807, 
          0.0492, 1.253173, 0.0537, 1.369539, 0.0627, 1.472478, 0.0761, 
          1.59332, 0.0806}, {
         0, 0, 0.1074148, 0, 0.2282565, 0, 0.3490981, 0.00448, 0.4520373, 0, 
          0.5639278, 0.00448, 0.6758182, 0.00895, 0.7921843, 0.00895, 
          0.9040747, 0.00895, 1.020441, 0.0134269, 1.136807, 0.00895, 
          1.253173, 0.00895, 1.369539, 0.0179, 1.476954, 0.0134269, 1.59332, 
          0.0179}, {
         0, 0, 0.1074148, 0, 0.2327321, -0.00448, 0.3490981, -0.00448, 
          0.4520373, -0.0134, 0.5594522, -0.00895, 0.6713426, -0.0134, 
          0.7921843, -0.0269, 0.9040747, -0.0358, 1.024916, -0.0358, 
          1.132331, -0.0403, 1.248697, -0.0492, 1.369539, -0.0537, 
          1.472478, -0.0627, 1.588844, -0.0671}, {
         0, 0, 0.1074148, 0, 0.2327321, -0.00895, 0.3490981, -0.0134, 
          0.4520373, -0.0224, 0.5594522, -0.0269, 0.6758182, -0.0403, 
          0.7877086, -0.0537, 0.8995991, -0.0716, 1.020441, -0.0761, 
          1.132331, -0.094, 1.248697, -0.1029392, 1.360588, -0.1253173, 
          1.468003, -0.1297929, 1.584369, -0.1476954}, {
         0, 0, 0.1074148, 0, 0.2282565, -0.0134, 0.3490981, -0.0179, 
          0.4520373, -0.0269, 0.5594522, -0.0403, 0.6713426, -0.0492, 
          0.7877086, -0.0716, 0.8995991, -0.094, 1.015965, -0.1029392, 
          1.118904, -0.1253173, 1.244222, -0.1432197, 1.356112, -0.1700734, 
          1.463527, -0.1879759, 1.575417, -0.2058784}, {
         0, 0, 0.1074148, 0, 0.2327321, -0.00895, 0.3490981, -0.0224, 
          0.4520373, -0.0358, 0.5594522, -0.0403, 0.6713426, -0.0582, 
          0.7877086, -0.0761, 0.8995991, -0.094, 1.015965, -0.1118904, 
          1.127856, -0.1387441, 1.244222, -0.1566466, 1.356112, -0.174549, 
          1.463527, -0.1969271, 1.570942, -0.2058784}, {
         0, 0, 0.1074148, 0, 0.2327321, -0.00895, 0.3490981, -0.0134, 
          0.4520373, -0.0224, 0.5594522, -0.0269, 0.6713426, -0.0403, 
          0.7877086, -0.0582, 0.9040747, -0.0716, 1.020441, -0.0895, 
          1.127856, -0.1029392, 1.248697, -0.1253173, 1.360588, -0.1387441, 
          1.463527, -0.1611222, 1.570942, -0.1700734}, {
         0, 0, 0.1074148, 0, 0.2372077, -0.00448, 0.3490981, -0.00895, 
          0.4520373, -0.0179, 0.5594522, -0.0179, 0.6758182, -0.0224, 
          0.7877086, -0.0358, 0.8995991, -0.0403, 1.020441, -0.0448, 
          1.132331, -0.0582, 1.248697, -0.0671, 1.369539, -0.0761, 
          1.472478, -0.0895, 1.575417, -0.0985}, {
         0, 0, 0.1074148, 0.00448, 0.2372077, 0, 0.3490981, 0, 0.4520373, 0, 
          0.5549766, 0, 0.6758182, -0.00448, 0.7877086, -0.00895, 
          0.8995991, -0.00448, 1.020441, -0.00448, 1.136807, -0.00895, 
          1.248697, -0.0134, 1.369539, -0.00448, 1.472478, -0.0224, 
          1.584369, -0.0134}, {
         0, 0, 0.1074148, 0.00448, 0.2372077, 0.00895, 0.3490981, 0.00448, 
          0.456513, 0.00895, 0.5594522, 0.00895, 0.6758182, 0.0134269, 
          0.7921843, 0.0179, 0.8995991, 0.0269, 1.024916, 0.0313, 1.136807, 
          0.0313, 1.248697, 0.0403, 1.374014, 0.0403, 1.472478, 0.0448, 
          1.588844, 0.0582}, {
         0, 0, 0.1074148, 0, 0.2372077, 0.00895, 0.3490981, 0.00895, 0.456513,
           0.00895, 0.5594522, 0.0179, 0.6758182, 0.0224, 0.7877086, 0.0269, 
          0.9040747, 0.0313, 1.024916, 0.0448, 1.136807, 0.0492, 1.248697, 
          0.0582, 1.374014, 0.0671, 1.481429, 0.0716, 1.588844, 0.0806}, {
         0, 0, 0.1074148, 0, 0.2416833, 0, 0.3535738, 0.00448, 0.456513, 
          0.00895, 0.5594522, 0.0134269, 0.6758182, 0.0179, 0.7877086, 0.0179,
           0.8995991, 0.0224, 1.020441, 0.0269, 1.136807, 0.0358, 1.253173, 
          0.0403, 1.365063, 0.0448, 1.485905, 0.0492, 1.59332, 0.0582}, {
         0, 0, 0.1074148, 0, 0.2416833, 0, 0.3535738, 0, 0.456513, -0.00448, 
          0.5594522, 0, 0.6758182, -0.00895, 0.7877086, -0.00448, 
          0.8995991, -0.00448, 1.020441, 0, 1.132331, 0, 1.248697, -0.00448, 
          1.360588, 0, 1.481429, -0.00448, 1.588844, -0.00895}, {
         0, 0, 0.1029392, 0, 0.2416833, -0.00448, 0.3535738, -0.00895, 
          0.456513, -0.0179, 0.5594522, -0.0134, 0.6758182, -0.0224, 
          0.7877086, -0.0313, 0.8951235, -0.0358, 1.020441, -0.0403, 
          1.132331, -0.0537, 1.244222, -0.0582, 1.369539, -0.0627, 
          1.476954, -0.0716, 1.584369, -0.0761}, {
         0, 0, 0.1074148, 0, 0.2416833, -0.00895, 0.3535738, -0.0134, 
          0.456513, -0.0224, 0.5594522, -0.0269, 0.6758182, -0.0403, 
          0.7921843, -0.0537, 0.8995991, -0.0671, 1.020441, -0.0761, 
          1.132331, -0.0985, 1.248697, -0.1118904, 1.360588, -0.1253173, 
          1.472478, -0.1387441, 1.579893, -0.152171}, {
         0, 0, 0.1074148, 0, 0.246159, -0.0134, 0.3535738, -0.0179, 
          0.4609886, -0.0269, 0.5594522, -0.0358, 0.6758182, -0.0537, 
          0.7877086, -0.0671, 0.8951235, -0.0850367, 1.020441, -0.1029392, 
          1.136807, -0.1253173, 1.244222, -0.1387441, 1.360588, -0.1566466, 
          1.468003, -0.1835003, 1.579893, -0.1969271}, {
         0, 0, 0.1074148, 0, 0.2416833, -0.0134, 0.3535738, -0.0179, 
          0.4609886, -0.0224, 0.5594522, -0.0358, 0.6802939, -0.0492, 
          0.7877086, -0.0627, 0.8951235, -0.0761, 1.020441, -0.0985, 
          1.132331, -0.1208416, 1.244222, -0.1342685, 1.356112, -0.1566466, 
          1.468003, -0.174549, 1.579893, -0.1879759}, {
         0, 0, 0.0985, 0, 0.246159, -0.00448, 0.3580494, -0.00895, 
          0.456513, -0.0224, 0.5594522, -0.0269, 0.6758182, -0.0403, 
          0.783233, -0.0492, 0.8951235, -0.0582, 1.020441, -0.0761, 
          1.136807, -0.094, 1.244222, -0.1074148, 1.360588, -0.116366, 
          1.472478, -0.1342685, 1.579893, -0.1432197}, {
         0, 0, 0.0985, 0, 0.246159, -0.00448, 0.3535738, -0.00895, 
          0.4654642, -0.0134, 0.5639278, -0.0134, 0.6758182, -0.0179, 
          0.7877086, -0.0269, 0.8951235, -0.0358, 1.020441, -0.0448, 
          1.136807, -0.0492, 1.248697, -0.0537, 1.365063, -0.0582, 
          1.472478, -0.0761, 1.584369, -0.0761}, {
         0, 0, 0.1029392, 0, 0.2506346, 0, 0.3580494, 0, 0.4609886, -0.00448, 
          0.5639278, -0.00448, 0.6758182, 0, 0.7877086, -0.00448, 0.8951235, 
          0, 1.020441, 0, 1.136807, -0.00448, 1.248697, -0.00448, 
          1.365063, -0.00448, 1.472478, 0, 1.584369, -0.00448}, {
         0, 0, 0.1029392, 0, 0.2506346, 0.00448, 0.3580494, 0.00895, 
          0.4609886, 0.00895, 0.5594522, 0.00895, 0.6758182, 0.0134269, 
          0.7877086, 0.0134269, 0.8951235, 0.0224, 1.024916, 0.0269, 1.141282,
           0.0269, 1.244222, 0.0358, 1.365063, 0.0403, 1.4769535, 0.0291, 
          1.588844, 0.0537}, {
         0, 0, 0.1029392, 0, 0.246159, 0.00895, 0.3580494, 0.00895, 0.4609886,
           0.0134269, 0.5594522, 0.0134269, 0.6758182, 0.0179, 0.7921843, 
          0.0224, 0.8995991, 0.0313, 1.024916, 0.0313, 1.145758, 0.0403, 
          1.244222, 0.0492, 1.369539, 0.0537, 1.481429, 0.0582, 1.584369, 
          0.0671}, {
         0, 0, 0.1029392, 0, 0.246159, 0, 0.3580494, 0.00448, 0.4609886, 0, 
          0.5594522, 0.00448, 0.6802939, 0.0134269, 0.7921843, 0.00448, 
          0.8995991, 0.0134269, 1.024916, 0.0134269, 1.145758, 0.0224, 
          1.248697, 0.0179, 1.369539, 0.0269, 1.481429, 0.0313, 1.59332, 
          0.0358}, {
         0, 0, 0.1029392, 0, 0.2506346, 0, 0.362525, 0, 0.4609886, -0.00448, 
          0.5594522, -0.00448, 0.6758182, -0.00895, 0.7921843, -0.00895, 
          0.8995991, -0.00895, 1.020441, -0.00895, 1.145758, -0.0134, 
          1.248697, -0.0134, 1.365063, -0.0224, 1.476954, -0.0269, 
          1.59332, -0.0269}, {
         0, 0, 0.1029392, 0, 0.2416833, -0.00448, 0.362525, -0.00895, 
          0.456513, -0.0179, 0.5594522, -0.0224, 0.6802939, -0.0269, 
          0.7921843, -0.0403, 0.8995991, -0.0358, 1.020441, -0.0448, 
          1.141282, -0.0671, 1.244222, -0.0716, 1.360588, -0.0761, 
          1.476954, -0.0895, 1.588844, -0.1074148}, {
         0, -0.00448, 0.1029392, 0, 0.2416833, -0.00895, 0.3670006, -0.0134, 
          0.4609886, -0.0224, 0.5594522, -0.0313, 0.6758182, -0.0403, 
          0.7921843, -0.0582, 0.8995991, -0.0671, 1.020441, -0.0850367, 
          1.141282, -0.0985, 1.253173, -0.1118904, 1.360588, -0.1253173, 
          1.476954, -0.1476954, 1.584369, -0.1566466}, {
         0, -0.00448, 0.0985, 0, 0.2416833, -0.00448, 0.362525, -0.0179, 
          0.4520373, -0.0269, 0.5594522, -0.0358, 0.6802939, -0.0492, 
          0.7877086, -0.0671, 0.8995991, -0.0761, 1.020441, -0.094, 
          1.136807, -0.116366, 1.244222, -0.1297929, 1.356112, -0.152171, 
          1.476954, -0.174549, 1.579893, -0.1879759}}, $CellContext`y[
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]]] := $CellContext`v[$CellContext`x] + 
        Sum[$CellContext`X[$CellContext`x, $CellContext`n] \
$CellContext`T[$CellContext`t, $CellContext`n], {$CellContext`n, 1, 
           7}], $CellContext`v[
         Pattern[$CellContext`x, 
          Blank[]]] := ((-6) $CellContext`g $CellContext`L^2 $CellContext`x^2 + 
         4 $CellContext`g $CellContext`L $CellContext`x^3 - $CellContext`g \
$CellContext`x^4)/(24 $CellContext`c^2), $CellContext`L = 
       1.6, $CellContext`X[
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`n, 
          Blank[]]] := 
       Cos[Part[$CellContext`\[Alpha], $CellContext`n] $CellContext`x] - Cosh[
        Part[$CellContext`\[Alpha], $CellContext`n] $CellContext`x] - ((
          Cosh[Part[$CellContext`\[Alpha], $CellContext`n] $CellContext`L] + 
          Cos[Part[$CellContext`\[Alpha], $CellContext`n] $CellContext`L])/(
         Sinh[Part[$CellContext`\[Alpha], $CellContext`n] $CellContext`L] + 
         Sin[Part[$CellContext`\[Alpha], $CellContext`n] $CellContext`L])) (
         Sin[Part[$CellContext`\[Alpha], $CellContext`n] $CellContext`x] - 
         Sinh[Part[$CellContext`\[Alpha], $CellContext`n] $CellContext`x]), \
$CellContext`\[Alpha] = {1.1719400429449756`, 2.9338069581088586`, 
        4.909223398898508, 6.872212959297166, 8.835730244404044, 
        10.799224707555148`, 12.76272015690078, 
        14.726215563629026`}, $CellContext`T[
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`n, 
          Blank[]]] := (
         Part[$CellContext`AN, $CellContext`n] 
          Cos[$CellContext`\[Mu][$CellContext`n] $CellContext`t] + 
         Part[$CellContext`BN, $CellContext`n] 
          Sin[$CellContext`\[Mu][$CellContext`n] $CellContext`t])/
        E^((1/2) $CellContext`k $CellContext`t), $CellContext`AN = {(
          0.01708002532301344 (3.2669394535721263` $CellContext`c^2 + 
           22.759425728692335` $CellContext`g + 
           3.3374183885553954` ((-8) $CellContext`g - 
             0.29963279504576884` ((-3.945940831916758) $CellContext`c^2 + 
              20.362363368326186` $CellContext`g))))/$CellContext`c^2, (
          0.000013400797174164186` ((-393.4643563613987) $CellContext`c^2 + 
           493.66519312435884` $CellContext`g + 
           54.654287010560694` ((-8) $CellContext`g - 
             0.01829682637350656 ((-154.9726758189674) $CellContext`c^2 + 
              493.5188185133708 $CellContext`g))))/$CellContext`c^2, (
          4.247872768789749*^-8 (80603.51788464916 $CellContext`c^2 + 
           3814.5524728249343` $CellContext`g + 
           1288.9850543978853` ((-8) $CellContext`g - 
             0.0007758041853070283 ((-1215.010907996633) $CellContext`c^2 + 
              3814.546266391452 $CellContext`g))))/$CellContext`c^2, (
          3.420415622308074*^-10 (814490.9016531678 $CellContext`c^2 + 
           14625.27357354029 $CellContext`g + 
           29803.87073804782 ((-8) $CellContext`g - 
             0.00003355268880280212 ((-4665.685182311908) $CellContext`c^2 + 
              14625.273305118779` $CellContext`g))))/$CellContext`c^2, (
          4.2067134326351754`*^-12 (1.9943905833542854`*^8 $CellContext`c^2 + 
           39951.831790108605` $CellContext`g + 
           689706.3529026293 ((-8) $CellContext`g - 
             1.4498924011432159`*^-6 ((-12749.665424158717`) $CellContext`c^2 + 
              39951.83177850946 $CellContext`g))))/$CellContext`c^2, (
          6.66526222604041*^-14 (3.0778528843483596`*^9 $CellContext`c^2 + 
           89143.40507192448 $CellContext`g + 
           1.5960258578710688`*^7 ((-8) $CellContext`g - 
             6.265562536207914*^-8 ((-28451.116017340537`) $CellContext`c^2 + 
              89143.40507142324 $CellContext`g))))/$CellContext`c^2, (
          1.2493596788763664`*^-15 (2.873024725494401*^11 $CellContext`c^2 + 
           173889.31565612732` $CellContext`g + 
           3.693314622503152*^8 ((-8) $CellContext`g - 
             2.707595129250147*^-9 ((-55501.14997531679) $CellContext`c^2 + 
              173889.31565610567` $CellContext`g))))/$CellContext`c^2}, \
$CellContext`\[Mu][
         Pattern[$CellContext`n, 
          Blank[]]] := (1/2) 
        Sqrt[4 $CellContext`c^2 
           Part[$CellContext`\[Alpha], $CellContext`n]^4 - $CellContext`k^2], \
$CellContext`BN = {(
          0.01708002532301344 (3.2669394535721263` $CellContext`c^2 + 
           22.759425728692335` $CellContext`g + 
           3.3374183885553954` ((-8) $CellContext`g - 
             0.29963279504576884` ((-3.945940831916758) $CellContext`c^2 + 
              20.362363368326186` $CellContext`g))) \
$CellContext`k)/($CellContext`c^2 
         Sqrt[7.5453877980506485` $CellContext`c^2 - $CellContext`k^2]), (
          0.000013400797174164186` ((-393.4643563613987) $CellContext`c^2 + 
           493.66519312435884` $CellContext`g + 
           54.654287010560694` ((-8) $CellContext`g - 
             0.01829682637350656 ((-154.9726758189674) $CellContext`c^2 + 
              493.5188185133708 $CellContext`g))) \
$CellContext`k)/($CellContext`c^2 
         Sqrt[296.3371695027897 $CellContext`c^2 - $CellContext`k^2]), (
          4.247872768789749*^-8 (80603.51788464916 $CellContext`c^2 + 
           3814.5524728249343` $CellContext`g + 
           1288.9850543978853` ((-8) $CellContext`g - 
             0.0007758041853070283 ((-1215.010907996633) $CellContext`c^2 + 
              3814.546266391452 $CellContext`g))) \
$CellContext`k)/($CellContext`c^2 
         Sqrt[2323.3314614205633` $CellContext`c^2 - $CellContext`k^2]), (
          3.420415622308074*^-10 (814490.9016531678 $CellContext`c^2 + 
           14625.27357354029 $CellContext`g + 
           29803.87073804782 ((-8) $CellContext`g - 
             0.00003355268880280212 ((-4665.685182311908) $CellContext`c^2 + 
              14625.273305118779` $CellContext`g))) \
$CellContext`k)/($CellContext`c^2 
         Sqrt[8921.675601268784 $CellContext`c^2 - $CellContext`k^2]), (
          4.2067134326351754`*^-12 (1.9943905833542854`*^8 $CellContext`c^2 + 
           39951.831790108605` $CellContext`g + 
           689706.3529026293 ((-8) $CellContext`g - 
             1.4498924011432159`*^-6 ((-12749.665424158717`) $CellContext`c^2 + 
              39951.83177850946 $CellContext`g))) \
$CellContext`k)/($CellContext`c^2 
         Sqrt[24379.7801382504 $CellContext`c^2 - $CellContext`k^2]), (
          6.66526222604041*^-14 (3.0778528843483596`*^9 $CellContext`c^2 + 
           89143.40507192448 $CellContext`g + 
           1.5960258578710688`*^7 ((-8) $CellContext`g - 
             6.265562536207914*^-8 ((-28451.116017340537`) $CellContext`c^2 + 
              89143.40507142324 $CellContext`g))) \
$CellContext`k)/($CellContext`c^2 
         Sqrt[54403.933759413594` $CellContext`c^2 - $CellContext`k^2]), (
          1.2493596788763664`*^-15 (2.873024725494401*^11 $CellContext`c^2 + 
           173889.31565612732` $CellContext`g + 
           3.693314622503152*^8 ((-8) $CellContext`g - 
             2.707595129250147*^-9 ((-55501.14997531679) $CellContext`c^2 + 
              173889.31565610567` $CellContext`g))) \
$CellContext`k)/($CellContext`c^2 
         Sqrt[106128.73270025979` $CellContext`c^2 - $CellContext`k^2])}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.45606144071875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Here's how to plot Figure 6 without using the Manipulate command\
\>", "Subsection",
 CellChangeTimes->{{3.4560027382981253`*^9, 3.4560027499387503`*^9}, {
  3.4560028060481253`*^9, 3.4560028427825003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"j", "-", "1"}], "30"], ",", 
         RowBox[{"data", "[", 
          RowBox[{"[", 
           RowBox[{"j", ",", "15", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "[", "Beam", "]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0", ",", "1"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.3"}], ",", "0.3"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<t\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}], ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          FractionBox[
           RowBox[{"j", "-", "1"}], "30"], ",", 
          RowBox[{"Evaluate", "[", 
           RowBox[{"y", "[", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "15", ",", "1"}], "]"}], "]"}], ",", 
             FractionBox[
              RowBox[{"j", "-", "1"}], "30"]}], "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", 
          RowBox[{"Length", "[", "Beam", "]"}]}], "}"}]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c", "\[Rule]", "12.87"}], ",", 
        RowBox[{"k", "\[Rule]", "0.94"}], ",", 
        RowBox[{"g", "\[Rule]", "9.8"}]}], "}"}]}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"RGBColor", "[", 
       RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.3`"}], ",", "0.3`"}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4560027743293753`*^9, 3.4560027914231253`*^9}, 
   3.4560028639700003`*^9, {3.4560029274543753`*^9, 3.4560029277825003`*^9}}],\


Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0, 0, 1], PointSize[0.02], 
    PointBox[{{0., -0.2372077}, {0.03333333333333333, -0.1969271}, {
     0.06666666666666667, -0.1253173}, {0.1, -0.0313}, {0.13333333333333333`, 
     0.0627}, {0.16666666666666666`, 0.0985}, {0.2, 0.0806}, {
     0.23333333333333334`, 0.0179}, {0.26666666666666666`, -0.0671}, {
     0.3, -0.1476954}, {0.3333333333333333, -0.2058784}, {
     0.36666666666666664`, -0.2058784}, {0.4, -0.1700734}, {
     0.43333333333333335`, -0.0985}, {0.4666666666666667, -0.0134}, {0.5, 
     0.0582}, {0.5333333333333333, 0.0806}, {0.5666666666666667, 0.0582}, {
     0.6, -0.00895}, {0.6333333333333333, -0.0761}, {
     0.6666666666666666, -0.152171}, {0.7, -0.1969271}, {
     0.7333333333333333, -0.1879759}, {0.7666666666666667, -0.1432197}, {
     0.8, -0.0761}, {0.8333333333333334, -0.00448}, {0.8666666666666667, 
     0.0537}, {0.9, 0.0671}, {0.9333333333333333, 0.0358}, {
     0.9666666666666667, -0.0269}, {1., -0.1074148}, {
     1.0333333333333334`, -0.1566466}, {
     1.0666666666666667`, -0.1879759}}]}, {{}, {}, 
    {RGBColor[1, 0, 0], 
     LineBox[{{0., -0.2529995843447671}, {
      0.03333333333333333, -0.19916409570788027`}, {
      0.06666666666666667, -0.12552757410742726`}, {
      0.1, -0.024250069324152586`}, {0.13333333333333333`, 
      0.09031061005119459}, {0.16666666666666666`, 0.12371868641641968`}, {
      0.2, 0.11902910247906726`}, {0.23333333333333334`, 
      0.05436278737381781}, {0.26666666666666666`, -0.04415922972679896}, {
      0.3, -0.13993780659915633`}, {
      0.3333333333333333, -0.19719402073872322`}, {
      0.36666666666666664`, -0.2053214435216893}, {
      0.4, -0.16900554008197863`}, {
      0.43333333333333335`, -0.07439851173849188}, {0.4666666666666667, 
      0.00319200659673262}, {0.5, 0.07615149398430225}, {0.5333333333333333, 
      0.11004359515506781`}, {0.5666666666666667, 0.069096639711406}, {0.6, 
      0.019276309140187284`}, {0.6333333333333333, -0.07400407951885166}, {
      0.6666666666666666, -0.1482402816110757}, {
      0.7, -0.17752838826362016`}, {
      0.7333333333333333, -0.18087012874113614`}, {
      0.7666666666666667, -0.1227611481855571}, {
      0.8, -0.052187146799077024`}, {0.8333333333333334, 
      0.02070406970629889}, {0.8666666666666667, 0.07166493755935288}, {0.9, 
      0.07845924078213899}, {0.9333333333333333, 0.04470945764766045}, {
      0.9666666666666667, -0.02277832443538319}, {1., -0.08636904832695286}, {
      1.0333333333333334`, -0.14995228491983667`}, {
      1.0666666666666667`, -0.16366926958272934`}}]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"y\"", TraditionalForm]},
  PlotRange->{-0.3, 0.3},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.4560614413125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Find error with a choice of c, k, and g via a Mean Sum of the Squares for \
Error Calculation\
\>", "Subsection",
 CellChangeTimes->{{3.437063405261375*^9, 3.437063432277*^9}}],

Cell[TextData[{
 "Find the error with the choices of c, k, and g (entered as c1, k1, and g1 \
so that the Manipulate command will work correctly) that give a reasonable \
fit graphically.  The function ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"H", 
     RowBox[{"(", 
      RowBox[{"c", ",", "k", ",", "g"}], ")"}]}]], TraditionalForm]]],
 " computes the mean of the sum of the squares for error (MSSE) over all data \
points."
}], "Text",
 CellChangeTimes->{{3.437063035292625*^9, 3.437063113902*^9}, {
  3.437064137792625*^9, 3.43706416555825*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", 
   RowBox[{"c_", ",", "k_", ",", "g_"}], "]"}], ":=", 
  RowBox[{"Evaluate", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"data", "[", 
          RowBox[{"[", 
           RowBox[{"j", ",", "i", ",", "2"}], "]"}], "]"}], "-", 
         RowBox[{"y", "[", 
          RowBox[{
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"j", ",", "i", ",", "1"}], "]"}], "]"}], ",", 
           FractionBox[
            RowBox[{"j", "-", "1"}], "30"]}], "]"}]}], ")"}], "2"], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "15"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", 
        RowBox[{"Length", "[", "Beam", "]"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Length", "[", "Beam", "]"}], "*", "15"}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.435160341638713*^9, 3.43516035107573*^9}, {
   3.435160476866164*^9, 3.435160491162307*^9}, 3.435312205782125*^9, {
   3.435405715282125*^9, 3.43540572123525*^9}, {3.435491617169515*^9, 
   3.435491619044515*^9}, {3.435491694482015*^9, 3.435491716544515*^9}, {
   3.437064271542625*^9, 3.437064272198875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 SqrtBox[
  RowBox[{"H", "[", 
   RowBox[{"12.87", ",", "0.94", ",", "9.8"}], "]"}]]], "Input",
 CellChangeTimes->{{3.4357798487007504`*^9, 3.4357798551382504`*^9}, {
  3.4370642817145*^9, 3.437064297573875*^9}}],

Cell[BoxData["0.01038746177833643`"], "Output",
 CellChangeTimes->{3.456061444359375*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Find values of c, k, and g that minimize MSSE via the FindMinimum command, \
starting with c = c1, k = k1, and fixing g = 9.8 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "/", 
    SuperscriptBox["sec", "2"]}], TraditionalForm]]],
 ".  Then compute error with the resulting c and k!"
}], "Subsection",
 CellChangeTimes->{{3.43706312793325*^9, 3.437063169636375*^9}, {
  3.437063593792625*^9, 3.437063603823875*^9}, {3.437064350777*^9, 
  3.437064387573875*^9}, {3.437064693027*^9, 3.437064728027*^9}, {
  3.456060170734375*^9, 3.45606017909375*^9}, {3.456060242328125*^9, 
  3.456060268671875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"c1", "=", "12.87"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k1", "=", "0.94"}], ";"}]}], "Input",
 CellChangeTimes->{{3.437064394948875*^9, 3.437064419355125*^9}, {
  3.456060192640625*^9, 3.456060193453125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"H", "[", 
    RowBox[{"c", ",", "k", ",", "9.8"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"c", ",", "c1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "k1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.455912663626423*^9, 3.455912671610798*^9}, {
  3.455912718501423*^9, 3.455912719579548*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.00010507292556040947`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c", "\[Rule]", "12.842027389628784`"}], ",", 
     RowBox[{"k", "\[Rule]", "1.0069783347943337`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.456061447921875*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 SqrtBox[
  RowBox[{"H", "[", 
   RowBox[{"12.84", ",", "1.01", ",", "9.8"}], "]"}]]], "Input",
 CellChangeTimes->{{3.455912730376423*^9, 3.455912731157673*^9}, {
  3.455912864751423*^9, 3.455912875892048*^9}, {3.455917662001423*^9, 
  3.455917666110798*^9}, {3.455917803173298*^9, 3.455917804376423*^9}, {
  3.4560603865625*^9, 3.456060387640625*^9}, {3.456061108171875*^9, 
  3.4560611093125*^9}}],

Cell[BoxData["0.01025110565999327`"], "Output",
 CellChangeTimes->{3.456061448296875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Plot model vs. measured data at all points with our new choices for c and k \
with g fixed at 9.8 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "/", 
    SuperscriptBox["sec", "2"]}], TraditionalForm]]],
 "  - this is Figure 7 in the paper:"
}], "Subsection",
 CellChangeTimes->{{3.437063209402*^9, 3.437063231198875*^9}, {
  3.437063461277*^9, 3.4370634689645*^9}, {3.437063636761375*^9, 
  3.437063642573875*^9}, {3.437064491042625*^9, 3.4370644955895*^9}, {
  3.437064836011375*^9, 3.437064850948875*^9}, {3.4560602254375*^9, 
  3.45606027921875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g1a", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Graphics3D", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"RGBColor", "[", 
           RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
          RowBox[{"PointSize", "[", "0.011", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
               "xtape", "\[LeftDoubleBracket]", "j", 
                "\[RightDoubleBracket]"}], ",", 
               FractionBox[
                RowBox[{"i", "-", "1"}], "30"], ",", 
               RowBox[{
                RowBox[{"Beam", "\[LeftDoubleBracket]", 
                 RowBox[{"All", ",", 
                  RowBox[{"2", " ", "j"}]}], "\[RightDoubleBracket]"}], 
                "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", 
                RowBox[{"Beam", "\[LeftDoubleBracket]", 
                 RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], 
                "]"}]}], "}"}]}], "]"}], "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "15"}], "}"}]}], "]"}], ",", 
     RowBox[{"Axes", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "True"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x\>\"", ",", "\"\<t\>\"", ",", "\"\<y\>\""}], "}"}]}], 
     ",", 
     RowBox[{"BoxRatios", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2", ",", "1"}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4347497162512503`*^9, 3.4347497172668753`*^9}, {
   3.4347504244075003`*^9, 3.4347504272512503`*^9}, {3.4347507323606253`*^9, 
   3.4347507941262503`*^9}, {3.4347508249231253`*^9, 
   3.4347508253918753`*^9}, {3.4351627277040405`*^9, 3.4351627638115664`*^9}, 
   3.4354918918413906`*^9, {3.43706455037075*^9, 3.4370645637145*^9}, {
   3.43706491362075*^9, 3.43706493637075*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g2a", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ParametricPlot3D", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
          "xtape", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
          ",", 
          FractionBox["j", "30"], ",", 
          RowBox[{
           RowBox[{"y", "[", 
            RowBox[{
             RowBox[{
             "xtape", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             ",", 
             FractionBox["j", "30"]}], "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"c", "\[Rule]", "12.84"}], ",", 
             RowBox[{"k", "\[Rule]", "1.01"}], ",", 
             RowBox[{"g", "\[Rule]", "9.8"}]}], "}"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "0", ",", "32"}], "}"}], ",", 
        RowBox[{"Axes", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"True", ",", "True", ",", "True"}], "}"}]}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<x\>\"", ",", "\"\<t\>\"", ",", "\"\<y\>\""}], "}"}]}], 
        ",", 
        RowBox[{"Ticks", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"xtape", ",", "Automatic", ",", "Automatic"}], "}"}]}], ",",
         
        RowBox[{"BoxRatios", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"3", ",", "2", ",", "1"}], "}"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "L"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{
              RowBox[{"Length", "[", "Beam", "]"}], "/", "30"}]}], "}"}], ",",
            
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.25"}], ",", "0.25"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "600"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "15"}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4347497465481253`*^9, 3.4347497471418753`*^9}, {
   3.4347499777512503`*^9, 3.4347499845168753`*^9}, 3.4347503933450003`*^9, {
   3.4347504483450003`*^9, 3.4347504894231253`*^9}, {3.4347506924075003`*^9, 
   3.4347507207043753`*^9}, {3.4347508160481253`*^9, 
   3.4347508166575003`*^9}, {3.4347509213137503`*^9, 
   3.4347509371887503`*^9}, {3.4347512960793753`*^9, 3.4347512962981253`*^9}, 
   3.4354918958101406`*^9, 3.4370645757145*^9, 3.437064612948875*^9, {
   3.43706464724575*^9, 3.43706467362075*^9}, {3.437064942777*^9, 
   3.437064945167625*^9}, {3.437065004605125*^9, 3.437065030855125*^9}, {
   3.437065065355125*^9, 3.4370650923395*^9}, {3.455912922126423*^9, 
   3.455912937767048*^9}, {3.456060402390625*^9, 3.45606040325*^9}, {
   3.456060520078125*^9, 3.45606052396875*^9}, {3.456061322359375*^9, 
   3.456061323421875*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"g2a", ",", "g1a", ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
   RowBox[{"ViewPoint", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.8", ",", 
      RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.43548406618044*^9, 3.435484458839203*^9}, {
  3.435485394763265*^9, 3.4354854665288906`*^9}, {3.4354855341226406`*^9, 
  3.435485841232015*^9}, {3.4354919142788906`*^9, 3.435492196169515*^9}}],

Cell[BoxData[
 Graphics3DBox[{{{{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxt0X0s1HEcB/Ars9VY7lTSg81Ds7X1MKUahoQp5Ci6k1wbLtHKTx1tOivs
Ko+3PB1qlLAuTqk85IjdbdymjjDh5unchePIToax6r+a9/e9vf95/fHZZ3vb
RMRd5G6l0WgBf2tE+5cjOeXPWq6x3Gibks2OD5mnTrpvdh+blYI2yhu8UuBy
6jUVAt5/OvzRc4oLPke/XVtIJYDfS06U5VEC8NYPSf65VAH4vsOtNtGsKnDf
Ly2i2qJ34MneZrmxunpwf31K8NO3UnCr+O108/R2cM1W9RCdJwc/2MCzooI6
wJeEhVzBhgJ8Z4qCETjZBS4rSpf1iJTgv26kLrPLesCPMxSuFWa94A3+IY99
o/vA1Xm61C5VP3jX7FUp//wA+PqAxfKT0u/gfV8H1XH0IXADS/2tLmYYXKo3
3FGOqcDd89WB+5kj4KZKSwd55Sh4W3r1RLnpOO6VOF/NaEYf1pXlW0ZNgMdy
QwayDqjBS8VHi2sV6JUGk3rXtEn8s4O1EOWsAbeI6HzjpEVfMnJpu1+qBU+M
6w2+6fcD/HLk4DbDErpJuHr3dM0UeIQ1vSKDPQ2eM+ORWWI+A87hiwysdvQs
UViSJFaHd5rsrlB2s+AnXplJx7vRJXm/eZ8z5sAFppwLjmf14FuY41UsPXqQ
6HrodNU8uJeYnm0fvABe6HlobH0DfXTR1ts67Ce43N5TZVmHnsvRWp3bsQhe
JinxuERwyTqTyyF4Z0lzDY/gGwNCl5cEj2Y6h64R3O2MML/GDN1P6NXUSHD2
6KpKRvC7/Ci7IYKLm5zeG9PRdzloujkEt31YbIgh+LHugD0JBPe99YmTSfAH
4hx9I8GzVjwZcoKX+Kw6Kgn+URvJ1xBc5rj3xQLBu9OU8jWCj/SmTRkz0HU2
TiaM//wPOjY+bA==
       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1mk8lFsYAHBRWqixpEguxpJuiGRLPAwpa1KZsiVZCl1uRKSUUGQLNSOX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       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1Ws8lOkbB3DVWkTM1Npsm5y3VLQ127b+xYVJa+VUycixhnEYyix2NINE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       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxN1Xk0lGscB/CxFNVYJuW0kN1FiHR1y+GHrpKIhClarMmWKWMfa/YsxWSU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       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxN1ms4lGkYB3CptG2YGUW2qEGJbemgslhuk9CKkktG5LCUWSSjtQhrRZYZ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       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1Xs41FkYB3DSZctlTFe7y4ZRz/aUbKntWaXXpUglk2SsJA1tpdYgmzVZ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       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxN1Xs0lGkYAHAJJZNhWq1kNqE2W5TUdmJ5jEnKJeWUqUjlEtFG2FxTajTu
txnGJZqQ+/WIZCoThZJyS265DMYYhrFjdYo5tn/2/faP95/fec7zPd/zPO/3
bXf2tnOTlpKSuvTjrP1x+LuFQbkhk6Abn5P5/CLFZMPQe3e6X3nDfx5w62Yj
3ScCSnTsu3LLS5G/qA62TvZJgU5Obr/sZCXyFTOJVh+NBRuqFYer/LB4tT0v
trtT8mE5Mux2Zk4hcsv3z5nlaZXwiNQRa+fEQj6+nseIJVUDuTJTdY9KJvJb
5vhkT0ENBE4vGFioMJG7ph8TS97XgfwBmeP7piKQWwvDTydVsIElL5XYcCIA
/vMmd8v6gUsvwf5+rK+hdDRy4g15JUIUB6xeB14nGCcin5Dm9iv5N8FHL9HL
B4pZyKmOJSEc7mvQm2cb1N9gIdeu9Sf6nGqGRmULylJvLvKNuRGvggtaIKXs
guKwCMuzmJDqFiFphXxCx5Sz5v/yR1awPX3ewUikvMo1jTTkm8JblU+OtwHt
DwftrKR05DM4Hc9E43ZY8NW941hHR96YFtXYwfwA7QU/xyfupCG3P9hCIc18
hPpufs4ang3q2z8ed5fOPuyA5YF1Fx0330e+yXhHRhilE35ZTmpJOhKFfL9y
q3EevgvSU9QCKI8YyBfL450D2F1wy2HPm4c96chrrc/QLN27gUEuH6JXPEZu
I9omG7O9B7qs2iTkZ/nIuXTB3bbBHlCfX3aKSShC3tugtS0v+ROs0/Ng6kcW
IG+bcWSHHu+Fc86zF9y9SpC7jD3rk17sBZrU/iLzSMxXejcvRWZ/Brf6JMfg
+jLk7l0B10IpfXBnY4LcgbvFyLvb+7jeSv1AtXWT6tDB6hRTuJ1VVweAPaFw
5qbjI+SfNb00OdqDsKmc4rHcgzlbKPb9MDIIcfa4d2pnUpFLTGfG/JlDIDas
sK8Li0YODO7JrbZfIIae3T5r54jmuKNKYur9/QusNMcVVFZbo3jcB1X9psfD
MCSaekNzDUTxb0SHgqkXR+D3O1WVgLuHvCGqZCwHNwqD52q8ZGpSkM+tvj96
3mUUKm+/MAz9gO0b8eZciXL9KIR0938jtGD7GbrPQkMFPwZPL+Ofp7CYyAcE
DxmqrmNA8iN7h1xiINcsDK6x44xB9KTWKauLWLyn25neWHUuLFcfI3x5iNVD
Xdf4NMuXC3KBPCNTHSxPdpFeenkrFx5PGHmYxAQhfyxWqDG+Nw7PD5evD7UJ
Qv3pG9K36xweh/Aecu/UNh+sb82UeVfDCTA756KkyopHrszA23xMmAAPAT+2
jpOGfLNzS/HhyQlQfcJSZWzB5itrsKZmgPSjT7+m5MzuzcHuxVqjhpDsSaj6
TfZ6qFwu8ppnctHixUkoKA0TfFXH7sVN767TXlY8MGGecNNUwPb8ytVPentZ
PEg3/zY8L8buhb1L33rxIg9ejpNaOimY61+6kCA8OQXaV78XOwRieRQucFX4
pVPQni3gkvdi9dSafHN8Js0H2t/fJ7t1sXqcNZTyos/yQThCNTCaw97rq0wR
M7mGD6XFPK4CGfP4aVJMBmEa8G0Frwmy2J47hTLFFM40TA/QjeOJVOz7E/Wt
9q6KAFwybuewj4Yjj2U6BJd5CoC4i3Pg042ryDcWgkCxRQD74tpFOMk1NPf4
Oq3zPlozcIN0fv8rmyjko2Xp0YVBM9DHK9yaUJqE3CAXzx79OANWT5guy4R4
5D6Z69JsdWehlZxJfOefgLyMvur/MnoWdu+SJyy5YL6lQ+9yEG8WxEmmnNdM
bJ8jcE42B8yE0OrTvwp87LlNutu+v2EKIXC3i0VZdSzyNbaj+RShELir2or+
zn8h3+WnJaVhOQe+6WaZXzv9kJ9iXjnHz5+Do52G3aelTJFbsYz8aJI5kMnQ
aaYKr6C+HSlSitt5eh46xkNkD+6iIf9zSb1WuWgesmY42vlqdOSpZJ2RFck8
2OL0iQdtM5D3vHU4j9cVwUHqPRJ1FftfDy9omms4iMBhlShHJj9AfhJnkKh+
XwRqO2ZlUnWwPWnaSR5UrRJBbcuesjZyHvJiM0Zo5YgILL50zSkYYHub7DRJ
PKa4AF+Pz945pY7Fm5gmMErxC5BX8dPbLXqYC7YfVlBWXoDsEYM+70N5Df8C
3pXdRg==
       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1Ws0lFsYB/CSSlFjWEqXWWhcGqKj66kWT5SORGTR6EIa16hMkUpoFSWX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       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxN02dUk1cYB3BmaWsgBAvioGxtekSFYCv1wAMKttggQzQKKFuGg0hBDiGg
ASJLCIYRQAVkqOyhIFMQZCkComKEUwlhGMI2qZ5aKfWL9/bD/fI773ne9/0/
/6vrFeTkKycjI+P4+ch/Pt4ulsqxffNglFJwrcWdZqHbtcF2mtPQ9sXDIi90
pNHZ8P6wfDV5pBF5610GlUvPAPLG017WA/j5T/tW9flx+bBhj7XE6H9zNm1v
1fWj3YLWqE3Cjbb3kB/sb+FVZlVDRb33q5tppcgjbYjcQHEdRCh7qBGo+cip
Cyznq1XN4NrWv0tpOBS+uNb5b1TVEtphmOScGnkzB/mUnPC1akgnWF3p6Fb4
vhh5rFtZRLvwEcTfo4YnEcuRG9SHaNEdu+GcmNtBrceuXMh+yLjdAwGXihgC
S+xSTqYve7UXWirpiQkmt/H8+KrmQPpjkPcgDzhcx+9dz+olOUw+ga4A9XcK
/oXI5wjkwFTzp7AUnC2blpOPvCMroWOINwAPOTmUCW4q8r/8o98fyxsCGju5
1PhmPMrHhNRrXkQchkEjtvo/UTi3euqRuIN+z4GV89i5rKkSud2ytmKS7gs4
+iByUGn4LnJhmjj6ydgLiNqVM6l4GO9rpE1fu4j7EnyCCw4pUeuQP5lza2ba
jkB+0269oSDs3hONfDnpCDC6PKoKL97HPRnReB+f+wrsW831UqnY/YbDzjBp
fKhlceZqq/Gc50/5wiDV1xAyf3j0p55a5BKa8FlNwCgoqYTqajzD/9W8IAke
GB8DB+vu2pHaAuSQLnTYbP8naJSHTq6NXUROGNA07ix+Ax03DH2b+lgo567l
nxmx7uMgTRKU72/PQN6WUDZRQBBAaUz7h5DteF+La/0HXLwFQLCN8q8IKsL9
vLBYRmoSgM0ZV01iNO4Dc9evOurECdguZJscNMZ9GBXnpWv6TMA7y86W8gDs
encYdU7tExB+NsPOfj32QN8jI1e2CKGq9GHVtwUFuIdKHfdvBAuB70laVOPh
e5FbsiO7slcIDUzyPY75VeTFknV15jGTcOq41Yu4Fj+cTzdtyeeXKchuyNqZ
4p6NnJROtBvkTEEWg+DNIhch1/DqKTWbngKDEm8eXRvfa0WKbN2o1TTQ484m
q3PwvqTye9sicqfhUfgo29SyGnld41eJEuk0bNY/cMjPsQb5haBh59O/z4Dy
Mx3PQ/G4t6cCXu7YmT8DiuTkVb8Y3Nuj3vyvJdIZMMq32kZhYTf2OMFZcHgL
ex6bbtrJx71ad0KoLip/Cwcyll7KELDXW/zt1igngrK87/KP2eDv9NJRLUo8
JoIluoys/nIV8g8KJTxunQgy2cGaSy44h5RZq6QctVkIjd4doa5RjPwkkyeh
tc+CCQWUMgVc5Fd4royKQDFYxET41wacR658B8QqPWLwS7aeyPuIe5vSoO9C
15+DoX9TnCRq6cgFFdmJd8LnYE0mMN5oWzZySiGxWTA4Bz92nvO1lLuOnH5N
KcveaB4uvzIL/EMGe0XaWsiDxHnoS1OMTaHh/m8c2uEZPjMPfEoY00Cai5xN
OGlnum8B3LUT5/OeY+800v7YxVuA+bu9rW+Imchl7QW3aAsL4B/2qM9+IBm5
I+/UcdGtRTA9nnP97LgbcusS1eStzkvQnlvvY2eIc8vcTx7/tLoEvc2fLvKZ
hcjfrOjZ6LguwzlDwx+K9uK9OBAoqVsuL4M0xUlFJF+BvHPr/jHNmmVQVDCu
De7Eey/dl86sHl+Gd1oB0WaeuJ/ck9Nav6msQMiAAevyFHYLS056OXEFVO0v
UTL7sYt1zdaRSCsgFM3WtzTUtP0H5VKwPg==
       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxN1Xs01GkYB/CSpHWvaNZmxchRK7als9HlyTW5NAYZIVlDbtVMre3ictrE
upT7ZCS55xq57IgQmcqEhOSSEzMTGuPeTNosWf/0vvvH+8/nPOc9v9/zfM/z
anjRHHwk1qxZQ14961aP6lb5CG+TOdgdn3un4RTlkNke52MRho+bvvmlsIst
KfRICP2oY9W4uRl5Y3WwbTL9FqzN2kVOzWlEvmS6TByIyobBmJ92HBvGrqrb
qOFLKQAPu70WVom1yK07GpjlaRUw49IgnjpVgTzMQiE5QMgC1SbtxRFGLnLb
6WtOSQ/qoVbRpYVDvgDfXO38RsVNMc3wxrE/iKSUjXxUgj+oGMSGhbZbsVXi
YuQR7qUhzfynMP/AJs3FuhK5Vk2QGp38HJSDUsQ7CiuQy+VFPgkubIWuvDXO
rjW4XpyQ6hO5zAFuXYhEs+d9fH/0g/oAehtsGWrnRziUIt98jaNk/74dmnQP
3JH6vRD5pOzOgMSDL6HB+HBqxpdc5C1pMS1dzE4guS2q8S4zkH/yC19wyeqC
cB1zI39RNOrPL0qcg/kKPXDEWKftx4x85DW2x6OsfV+Db0f+MW2rKuR2c+rr
b2j0wvwT0+qX3IfI+SnC8PahXmi7vLLJkYTn1ddEVM9PfgMiA+tm9/RHyNsn
3etDj/ZBz2ej79wNsVN5dQMS4j6oMwlYXspowDnpU1mIzuyHxcRdZfZP6pH7
9lw6E0oZAKGj06iqJb7n9csBPk1xEJoLB/d6HsXfKaLwuyv930LYeCBV8wP+
r/pp0YXOkSGQLj3Q361ciBwYfPsfSO+grprmlZQYhVy2k7CHfW8Y4vy0I0lT
UajPz+Z+DY44NQIe0g7kFXYG8qaYUl6uLBeGN1uY+2vnIZ9Z6bB0pXKhsKov
ScAuwvm8OFOq9IgL1KLUIfoEzmHoz0e2KyvwoPI9sUHyOq5/K8xiELx50Pss
3lb3CnbNomCWQzMPeAsSmuY+OD8BPsf7bm7jg9ZXGRWD7gKcww0tD+9e4INk
o/z41uhM5JnFerfLOXyQlj/bIXmVifyeSIZ18Pp7CNesI4b94YP785wy6208
CtR1OlJeLlnIlRgKdq8SRuHIi33ncx4XIVfxai0xGhuFNqbAsnO0HPl6g7Ws
tyZjsHWXct9KHp6XeN3+ppDMMSAm50S3qv2NnFUnFSsSj4HK+vZLO6gs5Bdp
PU6BNuMgd46mGTmG83Da/42efvY4DPMSyFsYOLfO1AFpkXgcXMvbDfs7se/x
PJkwbf8BuqmBKbrvapDLnOQrC+5/AG1rm6fq8dhrDn1xr5MQQJnXq9G92dXI
vbYr5se6CECw84xKnB/2z5LFzGSWAJZqTzjrcnEf4idMbqRvmgCtTyOkeb0S
5B6hTBGleQI6YmZ7U+3SkN9kugWXBQhhw5+idJqQjlyuCITyrUIIZRcQ3Gg4
t/G1RFc6cRLAiKhVysHz5Zbdji26MglkP339yX13kRvkKdRzX00Cf4ufc2VS
DnL6nQ1ppN1TcPOTbWDiWexlKStBj2OnwGdW/O9hWj7y77v0frsyvlpvtr/q
BgHvsUhZDztD02kIYXdIzf5vv7F3qy8+Y05Db4eIkKSajnwtiVtAmZ6Go8nG
Ew0cvPfIzNMnBAUzICSQ3nlneSI3L1aM03aaBcczcZYE1VTUn1SznSNLy7NQ
XrqfQ5TDe2B4XtNiu9scUMx9WR998btjL2uQuO2vObiVu3Q1IKcSOVvbbIhQ
uZov0sbL5/xxPktMGaEVI3PgFKb/IqsVe7LHmJqV/DzoyV03XJDC+Tl0OIFx
X2Eejgd8pRb+g/Ms1DCSUVKaB5uSiuh7E6ym/wB/yXFn
       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1Xs01GkYB/DSUcqUS2fKblnJpuyuwepk5fIUaZNqKDVyLZeUbY9JTiR0
0eQaGbZxC2mIYVwaJtPQMJI5bpXBimKM+zAitCHa/ul9/3j/+ZznvOf5Pc/3
vD9tT//jPgorVqwgfzurvh1CacIxt/lp0I/PSa/yoFi6s2503V2oFXz3oLAr
wiQqDRKYd7w8poXIqzkhR+jUf4BjVK8b543rv1gt6XRFZoMJcYDONcb+42/V
2r6UPJggN5zID69Cfri5ilGcUgphbUmGb25xkIfZqND9ZBVwwa5S/JbNRH5E
ftMxsYQPoZtswuv2/A3fXfPSWlX16BogZ2VJ9DNzkK98NheYuFwLBwMUi2vf
FCEfVJC+VQ2sg4hwA2p6YAny266F12qkL6CssTpC07oc+c/cQE2qw0tgddZ9
adzCQb7+Ea025HEDyBZdhf0cXD+bcN+HtiQCc/+O7C7NMnx/VAnfj9oIDjv2
ECajSpFvvClSsx9oAkUzk/9MvQuRjxP0/O5ZtIBzcFF5VjoTuTAlWvia0Qq7
XJqqIDsF+dz5W5+csl6DlOBk/QctBs3tdzWRBVOlDTKdJsJah/KRc4+cjDzs
K4b1QpeqpvAK5EentBRjtdtBS/+YufdxPnJpkuxWU087dFvciWCr4z12CnS0
mPQO2KjZbCAKEyBvGnflh9p2wnlFMFAhY/fq53UpzHZCsrjCjMiowfnp3PQp
KvNfkFw2S9ZbxvW+bUEXQyldUD5OW+AxniMXt3RJ/VXfAiwfmiupwn3OUKRv
yi50Q3kgbdFoAn8XXz4T0NrXA8EJxh07zQqRQ7LUfgv5Peg9iVWar45FTmjV
MKrL7QV9s82LibsT0Jzrp0xCbnv0wVIcrDp/9yFyQXRhfw5BAkv0dzdWBuch
n/zafNDZSwJKtiMCgzScQ80rk4VqzySQ0ZvmElnPRh5q+Oc2oko/iEWm6VZ6
xci7ZVnJGt79INMSZIyfxPXb80Mqjtf0g5uChpGQivPj53OyM26rFFLnSxtp
wMI5XCN8+iBACsqbx0SXWnH/mQWk1GKRFFzcF6JK/DOQ584oV1hEDMD70DZT
7vRFPJ+XlA/eewdhxHH5LCU1B/kmzwaW6dAgMEmvPLuzy5DPrjITXMscgoYH
YvXygafIK3irY2Zmh6C3fDBtNpyH/Ip/m+NfdsMA/QV7OJ/xfs9d6CAZZA8D
LeDFw3BXnMNTXl1KM7PDoGFL6t65iN3ojFuC3H4E+DY76NHiZ8iV3aTE0aIR
aOTG8fiR2LmW8648hVHYrxdcw9uB+/TcpsqMcRqFLOZ12sfbXOTxY/tj09TH
YN8v0UGTnsXI3UMZM5SaMfjV3KdljvcAeRzDJYTtJwOh3add3iZ4nuvzQbah
QQZBlTZEh55YNP/4Sh1nqs44LOW2eynXpiGXsFNj8q+Og6XS3oDVo9nIjR+p
8CWvxkH1Hqt56xP8blDT16SQ9SegIl6U087Bzk76Gvg8ZgLKTm9h28kfI//h
Nens1eEJuF5AdDtkm4ucRnA/uttKDvZf4wmXiTjndfpaC/UMOcRcN/ysczAT
v8NkSR5FLof7xIcZP23A/Tswzp0ezZuEbuuk59aGZ5AfKFC9q+v4AbSUqTdO
fExF87lvrdf3ZekDrPMgKi+wWch7p7fbbHOZgr64xHXmFPwfsScY39t6Zwqa
OSSae3M58jpd6x6NsilwHmK9WyvG+2VZJYeW9k2BvhfphJ5BJXK6+5DmoQ3f
3htfv7BTXJxPy30JyUUq07Awo9viVoVdpm2qrKY2DcOLj1uP8XiC/wE9LN7b

       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1Hk41HkcB3DHs6l1ThsRSljbsaQom8WnKBHlWJlyr1FpypqtoRrss+VI
kvsqOUKuceZKQzNGU/PkWF3MsMKMczRhZ/I8ecj6p+/3j+8/r+f3vJ/v73N8
tweGup+Vk5GRObl25NfOVweClme9BIyTinLb/Ik2A52bU68pc5jf/GpUODud
Egs2hKo68w7s7Q005zRKJugzEumZ+s+RL9uuGPBuFYIoZ58i17ET+Zaf27ef
J5YCi0rrMyaxkB/vbsuuyakD39GlL0syLcijjqqmkUVNsCWgzE2wqQy5s/iG
R2otA2JsfFVOdl2Cb6775wa1jbdZMN7QyMriP0Iu+/QzNfVrB2hZVFiRK+uQ
j8sJ+GrUTnD8C4im7MfIY3zoESzBczjw4EzlzuFm5IbNVF2K2wvwIdaxPXWx
KxfHdtDKXsIC10lkZ9mCXJqcdTZ2hQu/3E3u0X3aiPPjaxlkyiu4b7vbry2s
AfkPN7gEV2EX3A/Yob11Yy3yWaWd5BTrHpA+/u6r3J1S5Oyc2+y+7F5Y57W4
I3fDA+Sfg28uni7oAwfvgd1xSkmobvsIXOsS1TcQlfRZgXOrGnmz86lbx8+/
hdho+5XkuSfIBemim11D72C83m5rtBHuVz/TYFtJ2nu4pu0Yl7eNjbxr1ocR
6dgPvF3m+j4k7KSxVp6ctB9c9pBCCf9iX+7XWIzPH4C8iH2W/ibYz7+5eimS
yIO3wQb2orgO5G97eIJQNT6E61kE9+7B9xGm+Q6qtfPhkOwGTfmANuQSouB1
/YVB+G/WqO+IEP8XQyy53DsyBBphfVYRxTXIIUPgqu0yDBmFyzUz+5ORK/Vq
7u189AHMZGcoo6/TUZ058xa0GP8ROP6KI5YvKEHOvE0fK1IahYfvVvVWQiuR
f1rttvcijUJBt7sXh4/7qxv+iU54uubR1RWty3g+I02P6amrjkH90SKXvuF6
5IOiggzNoDGw9k7xmPLArl9Oa3JnjYHe1ld/MKNwPvnsqf5EHQHU2i5qPRBW
4TlUYLfkXRaA3d+5roH6eF/yK0zu1XAFwC21tA2aK0D+SKLYZB0thPTxyLbV
piu4Pi+Ic0GW47C5J16oo16KXCPwZeXBiXGwKLEyWBA3IJfK/8qMyJ+AEAXG
6q5GBvKm1nUJEukEHGDH/+Y31Y48PPSNx0WnSTANLqWmLDKRn7vw3mRP4SRc
JJMKd/2I58GTxFsvkU5Cb3vH/oVU7HsDfJPFrlPQnDmoqG2KcxR9BerTVVMg
VAldzyE9w3th88WnVW4axlaOnS5XwfcM1FMrSTg9DcQwupMfpRV50szhO/c3
zoCZKW9IjlCP3C8yW0JkzYBbiPKTELeHyBOzvWnVZBEkUQdc103445wnBl4U
g1mo2V/yzs0yD9V/tPpeQvn1WVB2SInXSixGblasyhj9Zxak/Ist3vllyCm5
Cjkuxh9BGGI4+X16OfLq9FXqs4SP4BxsOGkcQkeu1Wfy+/XJj5Dps1mSP4K/
j1XyO2FuKwbZpcKsq6nYO423LXGyxUAtCpog8R/i99ZltJQoFkOQDt29JSkf
uVv2uTPTpZ/geYPeQNugN/IjFWp3jTzmYLibE1H7OA/VIctu58jyyhzEmHMa
r5Dwnn5Y0D+q5z0P4SfMPdUtm5G7Kpml6MTNA0tZY3C3Fd73TiO7Ic36efhp
UxU7zBD3sdI2I7JuZC1HrVxKq8Oe5jeh66CyAPbTyxNZB/Ac2hxKzqhSXQCl
1SV7gyPYRdsPKhIIC8DzDzWJdWpn/g9tZKSD
       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1Hs4E2ocB3Ct+0PN9NRTabXSHE4o6qlTHfuV7k5CT87kHkrUwwjVKJxa
msswaqTHJXe5JsqlxuROB2lusVm2ZlrxbFLnUU7/9L5/vP98/ngvv+/v/W12
9zt9nqChoWH1cy38uSKo9PKvsTNgzHmUWudKp9msMxfvyWrl//KrN4IFiQwW
JFDy5sjF2F9UME9yGfcgImj8Ti+1BfmcxXe9gcgMCAn/+jTFtwn5eqMXm73o
udCU2FbkSmhEbtlZxytJLgNfN6bVyPJa5DeOELk+ikpoFqfL3IUFyE8qI84k
lNaCws0wKCHSH3452X+5tg67HjJ2sx1n7QqRL6iZCUz40QAu7OekJGIF8nGC
ZFA7sBFWZevOZFhXIb/t9DikXvIKUvfSbKiUauRbqwLJDNtm2NreqgrnY1+R
xWpg5rXAbETOj/ou7Oq4++dZ31uh8um89Tsd7Lfvltb6MNqhUKjHqgvE566K
aCXZvO+A3/R215qFlCMXJLMF3bzXEHuNxCS2pSGfufjPF/v0buC0G25XNsSj
+piRWs2zib2gf/DCvub8cuRVJ+0iLb3egK6/kmXBr0MuSVT80zHcByND8qSY
dgFyIV9vUzb3LZSak29S818h75h0qg09IYQDvRk+Ux44X4+x6gGCWggG+d8W
vbPHPidc8+VuWj9wtj45KivA+3j1Xr0cSh+ANb6Gm059w/3wpmtA4qc9CHa+
ase4Inyf91znIe0Xg+B51mY0JqQeuYou6Sn3HgKKafhDXQP8rlqlKuC1aBhE
cZffHostQw5JEhtd6xEgUPu9DeISkGu9XmvamDMKPcGXwu51pqA6N03tYd52
FYFIWtO19Hkecj778dgjLTHQ/Lrm29tKkH+a7zzq4CGGlUHh3G1hOEdy8KfH
pBoxUHe1cGZCcR+G7jhGWU0cg2mCJM+15CnyIUV60lrPMTAyu0U0OYd9Sz6z
8nT9GBSUubWXUZ4g9zlvJ4zZIAF3I2/iLLUUeVqBSUpJqwRi5A2dWy5nIs9R
aVaa33oP+mE0e3kPE9ehmf7Zc984OLW9sw1ILUS+xr2lcK90HDptGztNs6qQ
L965oHLooBT6LBY7lPrg/6teuJ8fkiaFTK1FVg/f8JFXVi+JUqmlcKC7QrDM
qwF5sF/vmUt/yWC+2LIwn4xzv+D91mR7hgxO+Ntxoj2x/+0xsEyllsHG2UT5
gnLspm7OcUqbDyC45JYda4Bd01myWl70ATSj/ExGrfG5VbRvTtUEObB5U4aR
D/A93Sna2VH2ckgrDRrxPYX7ijNxMPqBzgR07J/z8NCsQO4SylPR6yegsVt5
ReyXhTyG58gs9lFAeb/nlbtzFqj+nOd6Dgy9SQiLf/ZocCAdubg4JSr/+iS8
5MSv3Oici3xnFrFW/O8kRHI0fPX78HxjpC5Ntjb+CNGHiM9GaoqRFyfOB76M
+giOAact+s1wP6zrNjl3XfYRbvXFiLiKIuQsLRerXRZK+J3tut47DO/faLzp
vyaeEj64smcFaTl4rlqLc+lKJVysiJYlHcN9Zcu7cFae+wlqnI5LHDQtkR8u
0I7VP/MZjJf8cWpwSSaqz/1DhqK5758huiF3eMUGPK9Gp7ccoThOgfRESU+O
fzVyG62d8RvuTIHODrvukR04l0b9Q8Nry6dApiPrMWK9RF5okRRaJpqCiY4V
JFoqzpfrIiUfXzkNN7f5c/5k4HlCOxCXVESchsOlgZmzAdgVm/dqkkjToBYn
C1uu1fP/B5Wx3Ro=
       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1Hs0FFgcB3CxSlEGyaOs0aitPY1NykaHX97lzaGxXpVHijbP2Dy2pZRX
1Iw1bGdl89iR10x25JlhiJBUmvUcjLzNGA22dlXbP937x++fz7nn3Ht/v++9
On6hroHSUlJSTp9L5nMZkq6NWHn8A+TM+3cbT1NMLU8TIxbO9TR/8ZiE6FZa
WDJ4ar/+0dKyG3lTdaw9NexXCLeQ+tpGrQv5uvkH0sDNAuC8YjTW/tSBXPNA
k04QpQTkWYvlvNp25LY9jfTKXCa4MVcDTg49Rp5gpUgNnmdD3tL7Qtr2cuT2
wkS3O1UNsPNMQmS+WiR8ca3wzQTlVA6oMHXdL6lWId9Qvxp152ML+L3LiOHa
sZG/kRYMEqK48POwluE7jXrk173L4jiCNggU8w0ShNh1a6K0wlyeQLwb/7Su
dhPyrYXJLbF/doBMl/CGXnEj8pWsnMDkD51w1HRWIEPE66+nVDUEh3VBym4T
wwMqdchVEjuVnCe7QTZVX3L9XjXy1tzU1j56L1z2b2wf7y5Avno+ac3jXh9U
jjwKZ9Jvo/4cUuo0KVJ8CW9DQyNKt7CR19i737QNegXP089bbrLhIHcQa8um
6/TD4xo9O9rlVuQC2nxS93A/eKvxszIz8Lx4zSTtIuprcHphJG1AxPPtXvBu
iD/JAysXHWHJiU7k/hN1A9IrPFgeqHbuaMDr13k71lLy/wbHNfKxVgPsQS9j
LsZTBkC8M+Xks+NPkL96NiAIJQxCfw5ro95iG/JJqs8QoWkQhGaWxwP78fkl
FMEL1oUhSLWLneM7NCNvEEoieseGwTRyW52hFws5ZAucdzqNQmfFxpn1r2jI
FXrV9bnFfOh2IilbT+D+N6eWTdxXGAdjtciLbeos5KJPPdae/uMguUqmXDqA
56gVLSpTqh+HXDlRo/QYzmH8QRuiquIEmC/aGPK8HiEfmr+XrR4wAb9EkEgZ
Bth3M2LZrpwJ2LcdNEO6/kIeHOjOy9glAOO3efs3VzOR55fq5VV2CuDjUodr
N6EQebFEnm1ybRLOfqOh8ntnEr7vE8pSgPEb0Ep+FrnHvQr5Dr+OB0ZTb0C0
GmOd5VOHXNZgA3vIbApsHVV7JFT8fldkjjXH5U8Bv0ZX307UgpxdtzFNsjIF
LdZbJq+xuMijQ1+6hdhNQ6IU48TEUTzfcxde631XMA0b/I1OvSvAfsp/QE6y
Mg20teaWszTs+md8soTOMzCmSL2VysQu7yNQnS2fAQb/2xxRCN63xvS9d530
LIxKuI5dBJwfPyKhKM1jFva0B65G9+F7Zc6Zpf+mPAdXIjIWv9fA78s3ni6h
cOaAxbA3tycVI8+ge8VWBM/D7ag4YpLgIup/Zi3JM4y0AOEMms5K6B/Ixyvy
0hhXFkAwOEjmFDKQGxQqNow/X4CtcmVJWWaVyMPubsp1Ii+C7H88fmIFzmEF
7VPU47RF0A54OpJmhl2jT+/slelFCJnfRtsbh3OSrODrcNhcCMb6xLQj62XI
uWTtf9vpQrjcxHN3binF/6rTeAlFKIS7BwMPdcnhXO2LJEkRbUUAd6zqPTXp
yF3o536YLRHBW8GaX3yRC+qPZSnh1l63JSBbnJL05hQiz7HYP7b+YQl851Op
n/ofIu9/6uWpSBaDdBWbqxJUi5y/vNuK6CWGj4/S7ZUfNiJ3VjC4veuGGEbb
HgR4EPC/x91rMazOEoPDSHKmZgf2B+bZ8cwxMbBnOBVbn+PcUn2ntE5sWwat
zZFp1MM4J6bHs7LLFZfB1uSq4+gR7PM6RvJKSsswzHSNrTVubf4f0Gengg==

       "]]}}, {{}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], Line3DBox[CompressedData["
1:eJxF1Hs0lGkcB/BJB5VhXCJFxiVOtUzJnt1s5Se5JR2XlIzrklzaMi6bkygp
hdxNRuZERVbubCMMjfulQXIZty0z4z4YI2K10fZPz/vH88/nvOd5zvP9fd9H
wzPA3lsMh8PZfV9bv6/VTLWdVM110Et8Tq91dzQ6fpx1UFu/h/XDQyOuN6ZR
ouGXzh3uh8q6kNf9HWadSnkEun0xQt9dmO/RrdPwccwDz+7+iemwduRWnbW0
kowykPhSzig2bkAeYUZI9Rcw4E6Kt5PWcDFy64U7DimlTNDbQr4/UhAIP3xv
4HZZ+dh62CT7bX6aKke+peZzSMpmAxi1VWkrhL5GPiHGH5YNaYIp+ob/Ub03
yO+5FN6s5zeDYlJwUDq9Fvm+ypC9FLtWuNV+zGJArR65dE50Q9hfbeAdRxDa
8VjIV5LSvaM32uHdGxNycDD2/b2YUqY/5S2oX32WbRHDRK5wp13OdpwNVOqh
CS+ZSuSNGbGNPbRuMBKoDL2Peo78s2/U6sXsHnBVjhR/kJaA8jki134il9AL
zZQ/I5pGqpBXWp9/YOXTB8O9PylJnGxEflZEFH+o0Q+RxmOqVyabkPPTBFHs
0X6IId3t1HTF5sVhaRFzUwdA8jap2Te3Azl7zoUZfpoDGnhj+p4jbORevOoh
sRUO6CbHz53d9Rb5V47SakzWIPiWWPfODWL7+PSG/hHuOAR10jtSHgVh5/Z1
DfEDZIfBvHDUfwLfhnw81XVEtm4YDHfzVDosWpAvO/Lfl/uNgH5H9vK6AdYr
5sJyUPfYKLS+PoNLlqtADlS+rYrNB2Brb7VPm01Drl2+YRzw5QOMR16ODQr3
Q/nju5X1m158BEmh1CeVvBfIW0S/ht1zH4P38d9K9UuLkLNiC3nP8VxoTeo8
rRBQgVz4rdOc7MUFE5rurW5FBtbn68JCuRouvBvb/PSEWIU8/LCFuiKBB9Me
H+cTiDXIRwTZVOVLPEg0DOmrHq5GrpkfxrCv58E1aYdEMybWf3/v85x4VT7g
cqpJdevY/5L1kvS4pJ0PXWtSGbAbu9eLZSnGibvjoB18fLxEFIvywbc6Ll76
bQKMHh4MdJLC8lTybCswnJyAl7RBy7uqtcjFDbYwRk5Ogry2y2HTjXrkK1uP
sW5mTcI/52rSnTaxHjKqJeKWVyaBQyeT5Kex+V4P6HW4cmYKInFL0h7ercgv
+w2QDj2dgrWOwggeD/MLXkPbllem4EDsnoILHpjre7gmLdhOQ7CB6WqCAdYr
KVe+4kzRNOiIvNSSqdi5lUbrLtViM9DnIdlxg9yM3FNdNjfu4gyQjEXn8JnY
vRJnTz7MlJ+FTn2ziH+tXyN3C6ctO9bPwk73JstTLXnIP8euV0YpCmBRZ8Ve
6E5DHk9zDiv2F4BlcRktR+km9v7kg0CmTQBZvRdVq2/TkCdWaZEpWnPQ1sW6
UHE4Bzm3+HFc/o05cNi44vZfQgFygxwCk/tuDtotzI+OfC1DTqFLZtjozQPb
hvCM8/gV8uK0byFv4ubBstlCPK8e6/PuHtLvN6bmwbZbgW5PxTwa73b2Z5MF
2NjZYLo/oBh5kx7xSwttAXyeyOwr2laCvds23DzHhQXw7CCat3TlIt8frIVT
txLC2lqPAccqE7kd7bLTTJ4QQo0lOtW0rqHcTF/KJug4LIKy6Tm9pHgs5/RT
B8a+bixCCpshnX/rFfL+DmcyQU8EAxXOvZISTOQflzTN1J1FEN74JHhNHJuv
Ld4gWfW+CK4ORnBjZLB3tUnn1KhyuQj2icx5gScwT3Wb3GspswRPQ0wu7cdh
/TEyTqIWEZZAyMadp0hgLtAwlJKTWwLiUdV+4vZm1v/aacc8
       "]]}}}, {
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{0, 0, 0}, {0, Rational[1, 30], 0}, {0, Rational[1, 15], 0}, {
        0, Rational[1, 10], 0}, {0, Rational[2, 15], 0}, {
        0, Rational[1, 6], 0}, {0, Rational[1, 5], 0}, {
        0, Rational[7, 30], 0}, {0, Rational[4, 15], 0}, {
        0, Rational[3, 10], 0}, {0, Rational[1, 3], 0}, {
        0, Rational[11, 30], 0}, {0, Rational[2, 5], 0}, {
        0, Rational[13, 30], 0}, {0, Rational[7, 15], 0}, {
        0, Rational[1, 2], 0}, {0, Rational[8, 15], 0}, {
        0, Rational[17, 30], 0}, {0, Rational[3, 5], 0}, {
        0, Rational[19, 30], 0}, {0, Rational[2, 3], 0}, {
        0, Rational[7, 10], 0}, {0, Rational[11, 15], 0}, {
        0, Rational[23, 30], 0}, {0, Rational[4, 5], 0}, {
        0, Rational[5, 6], 0}, {0, Rational[13, 15], 0}, {
        0, Rational[9, 10], 0}, {0, Rational[14, 15], 0}, {
        0, Rational[29, 30], 0}, {0, 1, 0}, {0, Rational[31, 30], -0.00448}, {
        0, Rational[16, 15], -0.00448}}, {{0, 0, 0}, {
        0, 0.03333333333333333, 0}, {0, 0.06666666666666667, 0}, {
        0, 0.1, 0}, {0, 0.13333333333333333`, 0}, {
        0, 0.16666666666666666`, 0}, {0, 0.2, 0}, {
        0, 0.23333333333333334`, 0}, {0, 0.26666666666666666`, 0}, {
        0, 0.3, 0}, {0, 0.3333333333333333, 0}, {
        0, 0.36666666666666664`, 0}, {0, 0.4, 0}, {
        0, 0.43333333333333335`, 0}, {0, 0.4666666666666667, 0}, {
        0, 0.5, 0}, {0, 0.5333333333333333, 0}, {0, 0.5666666666666667, 0}, {
        0, 0.6, 0}, {0, 0.6333333333333333, 0}, {0, 0.6666666666666666, 0}, {
        0, 0.7, 0}, {0, 0.7333333333333333, 0}, {0, 0.7666666666666667, 0}, {
        0, 0.8, 0}, {0, 0.8333333333333334, 0}, {0, 0.8666666666666667, 0}, {
        0, 0.9, 0}, {0, 0.9333333333333333, 0}, {0, 0.9666666666666667, 0}, {
        0, 1, 0}, {0, 1.0333333333333334`, -0.00448}, {
        0, 1.0666666666666667`, -0.00448}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{0.1074148, 0, 0}, {0.1074148, Rational[1, 30], 0}, {
        0.1074148, Rational[1, 15], 0}, {0.1074148, Rational[1, 10], 0}, {
        0.1074148, Rational[2, 15], 0}, {
        0.1074148, Rational[1, 6], 0.00448}, {0.1074148, Rational[1, 5], 0}, {
        0.1074148, Rational[7, 30], 0}, {0.1074148, Rational[4, 15], 0}, {
        0.1074148, Rational[3, 10], 0}, {0.1074148, Rational[1, 3], 0}, {
        0.1074148, Rational[11, 30], 0}, {0.1074148, Rational[2, 5], 0}, {
        0.1074148, Rational[13, 30], 0}, {
        0.1074148, Rational[7, 15], 0.00448}, {
        0.1074148, Rational[1, 2], 0.00448}, {
        0.1074148, Rational[8, 15], 0}, {0.1074148, Rational[17, 30], 0}, {
        0.1074148, Rational[3, 5], 0}, {0.1074148, Rational[19, 30], 0}, {
        0.1074148, Rational[2, 3], 0}, {0.1074148, Rational[7, 10], 0}, {
        0.1074148, Rational[11, 15], 0}, {0.1074148, Rational[23, 30], 0}, {
        0.1074148, Rational[4, 5], 0}, {0.1074148, Rational[5, 6], 0}, {
        0.1074148, Rational[13, 15], 0}, {0.1074148, Rational[9, 10], 0}, {
        0.1074148, Rational[14, 15], 0}, {0.1074148, Rational[29, 30], 0}, {
        0.1074148, 1, 0}, {0.1074148, Rational[31, 30], 0}, {
        0.1074148, Rational[16, 15], 0}}, {{0.1074148, 0, 0}, {
        0.1074148, 0.03333333333333333, 0}, {
        0.1074148, 0.06666666666666667, 0}, {0.1074148, 0.1, 0}, {
        0.1074148, 0.13333333333333333`, 0}, {0.1074148, 0.16666666666666666`,
         0.00448}, {0.1074148, 0.2, 0}, {
        0.1074148, 0.23333333333333334`, 0}, {
        0.1074148, 0.26666666666666666`, 0}, {0.1074148, 0.3, 0}, {
        0.1074148, 0.3333333333333333, 0}, {
        0.1074148, 0.36666666666666664`, 0}, {0.1074148, 0.4, 0}, {
        0.1074148, 0.43333333333333335`, 0}, {0.1074148, 0.4666666666666667, 
        0.00448}, {0.1074148, 0.5, 0.00448}, {
        0.1074148, 0.5333333333333333, 0}, {
        0.1074148, 0.5666666666666667, 0}, {0.1074148, 0.6, 0}, {
        0.1074148, 0.6333333333333333, 0}, {
        0.1074148, 0.6666666666666666, 0}, {0.1074148, 0.7, 0}, {
        0.1074148, 0.7333333333333333, 0}, {
        0.1074148, 0.7666666666666667, 0}, {0.1074148, 0.8, 0}, {
        0.1074148, 0.8333333333333334, 0}, {
        0.1074148, 0.8666666666666667, 0}, {0.1074148, 0.9, 0}, {
        0.1074148, 0.9333333333333333, 0}, {
        0.1074148, 0.9666666666666667, 0}, {0.1074148, 1, 0}, {
        0.1074148, 1.0333333333333334`, 0}, {
        0.1074148, 1.0666666666666667`, 0}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{0.2193052, 0, -0.00895}, {
        0.2193052, Rational[1, 30], -0.00895}, {
        0.2193052, Rational[1, 15], 0}, {0.2193052, Rational[1, 10], 0}, {
        0.2193052, Rational[2, 15], 0.00448}, {
        0.2193052, Rational[1, 6], 0.00895}, {
        0.2193052, Rational[1, 5], 0.00448}, {
        0.2193052, Rational[7, 30], 0}, {
        0.2193052, Rational[4, 15], -0.00448}, {
        0.2193052, Rational[3, 10], -0.00895}, {
        0.2193052, Rational[1, 3], -0.0134}, {
        0.2193052, Rational[11, 30], -0.00895}, {
        0.2193052, Rational[2, 5], -0.00895}, {
        0.2193052, Rational[13, 30], -0.00448}, {
        0.2193052, Rational[7, 15], 0}, {
        0.2193052, Rational[1, 2], 0.00895}, {
        0.2193052, Rational[8, 15], 0.00895}, {
        0.2193052, Rational[17, 30], 0}, {0.2193052, Rational[3, 5], 0}, {
        0.2193052, Rational[19, 30], -0.00448}, {
        0.2193052, Rational[2, 3], -0.00895}, {
        0.2193052, Rational[7, 10], -0.0134}, {
        0.2193052, Rational[11, 15], -0.0134}, {
        0.2193052, Rational[23, 30], -0.00448}, {
        0.2193052, Rational[4, 5], -0.00448}, {
        0.2193052, Rational[5, 6], 0}, {
        0.2193052, Rational[13, 15], 0.00448}, {
        0.2193052, Rational[9, 10], 0.00895}, {
        0.2193052, Rational[14, 15], 0}, {0.2193052, Rational[29, 30], 0}, {
        0.2193052, 1, -0.00448}, {0.2193052, Rational[31, 30], -0.00895}, {
        0.2193052, Rational[16, 15], -0.00448}}, {{0.2193052, 0, -0.00895}, {
        0.2193052, 0.03333333333333333, -0.00895}, {
        0.2193052, 0.06666666666666667, 0}, {0.2193052, 0.1, 0}, {0.2193052, 
        0.13333333333333333`, 0.00448}, {0.2193052, 0.16666666666666666`, 
        0.00895}, {0.2193052, 0.2, 0.00448}, {
        0.2193052, 0.23333333333333334`, 0}, {0.2193052, 
        0.26666666666666666`, -0.00448}, {0.2193052, 0.3, -0.00895}, {
        0.2193052, 0.3333333333333333, -0.0134}, {0.2193052, 
        0.36666666666666664`, -0.00895}, {0.2193052, 0.4, -0.00895}, {
        0.2193052, 0.43333333333333335`, -0.00448}, {
        0.2193052, 0.4666666666666667, 0}, {0.2193052, 0.5, 0.00895}, {
        0.2193052, 0.5333333333333333, 0.00895}, {
        0.2193052, 0.5666666666666667, 0}, {0.2193052, 0.6, 0}, {0.2193052, 
        0.6333333333333333, -0.00448}, {0.2193052, 
        0.6666666666666666, -0.00895}, {0.2193052, 0.7, -0.0134}, {0.2193052, 
        0.7333333333333333, -0.0134}, {0.2193052, 
        0.7666666666666667, -0.00448}, {0.2193052, 0.8, -0.00448}, {
        0.2193052, 0.8333333333333334, 0}, {0.2193052, 0.8666666666666667, 
        0.00448}, {0.2193052, 0.9, 0.00895}, {
        0.2193052, 0.9333333333333333, 0}, {
        0.2193052, 0.9666666666666667, 0}, {0.2193052, 1, -0.00448}, {
        0.2193052, 1.0333333333333334`, -0.00895}, {0.2193052, 
        1.0666666666666667`, -0.00448}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{0.3401469, 0, -0.0179}, {
        0.3401469, Rational[1, 30], -0.0134}, {
        0.3401469, Rational[1, 15], -0.00895}, {
        0.3401469, Rational[1, 10], 0}, {
        0.3401469, Rational[2, 15], 0.00448}, {
        0.3401469, Rational[1, 6], 0.00895}, {
        0.3401469, Rational[1, 5], 0.00448}, {
        0.3401469, Rational[7, 30], 0.00448}, {
        0.3401469, Rational[4, 15], -0.00448}, {
        0.3401469, Rational[3, 10], -0.0134}, {
        0.3401469, Rational[1, 3], -0.0179}, {
        0.3401469, Rational[11, 30], -0.0224}, {
        0.3401469, Rational[2, 5], -0.0134}, {
        0.3401469, Rational[13, 30], -0.00895}, {
        0.3401469, Rational[7, 15], 0}, {
        0.3401469, Rational[1, 2], 0.00448}, {
        0.3401469, Rational[8, 15], 0.00895}, {
        0.3401469, Rational[17, 30], 0.00448}, {
        0.3401469, Rational[3, 5], 0}, {
        0.3401469, Rational[19, 30], -0.00895}, {
        0.3401469, Rational[2, 3], -0.0134}, {
        0.3401469, Rational[7, 10], -0.0179}, {
        0.3401469, Rational[11, 15], -0.0179}, {
        0.3401469, Rational[23, 30], -0.00895}, {
        0.3401469, Rational[4, 5], -0.00895}, {
        0.3401469, Rational[5, 6], 0}, {
        0.3401469, Rational[13, 15], 0.00895}, {
        0.3401469, Rational[9, 10], 0.00895}, {
        0.3401469, Rational[14, 15], 0.00448}, {
        0.3401469, Rational[29, 30], 0}, {0.3401469, 1, -0.00895}, {
        0.3401469, Rational[31, 30], -0.0134}, {
        0.3401469, Rational[16, 15], -0.0179}}, {{0.3401469, 0, -0.0179}, {
        0.3401469, 0.03333333333333333, -0.0134}, {0.3401469, 
        0.06666666666666667, -0.00895}, {0.3401469, 0.1, 0}, {0.3401469, 
        0.13333333333333333`, 0.00448}, {0.3401469, 0.16666666666666666`, 
        0.00895}, {0.3401469, 0.2, 0.00448}, {0.3401469, 0.23333333333333334`,
         0.00448}, {0.3401469, 0.26666666666666666`, -0.00448}, {0.3401469, 
        0.3, -0.0134}, {0.3401469, 0.3333333333333333, -0.0179}, {0.3401469, 
        0.36666666666666664`, -0.0224}, {0.3401469, 0.4, -0.0134}, {0.3401469,
         0.43333333333333335`, -0.00895}, {
        0.3401469, 0.4666666666666667, 0}, {0.3401469, 0.5, 0.00448}, {
        0.3401469, 0.5333333333333333, 0.00895}, {0.3401469, 
        0.5666666666666667, 0.00448}, {0.3401469, 0.6, 0}, {0.3401469, 
        0.6333333333333333, -0.00895}, {0.3401469, 
        0.6666666666666666, -0.0134}, {0.3401469, 0.7, -0.0179}, {0.3401469, 
        0.7333333333333333, -0.0179}, {0.3401469, 
        0.7666666666666667, -0.00895}, {0.3401469, 0.8, -0.00895}, {
        0.3401469, 0.8333333333333334, 0}, {0.3401469, 0.8666666666666667, 
        0.00895}, {0.3401469, 0.9, 0.00895}, {0.3401469, 0.9333333333333333, 
        0.00448}, {0.3401469, 0.9666666666666667, 0}, {
        0.3401469, 1, -0.00895}, {0.3401469, 1.0333333333333334`, -0.0134}, {
        0.3401469, 1.0666666666666667`, -0.0179}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{0.4475617, 0, -0.0269}, {
        0.4475617, Rational[1, 30], -0.0269}, {
        0.4475617, Rational[1, 15], -0.0179}, {
        0.4475617, Rational[1, 10], -0.00448}, {
        0.4475617, Rational[2, 15], 0.00448}, {
        0.4475617, Rational[1, 6], 0.0179}, {
        0.4475617, Rational[1, 5], 0.00895}, {
        0.4475617, Rational[7, 30], 0}, {
        0.4475617, Rational[4, 15], -0.0134}, {
        0.4475617, Rational[3, 10], -0.0224}, {
        0.4475617, Rational[1, 3], -0.0269}, {
        0.4475617, Rational[11, 30], -0.0358}, {
        0.4475617, Rational[2, 5], -0.0224}, {
        0.4475617, Rational[13, 30], -0.0179}, {
        0.4475617, Rational[7, 15], 0}, {
        0.4475617, Rational[1, 2], 0.00895}, {
        0.4475617, Rational[8, 15], 0.00895}, {
        0.4475617, Rational[17, 30], 0.00895}, {
        0.4475617, Rational[3, 5], -0.00448}, {
        0.4475617, Rational[19, 30], -0.0179}, {
        0.4475617, Rational[2, 3], -0.0224}, {
        0.4475617, Rational[7, 10], -0.0269}, {
        0.4475617, Rational[11, 15], -0.0224}, {
        0.4475617, Rational[23, 30], -0.0224}, {
        0.4475617, Rational[4, 5], -0.0134}, {
        0.4475617, Rational[5, 6], -0.00448}, {
        0.4475617, Rational[13, 15], 0.00895}, {
        0.4475617, Rational[9, 10], 0.0134269}, {
        0.4475617, Rational[14, 15], 0}, {
        0.4475617, Rational[29, 30], -0.00448}, {0.4475617, 1, -0.0179}, {
        0.4475617, Rational[31, 30], -0.0224}, {
        0.4475617, Rational[16, 15], -0.0269}}, {{0.4475617, 0, -0.0269}, {
        0.4475617, 0.03333333333333333, -0.0269}, {0.4475617, 
        0.06666666666666667, -0.0179}, {0.4475617, 0.1, -0.00448}, {0.4475617,
         0.13333333333333333`, 0.00448}, {0.4475617, 0.16666666666666666`, 
        0.0179}, {0.4475617, 0.2, 0.00895}, {
        0.4475617, 0.23333333333333334`, 0}, {0.4475617, 
        0.26666666666666666`, -0.0134}, {0.4475617, 0.3, -0.0224}, {0.4475617,
         0.3333333333333333, -0.0269}, {0.4475617, 
        0.36666666666666664`, -0.0358}, {0.4475617, 0.4, -0.0224}, {0.4475617,
         0.43333333333333335`, -0.0179}, {0.4475617, 0.4666666666666667, 0}, {
        0.4475617, 0.5, 0.00895}, {0.4475617, 0.5333333333333333, 0.00895}, {
        0.4475617, 0.5666666666666667, 0.00895}, {0.4475617, 0.6, -0.00448}, {
        0.4475617, 0.6333333333333333, -0.0179}, {0.4475617, 
        0.6666666666666666, -0.0224}, {0.4475617, 0.7, -0.0269}, {0.4475617, 
        0.7333333333333333, -0.0224}, {0.4475617, 
        0.7666666666666667, -0.0224}, {0.4475617, 0.8, -0.0134}, {0.4475617, 
        0.8333333333333334, -0.00448}, {0.4475617, 0.8666666666666667, 
        0.00895}, {0.4475617, 0.9, 0.0134269}, {
        0.4475617, 0.9333333333333333, 0}, {0.4475617, 
        0.9666666666666667, -0.00448}, {0.4475617, 1, -0.0179}, {0.4475617, 
        1.0333333333333334`, -0.0224}, {0.4475617, 
        1.0666666666666667`, -0.0269}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{0.5549766, 0, -0.0403}, {
        0.5549766, Rational[1, 30], -0.0358}, {
        0.5549766, Rational[1, 15], -0.0179}, {
        0.5549766, Rational[1, 10], -0.00448}, {
        0.5549766, Rational[2, 15], 0.00895}, {
        0.5549766, Rational[1, 6], 0.0224}, {
        0.5549766, Rational[1, 5], 0.0134269}, {
        0.5549766, Rational[7, 30], 0.00448}, {
        0.5549766, Rational[4, 15], -0.00895}, {
        0.5549766, Rational[3, 10], -0.0269}, {
        0.5549766, Rational[1, 3], -0.0403}, {
        0.5549766, Rational[11, 30], -0.0403}, {
        0.5549766, Rational[2, 5], -0.0269}, {
        0.5549766, Rational[13, 30], -0.0179}, {
        0.5549766, Rational[7, 15], 0}, {
        0.5549766, Rational[1, 2], 0.00895}, {
        0.5549766, Rational[8, 15], 0.0179}, {
        0.5549766, Rational[17, 30], 0.0134269}, {
        0.5549766, Rational[3, 5], 0}, {
        0.5549766, Rational[19, 30], -0.0134}, {
        0.5549766, Rational[2, 3], -0.0269}, {
        0.5549766, Rational[7, 10], -0.0358}, {
        0.5549766, Rational[11, 15], -0.0358}, {
        0.5549766, Rational[23, 30], -0.0269}, {
        0.5549766, Rational[4, 5], -0.0134}, {
        0.5549766, Rational[5, 6], -0.00448}, {
        0.5549766, Rational[13, 15], 0.00895}, {
        0.5549766, Rational[9, 10], 0.0134269}, {
        0.5549766, Rational[14, 15], 0.00448}, {
        0.5549766, Rational[29, 30], -0.00448}, {0.5549766, 1, -0.0224}, {
        0.5549766, Rational[31, 30], -0.0313}, {
        0.5549766, Rational[16, 15], -0.0358}}, {{0.5549766, 0, -0.0403}, {
        0.5549766, 0.03333333333333333, -0.0358}, {0.5549766, 
        0.06666666666666667, -0.0179}, {0.5549766, 0.1, -0.00448}, {0.5549766,
         0.13333333333333333`, 0.00895}, {0.5549766, 0.16666666666666666`, 
        0.0224}, {0.5549766, 0.2, 0.0134269}, {0.5549766, 
        0.23333333333333334`, 0.00448}, {0.5549766, 
        0.26666666666666666`, -0.00895}, {0.5549766, 0.3, -0.0269}, {
        0.5549766, 0.3333333333333333, -0.0403}, {0.5549766, 
        0.36666666666666664`, -0.0403}, {0.5549766, 0.4, -0.0269}, {0.5549766,
         0.43333333333333335`, -0.0179}, {0.5549766, 0.4666666666666667, 0}, {
        0.5549766, 0.5, 0.00895}, {0.5549766, 0.5333333333333333, 0.0179}, {
        0.5549766, 0.5666666666666667, 0.0134269}, {0.5549766, 0.6, 0}, {
        0.5549766, 0.6333333333333333, -0.0134}, {0.5549766, 
        0.6666666666666666, -0.0269}, {0.5549766, 0.7, -0.0358}, {0.5549766, 
        0.7333333333333333, -0.0358}, {0.5549766, 
        0.7666666666666667, -0.0269}, {0.5549766, 0.8, -0.0134}, {0.5549766, 
        0.8333333333333334, -0.00448}, {0.5549766, 0.8666666666666667, 
        0.00895}, {0.5549766, 0.9, 0.0134269}, {0.5549766, 0.9333333333333333,
         0.00448}, {0.5549766, 0.9666666666666667, -0.00448}, {
        0.5549766, 1, -0.0224}, {0.5549766, 1.0333333333333334`, -0.0313}, {
        0.5549766, 1.0666666666666667`, -0.0358}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{0.6713426, 0, -0.0582}, {
        0.6713426, Rational[1, 30], -0.0492}, {
        0.6713426, Rational[1, 15], -0.0313}, {
        0.6713426, Rational[1, 10], -0.00895}, {
        0.6713426, Rational[2, 15], 0.00895}, {
        0.6713426, Rational[1, 6], 0.0313}, {
        0.6713426, Rational[1, 5], 0.0134269}, {
        0.6713426, Rational[7, 30], 0.00895}, {
        0.6713426, Rational[4, 15], -0.0134}, {
        0.6713426, Rational[3, 10], -0.0403}, {
        0.6713426, Rational[1, 3], -0.0492}, {
        0.6713426, Rational[11, 30], -0.0582}, {
        0.6713426, Rational[2, 5], -0.0403}, {
        0.6713426, Rational[13, 30], -0.0224}, {
        0.6713426, Rational[7, 15], -0.00448}, {
        0.6713426, Rational[1, 2], 0.0134269}, {
        0.6713426, Rational[8, 15], 0.0224}, {
        0.6713426, Rational[17, 30], 0.0179}, {
        0.6713426, Rational[3, 5], -0.00895}, {
        0.6713426, Rational[19, 30], -0.0224}, {
        0.6713426, Rational[2, 3], -0.0403}, {
        0.6713426, Rational[7, 10], -0.0537}, {
        0.6713426, Rational[11, 15], -0.0492}, {
        0.6713426, Rational[23, 30], -0.0403}, {
        0.6713426, Rational[4, 5], -0.0179}, {0.6713426, Rational[5, 6], 0}, {
        0.6713426, Rational[13, 15], 0.0134269}, {
        0.6713426, Rational[9, 10], 0.0179}, {
        0.6713426, Rational[14, 15], 0.0134269}, {
        0.6713426, Rational[29, 30], -0.00895}, {0.6713426, 1, -0.0269}, {
        0.6713426, Rational[31, 30], -0.0403}, {
        0.6713426, Rational[16, 15], -0.0492}}, {{0.6713426, 0, -0.0582}, {
        0.6713426, 0.03333333333333333, -0.0492}, {0.6713426, 
        0.06666666666666667, -0.0313}, {0.6713426, 0.1, -0.00895}, {0.6713426,
         0.13333333333333333`, 0.00895}, {0.6713426, 0.16666666666666666`, 
        0.0313}, {0.6713426, 0.2, 0.0134269}, {0.6713426, 
        0.23333333333333334`, 0.00895}, {0.6713426, 
        0.26666666666666666`, -0.0134}, {0.6713426, 0.3, -0.0403}, {0.6713426,
         0.3333333333333333, -0.0492}, {0.6713426, 
        0.36666666666666664`, -0.0582}, {0.6713426, 0.4, -0.0403}, {0.6713426,
         0.43333333333333335`, -0.0224}, {0.6713426, 
        0.4666666666666667, -0.00448}, {0.6713426, 0.5, 0.0134269}, {
        0.6713426, 0.5333333333333333, 0.0224}, {0.6713426, 
        0.5666666666666667, 0.0179}, {0.6713426, 0.6, -0.00895}, {0.6713426, 
        0.6333333333333333, -0.0224}, {0.6713426, 
        0.6666666666666666, -0.0403}, {0.6713426, 0.7, -0.0537}, {0.6713426, 
        0.7333333333333333, -0.0492}, {0.6713426, 
        0.7666666666666667, -0.0403}, {0.6713426, 0.8, -0.0179}, {
        0.6713426, 0.8333333333333334, 0}, {0.6713426, 0.8666666666666667, 
        0.0134269}, {0.6713426, 0.9, 0.0179}, {0.6713426, 0.9333333333333333, 
        0.0134269}, {0.6713426, 0.9666666666666667, -0.00895}, {
        0.6713426, 1, -0.0269}, {0.6713426, 1.0333333333333334`, -0.0403}, {
        0.6713426, 1.0666666666666667`, -0.0492}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{0.783233, 0, -0.0805611}, {
        0.783233, Rational[1, 30], -0.0761}, {
        0.783233, Rational[1, 15], -0.0448}, {
        0.783233, Rational[1, 10], -0.00895}, {
        0.783233, Rational[2, 15], 0.0179}, {
        0.783233, Rational[1, 6], 0.0358}, {
        0.783233, Rational[1, 5], 0.0269}, {
        0.783233, Rational[7, 30], 0.00895}, {
        0.783233, Rational[4, 15], -0.0269}, {
        0.783233, Rational[3, 10], -0.0537}, {
        0.783233, Rational[1, 3], -0.0716}, {
        0.783233, Rational[11, 30], -0.0761}, {
        0.783233, Rational[2, 5], -0.0582}, {
        0.783233, Rational[13, 30], -0.0358}, {
        0.783233, Rational[7, 15], -0.00895}, {
        0.783233, Rational[1, 2], 0.0179}, {
        0.783233, Rational[8, 15], 0.0269}, {
        0.783233, Rational[17, 30], 0.0179}, {
        0.783233, Rational[3, 5], -0.00448}, {
        0.783233, Rational[19, 30], -0.0313}, {
        0.783233, Rational[2, 3], -0.0537}, {
        0.783233, Rational[7, 10], -0.0671}, {
        0.783233, Rational[11, 15], -0.0627}, {
        0.783233, Rational[23, 30], -0.0492}, {
        0.783233, Rational[4, 5], -0.0269}, {
        0.783233, Rational[5, 6], -0.00448}, {
        0.783233, Rational[13, 15], 0.0134269}, {
        0.783233, Rational[9, 10], 0.0224}, {
        0.783233, Rational[14, 15], 0.00448}, {
        0.783233, Rational[29, 30], -0.00895}, {0.783233, 1, -0.0403}, {
        0.783233, Rational[31, 30], -0.0582}, {
        0.783233, Rational[16, 15], -0.0671}}, {{0.783233, 0, -0.0805611}, {
        0.783233, 0.03333333333333333, -0.0761}, {0.783233, 
        0.06666666666666667, -0.0448}, {0.783233, 0.1, -0.00895}, {0.783233, 
        0.13333333333333333`, 0.0179}, {0.783233, 0.16666666666666666`, 
        0.0358}, {0.783233, 0.2, 0.0269}, {0.783233, 0.23333333333333334`, 
        0.00895}, {0.783233, 0.26666666666666666`, -0.0269}, {0.783233, 
        0.3, -0.0537}, {0.783233, 0.3333333333333333, -0.0716}, {0.783233, 
        0.36666666666666664`, -0.0761}, {0.783233, 0.4, -0.0582}, {0.783233, 
        0.43333333333333335`, -0.0358}, {0.783233, 
        0.4666666666666667, -0.00895}, {0.783233, 0.5, 0.0179}, {0.783233, 
        0.5333333333333333, 0.0269}, {0.783233, 0.5666666666666667, 0.0179}, {
        0.783233, 0.6, -0.00448}, {0.783233, 0.6333333333333333, -0.0313}, {
        0.783233, 0.6666666666666666, -0.0537}, {0.783233, 0.7, -0.0671}, {
        0.783233, 0.7333333333333333, -0.0627}, {0.783233, 
        0.7666666666666667, -0.0492}, {0.783233, 0.8, -0.0269}, {0.783233, 
        0.8333333333333334, -0.00448}, {0.783233, 0.8666666666666667, 
        0.0134269}, {0.783233, 0.9, 0.0224}, {0.783233, 0.9333333333333333, 
        0.00448}, {0.783233, 0.9666666666666667, -0.00895}, {
        0.783233, 1, -0.0403}, {0.783233, 1.0333333333333334`, -0.0582}, {
        0.783233, 1.0666666666666667`, -0.0671}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{0.8995991, 0, -0.094}, {0.8995991, Rational[1, 30], -0.0895}, {
        0.8995991, Rational[1, 15], -0.0492}, {
        0.8995991, Rational[1, 10], -0.0134}, {
        0.8995991, Rational[2, 15], 0.0224}, {
        0.8995991, Rational[1, 6], 0.0403}, {
        0.8995991, Rational[1, 5], 0.0313}, {
        0.8995991, Rational[7, 30], 0.00895}, {
        0.8995991, Rational[4, 15], -0.0358}, {
        0.8995991, Rational[3, 10], -0.0716}, {
        0.8995991, Rational[1, 3], -0.094}, {
        0.8995991, Rational[11, 30], -0.094}, {
        0.8995991, Rational[2, 5], -0.0716}, {
        0.8995991, Rational[13, 30], -0.0403}, {
        0.8995991, Rational[7, 15], -0.00448}, {
        0.8995991, Rational[1, 2], 0.0269}, {
        0.8995991, Rational[8, 15], 0.0313}, {
        0.8995991, Rational[17, 30], 0.0224}, {
        0.8995991, Rational[3, 5], -0.00448}, {
        0.8995991, Rational[19, 30], -0.0358}, {
        0.8995991, Rational[2, 3], -0.0671}, {
        0.8995991, Rational[7, 10], -0.0850367}, {
        0.8995991, Rational[11, 15], -0.0761}, {
        0.8995991, Rational[23, 30], -0.0582}, {
        0.8995991, Rational[4, 5], -0.0358}, {0.8995991, Rational[5, 6], 0}, {
        0.8995991, Rational[13, 15], 0.0224}, {
        0.8995991, Rational[9, 10], 0.0313}, {
        0.8995991, Rational[14, 15], 0.0134269}, {
        0.8995991, Rational[29, 30], -0.00895}, {0.8995991, 1, -0.0358}, {
        0.8995991, Rational[31, 30], -0.0671}, {
        0.8995991, Rational[16, 15], -0.0761}}, {{0.8995991, 0, -0.094}, {
        0.8995991, 0.03333333333333333, -0.0895}, {0.8995991, 
        0.06666666666666667, -0.0492}, {0.8995991, 0.1, -0.0134}, {0.8995991, 
        0.13333333333333333`, 0.0224}, {0.8995991, 0.16666666666666666`, 
        0.0403}, {0.8995991, 0.2, 0.0313}, {0.8995991, 0.23333333333333334`, 
        0.00895}, {0.8995991, 0.26666666666666666`, -0.0358}, {0.8995991, 
        0.3, -0.0716}, {0.8995991, 0.3333333333333333, -0.094}, {0.8995991, 
        0.36666666666666664`, -0.094}, {0.8995991, 0.4, -0.0716}, {0.8995991, 
        0.43333333333333335`, -0.0403}, {0.8995991, 
        0.4666666666666667, -0.00448}, {0.8995991, 0.5, 0.0269}, {0.8995991, 
        0.5333333333333333, 0.0313}, {0.8995991, 0.5666666666666667, 
        0.0224}, {0.8995991, 0.6, -0.00448}, {0.8995991, 
        0.6333333333333333, -0.0358}, {0.8995991, 
        0.6666666666666666, -0.0671}, {0.8995991, 0.7, -0.0850367}, {
        0.8995991, 0.7333333333333333, -0.0761}, {0.8995991, 
        0.7666666666666667, -0.0582}, {0.8995991, 0.8, -0.0358}, {
        0.8995991, 0.8333333333333334, 0}, {0.8995991, 0.8666666666666667, 
        0.0224}, {0.8995991, 0.9, 0.0313}, {0.8995991, 0.9333333333333333, 
        0.0134269}, {0.8995991, 0.9666666666666667, -0.00895}, {
        0.8995991, 1, -0.0358}, {0.8995991, 1.0333333333333334`, -0.0671}, {
        0.8995991, 1.0666666666666667`, -0.0761}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{1.015965, 0, -0.1208416}, {
        1.015965, Rational[1, 30], -0.0985}, {
        1.015965, Rational[1, 15], -0.0627}, {
        1.015965, Rational[1, 10], -0.00895}, {
        1.015965, Rational[2, 15], 0.0269}, {
        1.015965, Rational[1, 6], 0.0537}, {
        1.015965, Rational[1, 5], 0.0448}, {
        1.015965, Rational[7, 30], 0.0134269}, {
        1.015965, Rational[4, 15], -0.0358}, {
        1.015965, Rational[3, 10], -0.0761}, {
        1.015965, Rational[1, 3], -0.1029392}, {
        1.015965, Rational[11, 30], -0.1118904}, {
        1.015965, Rational[2, 5], -0.0895}, {
        1.015965, Rational[13, 30], -0.0448}, {
        1.015965, Rational[7, 15], -0.00448}, {
        1.015965, Rational[1, 2], 0.0313}, {
        1.015965, Rational[8, 15], 0.0448}, {
        1.015965, Rational[17, 30], 0.0269}, {1.015965, Rational[3, 5], 0}, {
        1.015965, Rational[19, 30], -0.0403}, {
        1.015965, Rational[2, 3], -0.0761}, {
        1.015965, Rational[7, 10], -0.1029392}, {
        1.015965, Rational[11, 15], -0.0985}, {
        1.015965, Rational[23, 30], -0.0761}, {
        1.015965, Rational[4, 5], -0.0448}, {1.015965, Rational[5, 6], 0}, {
        1.015965, Rational[13, 15], 0.0269}, {
        1.015965, Rational[9, 10], 0.0313}, {
        1.015965, Rational[14, 15], 0.0134269}, {
        1.015965, Rational[29, 30], -0.00895}, {1.015965, 1, -0.0448}, {
        1.015965, Rational[31, 30], -0.0850367}, {
        1.015965, Rational[16, 15], -0.094}}, {{1.015965, 0, -0.1208416}, {
        1.015965, 0.03333333333333333, -0.0985}, {1.015965, 
        0.06666666666666667, -0.0627}, {1.015965, 0.1, -0.00895}, {1.015965, 
        0.13333333333333333`, 0.0269}, {1.015965, 0.16666666666666666`, 
        0.0537}, {1.015965, 0.2, 0.0448}, {1.015965, 0.23333333333333334`, 
        0.0134269}, {1.015965, 0.26666666666666666`, -0.0358}, {1.015965, 
        0.3, -0.0761}, {1.015965, 0.3333333333333333, -0.1029392}, {1.015965, 
        0.36666666666666664`, -0.1118904}, {1.015965, 0.4, -0.0895}, {
        1.015965, 0.43333333333333335`, -0.0448}, {1.015965, 
        0.4666666666666667, -0.00448}, {1.015965, 0.5, 0.0313}, {1.015965, 
        0.5333333333333333, 0.0448}, {1.015965, 0.5666666666666667, 0.0269}, {
        1.015965, 0.6, 0}, {1.015965, 0.6333333333333333, -0.0403}, {1.015965,
         0.6666666666666666, -0.0761}, {1.015965, 0.7, -0.1029392}, {1.015965,
         0.7333333333333333, -0.0985}, {1.015965, 
        0.7666666666666667, -0.0761}, {1.015965, 0.8, -0.0448}, {
        1.015965, 0.8333333333333334, 0}, {1.015965, 0.8666666666666667, 
        0.0269}, {1.015965, 0.9, 0.0313}, {1.015965, 0.9333333333333333, 
        0.0134269}, {1.015965, 0.9666666666666667, -0.00895}, {
        1.015965, 1, -0.0448}, {1.015965, 1.0333333333333334`, -0.0850367}, {
        1.015965, 1.0666666666666667`, -0.094}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{1.12338, 0, -0.1432197}, {
        1.12338, Rational[1, 30], -0.1253173}, {
        1.12338, Rational[1, 15], -0.0716}, {
        1.12338, Rational[1, 10], -0.0134}, {
        1.12338, Rational[2, 15], 0.0313}, {
        1.12338, Rational[1, 6], 0.0627}, {1.12338, Rational[1, 5], 0.0492}, {
        1.12338, Rational[7, 30], 0.00895}, {
        1.12338, Rational[4, 15], -0.0403}, {
        1.12338, Rational[3, 10], -0.094}, {
        1.12338, Rational[1, 3], -0.1253173}, {
        1.12338, Rational[11, 30], -0.1387441}, {
        1.12338, Rational[2, 5], -0.1029392}, {
        1.12338, Rational[13, 30], -0.0582}, {
        1.12338, Rational[7, 15], -0.00895}, {
        1.12338, Rational[1, 2], 0.0313}, {
        1.12338, Rational[8, 15], 0.0492}, {
        1.12338, Rational[17, 30], 0.0358}, {1.12338, Rational[3, 5], 0}, {
        1.12338, Rational[19, 30], -0.0537}, {
        1.12338, Rational[2, 3], -0.0985}, {
        1.12338, Rational[7, 10], -0.1253173}, {
        1.12338, Rational[11, 15], -0.1208416}, {
        1.12338, Rational[23, 30], -0.094}, {
        1.12338, Rational[4, 5], -0.0492}, {
        1.12338, Rational[5, 6], -0.00448}, {
        1.12338, Rational[13, 15], 0.0269}, {
        1.12338, Rational[9, 10], 0.0403}, {
        1.12338, Rational[14, 15], 0.0224}, {
        1.12338, Rational[29, 30], -0.0134}, {1.12338, 1, -0.0671}, {
        1.12338, Rational[31, 30], -0.0985}, {
        1.12338, Rational[16, 15], -0.116366}}, {{1.12338, 0, -0.1432197}, {
        1.12338, 0.03333333333333333, -0.1253173}, {1.12338, 
        0.06666666666666667, -0.0716}, {1.12338, 0.1, -0.0134}, {1.12338, 
        0.13333333333333333`, 0.0313}, {1.12338, 0.16666666666666666`, 
        0.0627}, {1.12338, 0.2, 0.0492}, {1.12338, 0.23333333333333334`, 
        0.00895}, {1.12338, 0.26666666666666666`, -0.0403}, {1.12338, 
        0.3, -0.094}, {1.12338, 0.3333333333333333, -0.1253173}, {1.12338, 
        0.36666666666666664`, -0.1387441}, {1.12338, 0.4, -0.1029392}, {
        1.12338, 0.43333333333333335`, -0.0582}, {1.12338, 
        0.4666666666666667, -0.00895}, {1.12338, 0.5, 0.0313}, {1.12338, 
        0.5333333333333333, 0.0492}, {1.12338, 0.5666666666666667, 0.0358}, {
        1.12338, 0.6, 0}, {1.12338, 0.6333333333333333, -0.0537}, {1.12338, 
        0.6666666666666666, -0.0985}, {1.12338, 0.7, -0.1253173}, {1.12338, 
        0.7333333333333333, -0.1208416}, {1.12338, 
        0.7666666666666667, -0.094}, {1.12338, 0.8, -0.0492}, {1.12338, 
        0.8333333333333334, -0.00448}, {1.12338, 0.8666666666666667, 
        0.0269}, {1.12338, 0.9, 0.0403}, {1.12338, 0.9333333333333333, 
        0.0224}, {1.12338, 0.9666666666666667, -0.0134}, {
        1.12338, 1, -0.0671}, {1.12338, 1.0333333333333334`, -0.0985}, {
        1.12338, 1.0666666666666667`, -0.116366}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{1.230795, 0, -0.1700734}, {
        1.230795, Rational[1, 30], -0.1476954}, {
        1.230795, Rational[1, 15], -0.0895}, {
        1.230795, Rational[1, 10], -0.0224}, {
        1.230795, Rational[2, 15], 0.0403}, {
        1.230795, Rational[1, 6], 0.0716}, {
        1.230795, Rational[1, 5], 0.0537}, {
        1.230795, Rational[7, 30], 0.00895}, {
        1.230795, Rational[4, 15], -0.0492}, {
        1.230795, Rational[3, 10], -0.1029392}, {
        1.230795, Rational[1, 3], -0.1432197}, {
        1.230795, Rational[11, 30], -0.1566466}, {
        1.230795, Rational[2, 5], -0.1253173}, {
        1.230795, Rational[13, 30], -0.0671}, {
        1.230795, Rational[7, 15], -0.0134}, {
        1.230795, Rational[1, 2], 0.0403}, {
        1.230795, Rational[8, 15], 0.0582}, {
        1.230795, Rational[17, 30], 0.0403}, {
        1.230795, Rational[3, 5], -0.00448}, {
        1.230795, Rational[19, 30], -0.0582}, {
        1.230795, Rational[2, 3], -0.1118904}, {
        1.230795, Rational[7, 10], -0.1387441}, {
        1.230795, Rational[11, 15], -0.1342685}, {
        1.230795, Rational[23, 30], -0.1074148}, {
        1.230795, Rational[4, 5], -0.0537}, {
        1.230795, Rational[5, 6], -0.00448}, {
        1.230795, Rational[13, 15], 0.0358}, {
        1.230795, Rational[9, 10], 0.0492}, {
        1.230795, Rational[14, 15], 0.0179}, {
        1.230795, Rational[29, 30], -0.0134}, {1.230795, 1, -0.0716}, {
        1.230795, Rational[31, 30], -0.1118904}, {
        1.230795, Rational[16, 15], -0.1297929}}, {{
        1.230795, 0, -0.1700734}, {1.230795, 
        0.03333333333333333, -0.1476954}, {1.230795, 
        0.06666666666666667, -0.0895}, {1.230795, 0.1, -0.0224}, {1.230795, 
        0.13333333333333333`, 0.0403}, {1.230795, 0.16666666666666666`, 
        0.0716}, {1.230795, 0.2, 0.0537}, {1.230795, 0.23333333333333334`, 
        0.00895}, {1.230795, 0.26666666666666666`, -0.0492}, {1.230795, 
        0.3, -0.1029392}, {1.230795, 0.3333333333333333, -0.1432197}, {
        1.230795, 0.36666666666666664`, -0.1566466}, {1.230795, 
        0.4, -0.1253173}, {1.230795, 0.43333333333333335`, -0.0671}, {
        1.230795, 0.4666666666666667, -0.0134}, {1.230795, 0.5, 0.0403}, {
        1.230795, 0.5333333333333333, 0.0582}, {1.230795, 0.5666666666666667, 
        0.0403}, {1.230795, 0.6, -0.00448}, {1.230795, 
        0.6333333333333333, -0.0582}, {1.230795, 
        0.6666666666666666, -0.1118904}, {1.230795, 0.7, -0.1387441}, {
        1.230795, 0.7333333333333333, -0.1342685}, {1.230795, 
        0.7666666666666667, -0.1074148}, {1.230795, 0.8, -0.0537}, {1.230795, 
        0.8333333333333334, -0.00448}, {1.230795, 0.8666666666666667, 
        0.0358}, {1.230795, 0.9, 0.0492}, {1.230795, 0.9333333333333333, 
        0.0179}, {1.230795, 0.9666666666666667, -0.0134}, {
        1.230795, 1, -0.0716}, {1.230795, 1.0333333333333334`, -0.1118904}, {
        1.230795, 1.0666666666666667`, -0.1297929}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{1.347161, 0, -0.1924515}, {
        1.347161, Rational[1, 30], -0.1655978}, {
        1.347161, Rational[1, 15], -0.0985}, {
        1.347161, Rational[1, 10], -0.0269}, {
        1.347161, Rational[2, 15], 0.0448}, {
        1.347161, Rational[1, 6], 0.0806}, {
        1.347161, Rational[1, 5], 0.0627}, {
        1.347161, Rational[7, 30], 0.0179}, {
        1.347161, Rational[4, 15], -0.0537}, {
        1.347161, Rational[3, 10], -0.1253173}, {
        1.347161, Rational[1, 3], -0.1700734}, {
        1.347161, Rational[11, 30], -0.174549}, {
        1.347161, Rational[2, 5], -0.1387441}, {
        1.347161, Rational[13, 30], -0.0761}, {
        1.347161, Rational[7, 15], -0.00448}, {
        1.347161, Rational[1, 2], 0.0403}, {
        1.347161, Rational[8, 15], 0.0671}, {
        1.347161, Rational[17, 30], 0.0448}, {1.347161, Rational[3, 5], 0}, {
        1.347161, Rational[19, 30], -0.0627}, {
        1.347161, Rational[2, 3], -0.1253173}, {
        1.347161, Rational[7, 10], -0.1566466}, {
        1.347161, Rational[11, 15], -0.1566466}, {
        1.347161, Rational[23, 30], -0.116366}, {
        1.347161, Rational[4, 5], -0.0582}, {
        1.347161, Rational[5, 6], -0.00448}, {
        1.347161, Rational[13, 15], 0.0403}, {
        1.347161, Rational[9, 10], 0.0537}, {
        1.347161, Rational[14, 15], 0.0269}, {
        1.347161, Rational[29, 30], -0.0224}, {1.347161, 1, -0.0761}, {
        1.347161, Rational[31, 30], -0.1253173}, {
        1.347161, Rational[16, 15], -0.152171}}, {{1.347161, 0, -0.1924515}, {
        1.347161, 0.03333333333333333, -0.1655978}, {1.347161, 
        0.06666666666666667, -0.0985}, {1.347161, 0.1, -0.0269}, {1.347161, 
        0.13333333333333333`, 0.0448}, {1.347161, 0.16666666666666666`, 
        0.0806}, {1.347161, 0.2, 0.0627}, {1.347161, 0.23333333333333334`, 
        0.0179}, {1.347161, 0.26666666666666666`, -0.0537}, {1.347161, 
        0.3, -0.1253173}, {1.347161, 0.3333333333333333, -0.1700734}, {
        1.347161, 0.36666666666666664`, -0.174549}, {1.347161, 
        0.4, -0.1387441}, {1.347161, 0.43333333333333335`, -0.0761}, {
        1.347161, 0.4666666666666667, -0.00448}, {1.347161, 0.5, 0.0403}, {
        1.347161, 0.5333333333333333, 0.0671}, {1.347161, 0.5666666666666667, 
        0.0448}, {1.347161, 0.6, 0}, {1.347161, 
        0.6333333333333333, -0.0627}, {1.347161, 
        0.6666666666666666, -0.1253173}, {1.347161, 0.7, -0.1566466}, {
        1.347161, 0.7333333333333333, -0.1566466}, {1.347161, 
        0.7666666666666667, -0.116366}, {1.347161, 0.8, -0.0582}, {1.347161, 
        0.8333333333333334, -0.00448}, {1.347161, 0.8666666666666667, 
        0.0403}, {1.347161, 0.9, 0.0537}, {1.347161, 0.9333333333333333, 
        0.0269}, {1.347161, 0.9666666666666667, -0.0224}, {
        1.347161, 1, -0.0761}, {1.347161, 1.0333333333333334`, -0.1253173}, {
        1.347161, 1.0666666666666667`, -0.152171}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{1.459051, 0, -0.2148296}, {
        1.459051, Rational[1, 30], -0.1879759}, {
        1.459051, Rational[1, 15], -0.116366}, {
        1.459051, Rational[1, 10], -0.0224}, {
        1.459051, Rational[2, 15], 0.0492}, {
        1.459051, Rational[1, 6], 0.085}, {
        1.459051, Rational[1, 5], 0.0761}, {
        1.459051, Rational[7, 30], 0.0134269}, {
        1.459051, Rational[4, 15], -0.0627}, {
        1.459051, Rational[3, 10], -0.1297929}, {
        1.459051, Rational[1, 3], -0.1879759}, {
        1.459051, Rational[11, 30], -0.1969271}, {
        1.459051, Rational[2, 5], -0.1611222}, {
        1.459051, Rational[13, 30], -0.0895}, {
        1.459051, Rational[7, 15], -0.0224}, {
        1.459051, Rational[1, 2], 0.0448}, {
        1.459051, Rational[8, 15], 0.0716}, {
        1.459051, Rational[17, 30], 0.0492}, {
        1.459051, Rational[3, 5], -0.00448}, {
        1.459051, Rational[19, 30], -0.0716}, {
        1.459051, Rational[2, 3], -0.1387441}, {
        1.459051, Rational[7, 10], -0.1835003}, {
        1.459051, Rational[11, 15], -0.174549}, {
        1.459051, Rational[23, 30], -0.1342685}, {
        1.459051, Rational[4, 5], -0.0761}, {1.459051, Rational[5, 6], 0}, {
        1.459051, Rational[13, 15], 0.0291}, {
        1.459051, Rational[9, 10], 0.0582}, {
        1.459051, Rational[14, 15], 0.0313}, {
        1.459051, Rational[29, 30], -0.0269}, {1.459051, 1, -0.0895}, {
        1.459051, Rational[31, 30], -0.1476954}, {
        1.459051, Rational[16, 15], -0.174549}}, {{1.459051, 0, -0.2148296}, {
        1.459051, 0.03333333333333333, -0.1879759}, {1.459051, 
        0.06666666666666667, -0.116366}, {1.459051, 0.1, -0.0224}, {1.459051, 
        0.13333333333333333`, 0.0492}, {1.459051, 0.16666666666666666`, 
        0.085}, {1.459051, 0.2, 0.0761}, {1.459051, 0.23333333333333334`, 
        0.0134269}, {1.459051, 0.26666666666666666`, -0.0627}, {1.459051, 
        0.3, -0.1297929}, {1.459051, 0.3333333333333333, -0.1879759}, {
        1.459051, 0.36666666666666664`, -0.1969271}, {1.459051, 
        0.4, -0.1611222}, {1.459051, 0.43333333333333335`, -0.0895}, {
        1.459051, 0.4666666666666667, -0.0224}, {1.459051, 0.5, 0.0448}, {
        1.459051, 0.5333333333333333, 0.0716}, {1.459051, 0.5666666666666667, 
        0.0492}, {1.459051, 0.6, -0.00448}, {1.459051, 
        0.6333333333333333, -0.0716}, {1.459051, 
        0.6666666666666666, -0.1387441}, {1.459051, 0.7, -0.1835003}, {
        1.459051, 0.7333333333333333, -0.174549}, {1.459051, 
        0.7666666666666667, -0.1342685}, {1.459051, 0.8, -0.0761}, {
        1.459051, 0.8333333333333334, 0}, {1.459051, 0.8666666666666667, 
        0.0291}, {1.459051, 0.9, 0.0582}, {1.459051, 0.9333333333333333, 
        0.0313}, {1.459051, 0.9666666666666667, -0.0269}, {
        1.459051, 1, -0.0895}, {1.459051, 1.0333333333333334`, -0.1476954}, {
        1.459051, 1.0666666666666667`, -0.174549}}]]}, 
    {RGBColor[0, 0, 1], PointSize[0.011], 
     Point3DBox[
      NCache[{{1.570942, 0, -0.2372077}, {
        1.570942, Rational[1, 30], -0.1969271}, {
        1.570942, Rational[1, 15], -0.1253173}, {
        1.570942, Rational[1, 10], -0.0313}, {
        1.570942, Rational[2, 15], 0.0627}, {
        1.570942, Rational[1, 6], 0.0985}, {
        1.570942, Rational[1, 5], 0.0806}, {
        1.570942, Rational[7, 30], 0.0179}, {
        1.570942, Rational[4, 15], -0.0671}, {
        1.570942, Rational[3, 10], -0.1476954}, {
        1.570942, Rational[1, 3], -0.2058784}, {
        1.570942, Rational[11, 30], -0.2058784}, {
        1.570942, Rational[2, 5], -0.1700734}, {
        1.570942, Rational[13, 30], -0.0985}, {
        1.570942, Rational[7, 15], -0.0134}, {
        1.570942, Rational[1, 2], 0.0582}, {
        1.570942, Rational[8, 15], 0.0806}, {
        1.570942, Rational[17, 30], 0.0582}, {
        1.570942, Rational[3, 5], -0.00895}, {
        1.570942, Rational[19, 30], -0.0761}, {
        1.570942, Rational[2, 3], -0.152171}, {
        1.570942, Rational[7, 10], -0.1969271}, {
        1.570942, Rational[11, 15], -0.1879759}, {
        1.570942, Rational[23, 30], -0.1432197}, {
        1.570942, Rational[4, 5], -0.0761}, {
        1.570942, Rational[5, 6], -0.00448}, {
        1.570942, Rational[13, 15], 0.0537}, {
        1.570942, Rational[9, 10], 0.0671}, {
        1.570942, Rational[14, 15], 0.0358}, {
        1.570942, Rational[29, 30], -0.0269}, {1.570942, 1, -0.1074148}, {
        1.570942, Rational[31, 30], -0.1566466}, {
        1.570942, Rational[16, 15], -0.1879759}}, {{
        1.570942, 0, -0.2372077}, {1.570942, 
        0.03333333333333333, -0.1969271}, {1.570942, 
        0.06666666666666667, -0.1253173}, {1.570942, 0.1, -0.0313}, {1.570942,
         0.13333333333333333`, 0.0627}, {1.570942, 0.16666666666666666`, 
        0.0985}, {1.570942, 0.2, 0.0806}, {1.570942, 0.23333333333333334`, 
        0.0179}, {1.570942, 0.26666666666666666`, -0.0671}, {1.570942, 
        0.3, -0.1476954}, {1.570942, 0.3333333333333333, -0.2058784}, {
        1.570942, 0.36666666666666664`, -0.2058784}, {1.570942, 
        0.4, -0.1700734}, {1.570942, 0.43333333333333335`, -0.0985}, {
        1.570942, 0.4666666666666667, -0.0134}, {1.570942, 0.5, 0.0582}, {
        1.570942, 0.5333333333333333, 0.0806}, {1.570942, 0.5666666666666667, 
        0.0582}, {1.570942, 0.6, -0.00895}, {1.570942, 
        0.6333333333333333, -0.0761}, {1.570942, 
        0.6666666666666666, -0.152171}, {1.570942, 0.7, -0.1969271}, {
        1.570942, 0.7333333333333333, -0.1879759}, {1.570942, 
        0.7666666666666667, -0.1432197}, {1.570942, 0.8, -0.0761}, {1.570942, 
        0.8333333333333334, -0.00448}, {1.570942, 0.8666666666666667, 
        0.0537}, {1.570942, 0.9, 0.0671}, {1.570942, 0.9333333333333333, 
        0.0358}, {1.570942, 0.9666666666666667, -0.0269}, {
        1.570942, 1, -0.1074148}, {1.570942, 
        1.0333333333333334`, -0.1566466}, {1.570942, 
        1.0666666666666667`, -0.1879759}}]]}}},
  Axes->{True, True, True},
  AxesLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"y\"", TraditionalForm]},
  BoxRatios->{3, 2, 1},
  Boxed->False,
  ImageSize->600,
  PlotRange->NCache[{{0, 1.6}, {0, 
      Rational[11, 10]}, {-0.25, 0.25}}, {{0, 1.6}, {0, 1.1}, {-0.25, 0.25}}],
  
  PlotRangePadding->{Automatic, Automatic, Automatic},
  Ticks->{{{0, 
      FormBox["0", TraditionalForm]}, {0.1074148, 
      FormBox["0.1074148`", TraditionalForm]}, {0.2193052, 
      FormBox["0.2193052`", TraditionalForm]}, {0.3401469, 
      FormBox["0.3401469`", TraditionalForm]}, {0.4475617, 
      FormBox["0.4475617`", TraditionalForm]}, {0.5549766, 
      FormBox["0.5549766`", TraditionalForm]}, {0.6713426, 
      FormBox["0.6713426`", TraditionalForm]}, {0.783233, 
      FormBox["0.783233`", TraditionalForm]}, {0.8995991, 
      FormBox["0.8995991`", TraditionalForm]}, {1.015965, 
      FormBox["1.015965`", TraditionalForm]}, {1.12338, 
      FormBox["1.12338`", TraditionalForm]}, {1.230795, 
      FormBox["1.230795`", TraditionalForm]}, {1.347161, 
      FormBox["1.347161`", TraditionalForm]}, {1.459051, 
      FormBox["1.459051`", TraditionalForm]}, {1.570942, 
      FormBox["1.570942`", TraditionalForm]}}, Automatic, Automatic},
  ViewPoint->{0.8, -1.5, 1.5}]], "Output",
 CellChangeTimes->{3.456061452171875*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
ShowSelection->True,
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 143, 5, 50, "Subtitle"],
Cell[736, 30, 217, 4, 28, "Subsubtitle"],
Cell[CellGroupData[{
Cell[978, 38, 31, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[1034, 42, 38, 0, 28, "Subsubsection"],
Cell[1075, 44, 565, 10, 101, "Text"],
Cell[1643, 56, 32149, 585, 2366, "Input"],
Cell[33795, 643, 159, 3, 29, "Text"],
Cell[33957, 648, 187, 6, 31, "Input"],
Cell[34147, 656, 147, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[34319, 663, 403, 13, 31, "Input"],
Cell[34725, 678, 378, 7, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35140, 690, 63, 1, 31, "Input"],
Cell[35206, 693, 71, 1, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[35338, 701, 43, 0, 36, "Subsection"],
Cell[35384, 703, 47, 0, 29, "Text"],
Cell[35434, 705, 101, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[35560, 711, 824, 25, 33, "Input"],
Cell[36387, 738, 549, 17, 50, "Output"]
}, Open  ]],
Cell[36951, 758, 547, 16, 50, "Input"],
Cell[CellGroupData[{
Cell[37523, 778, 54, 1, 31, "Input"],
Cell[37580, 781, 408, 13, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38037, 800, 40, 0, 36, "Subsection"],
Cell[38080, 802, 599, 14, 47, "Text"],
Cell[38682, 818, 69, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[38776, 824, 378, 11, 33, "Input"],
Cell[39157, 837, 220, 6, 30, "Output"]
}, Open  ]],
Cell[39392, 846, 241, 7, 31, "Input"],
Cell[39636, 855, 237, 6, 52, "Input"],
Cell[CellGroupData[{
Cell[39898, 865, 120, 2, 31, "Input"],
Cell[40021, 869, 195, 6, 30, "Output"]
}, Open  ]],
Cell[40231, 878, 160, 5, 31, "Input"],
Cell[CellGroupData[{
Cell[40416, 887, 118, 2, 31, "Input"],
Cell[40537, 891, 531, 17, 50, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[41117, 914, 37, 0, 36, "Subsection"],
Cell[CellGroupData[{
Cell[41179, 918, 51, 0, 28, "Subsubsection"],
Cell[41233, 920, 997, 29, 90, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42267, 954, 194, 7, 28, "Subsubsection"],
Cell[42464, 963, 1402, 45, 47, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43903, 1013, 508, 13, 45, "Subsubsection"],
Cell[44414, 1028, 7483, 215, 183, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51934, 1248, 253, 8, 28, "Subsubsection"],
Cell[52190, 1258, 1119, 35, 126, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[53346, 1298, 190, 7, 28, "Subsubsection"],
Cell[53539, 1307, 753, 24, 38, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54329, 1336, 467, 17, 28, "Subsubsection"],
Cell[54799, 1355, 416, 14, 31, "Input"],
Cell[55218, 1371, 140, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[55383, 1376, 77, 2, 31, "Input"],
Cell[55463, 1380, 21530, 612, 1203, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[77054, 1999, 295, 6, 36, "Subsection"],
Cell[77352, 2007, 127, 3, 29, "Text"],
Cell[77482, 2012, 183, 6, 31, "Input"],
Cell[77668, 2020, 431, 13, 31, "Input"],
Cell[78102, 2035, 159, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[78286, 2042, 3300, 88, 187, "Input"],
Cell[81589, 2132, 33531, 523, 490, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[115169, 2661, 217, 4, 36, "Subsection"],
Cell[CellGroupData[{
Cell[115411, 2669, 2337, 64, 133, "Input"],
Cell[117753, 2736, 2878, 52, 245, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[120680, 2794, 186, 4, 36, "Subsection"],
Cell[120869, 2800, 562, 14, 50, "Text"],
Cell[121434, 2816, 1286, 34, 46, "Input"],
Cell[CellGroupData[{
Cell[122745, 2854, 226, 5, 34, "Input"],
Cell[122974, 2861, 89, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[123112, 2868, 616, 13, 63, "Subsection"],
Cell[123731, 2883, 261, 6, 52, "Input"],
Cell[CellGroupData[{
Cell[124017, 2893, 378, 10, 31, "Input"],
Cell[124398, 2905, 289, 8, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124724, 2918, 413, 8, 34, "Input"],
Cell[125140, 2928, 89, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[125278, 2935, 571, 13, 58, "Subsection"],
Cell[125852, 2950, 2245, 53, 146, "Input"],
Cell[128100, 3005, 3070, 74, 112, "Input"],
Cell[CellGroupData[{
Cell[131195, 3083, 484, 10, 31, "Input"],
Cell[131682, 3095, 75726, 1322, 476, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
